# API Reference - Types and Classes

## Classes

The following classes are defined:

|Name                |Description                                                           |
|:-------------------|:---------------------------------------------------------------------|
|`auth              `|Management of remote authentication services                          |
|`blob              `|A placeholder for a binary blob                                       |
|`Bond              `|                                                                      |
|`Certificate       `|Description                                                           |
|`Cluster           `|Cluster&#45;wide Cluster metadata                                     |
|`Cluster_host      `|Cluster member metadata                                               |
|`console           `|A console                                                             |
|`crashdump         `|**Deprecated**. A VM crashdump                                        |
|`data_source       `|Data sources for logging in RRDs                                      |
|`DR_task           `|DR task                                                               |
|`event             `|Asynchronous event registration and handling                          |
|`Feature           `|A new piece of functionality                                          |
|`GPU_group         `|A group of compatible GPUs across the resource pool                   |
|`host              `|A physical host                                                       |
|`host_cpu          `|**Deprecated**. A physical CPU                                        |
|`host_crashdump    `|Represents a host crash dump                                          |
|`host_metrics      `|The metrics associated with a host                                    |
|`host_patch        `|**Deprecated**. Represents a patch stored on a server                 |
|`LVHD              `|LVHD SR specific operations                                           |
|`message           `|An message for the attention of the administrator                     |
|`network           `|A virtual network                                                     |
|`network_sriov     `|network&#45;sriov which connects logical pif and physical pif         |
|`PBD               `|The physical block devices through which hosts access SRs             |
|`PCI               `|A PCI device                                                          |
|`PGPU              `|A physical GPU &#40;pGPU&#41;                                         |
|`PIF               `|A physical network interface &#40;note separate VLANs are represented as several PIFs&#41;|
|`PIF_metrics       `|The metrics associated with a physical network interface              |
|`pool              `|Pool&#45;wide information                                             |
|`pool_patch        `|**Deprecated**. Pool&#45;wide patches                                 |
|`pool_update       `|Pool&#45;wide updates to the host software                            |
|`probe_result      `|A set of properties that describe one result element of SR.probe. Result elements and properties can change dynamically based on changes to the the SR.probe input&#45;parameters or the target.|
|`PUSB              `|A physical USB device                                                 |
|`PVS_cache_storage `|Describes the storage that is available to a PVS site for caching purposes|
|`PVS_proxy         `|a proxy connects a VM/VIF with a PVS site                             |
|`PVS_server        `|individual machine serving provisioning &#40;block&#41; data          |
|`PVS_site          `|machines serving blocks of data for provisioning VMs                  |
|`role              `|A set of permissions associated with a subject                        |
|`SDN_controller    `|Describes the SDN controller that is to connect with the pool         |
|`secret            `|A secret                                                              |
|`session           `|A session                                                             |
|`SM                `|A storage manager plugin                                              |
|`SR                `|A storage repository                                                  |
|`sr_stat           `|A set of high&#45;level properties associated with an SR.             |
|`subject           `|A user or group that can log in xapi                                  |
|`task              `|A long&#45;running asynchronous task                                  |
|`tunnel            `|A tunnel for network traffic                                          |
|`USB_group         `|A group of compatible USBs across the resource pool                   |
|`user              `|**Deprecated**. A user of the system                                  |
|`VBD               `|A virtual block device                                                |
|`VBD_metrics       `|**Removed**. The metrics associated with a virtual block device       |
|`VDI               `|A virtual disk image                                                  |
|`vdi_nbd_server_info`|Details for connecting to a VDI using the Network Block Device protocol|
|`VGPU              `|A virtual GPU &#40;vGPU&#41;                                          |
|`VGPU_type         `|A type of virtual GPU                                                 |
|`VIF               `|A virtual network interface                                           |
|`VIF_metrics       `|**Removed**. The metrics associated with a virtual network device     |
|`VLAN              `|A VLAN mux/demux                                                      |
|`VM                `|A virtual machine &#40;or 'guest'&#41;.                               |
|`VM_appliance      `|VM appliance                                                          |
|`VM_guest_metrics  `|The metrics reported by the guest &#40;as opposed to inferred from outside&#41;|
|`VM_metrics        `|The metrics associated with a VM                                      |
|`VMPP              `|**Removed**. VM Protection Policy                                     |
|`VMSS              `|VM Snapshot Schedule                                                  |
|`VTPM              `|A virtual TPM device                                                  |
|`VUSB              `|Describes the vusb device                                             |

## Relationships Between Classes

Fields that are bound together are shown in the following table:

|_object.field_                          |_object.field_                          |_relationship_ |
|:---------------------------------------|:---------------------------------------|:--------------|
|`VM.snapshot_of                        `|`VM.snapshots                          `|one-to-many    |
|`VDI.snapshot_of                       `|`VDI.snapshots                         `|one-to-many    |
|`VM.parent                             `|`VM.children                           `|one-to-many    |
|`task.subtask_of                       `|`task.subtasks                         `|one-to-many    |
|`PIF.bond_slave_of                     `|`Bond.slaves                           `|one-to-many    |
|`Bond.master                           `|`PIF.bond_master_of                    `|one-to-many    |
|`VLAN.tagged_PIF                       `|`PIF.VLAN_slave_of                     `|one-to-many    |
|`tunnel.access_PIF                     `|`PIF.tunnel_access_PIF_of              `|one-to-many    |
|`tunnel.transport_PIF                  `|`PIF.tunnel_transport_PIF_of           `|one-to-many    |
|`PBD.host                              `|`host.PBDs                             `|one-to-many    |
|`PBD.SR                                `|`SR.PBDs                               `|one-to-many    |
|`VBD.VDI                               `|`VDI.VBDs                              `|one-to-many    |
|`crashdump.VDI                         `|`VDI.crash_dumps                       `|one-to-many    |
|`VBD.VM                                `|`VM.VBDs                               `|one-to-many    |
|`crashdump.VM                          `|`VM.crash_dumps                        `|one-to-many    |
|`VIF.VM                                `|`VM.VIFs                               `|one-to-many    |
|`VIF.network                           `|`network.VIFs                          `|one-to-many    |
|`Cluster_host.cluster                  `|`Cluster.cluster_hosts                 `|one-to-many    |
|`PIF.host                              `|`host.PIFs                             `|one-to-many    |
|`PIF.network                           `|`network.PIFs                          `|one-to-many    |
|`VDI.SR                                `|`SR.VDIs                               `|one-to-many    |
|`VTPM.VM                               `|`VM.VTPMs                              `|one-to-many    |
|`console.VM                            `|`VM.consoles                           `|one-to-many    |
|`VM.resident_on                        `|`host.resident_VMs                     `|one-to-many    |
|`host_cpu.host                         `|`host.host_CPUs                        `|one-to-many    |
|`host_crashdump.host                   `|`host.crashdumps                       `|one-to-many    |
|`host_patch.host                       `|`host.patches                          `|one-to-many    |
|`host_patch.pool_patch                 `|`pool_patch.host_patches               `|one-to-many    |
|`host.updates                          `|`pool_update.hosts                     `|many-to-many   |
|`subject.roles                         `|`subject.roles                         `|unknown type   |
|`role.subroles                         `|`role.subroles                         `|many-to-many   |
|`VM.protection_policy                  `|`VMPP.VMs                              `|one-to-many    |
|`VM.snapshot_schedule                  `|`VMSS.VMs                              `|one-to-many    |
|`VM.appliance                          `|`VM_appliance.VMs                      `|one-to-many    |
|`PGPU.GPU_group                        `|`GPU_group.PGPUs                       `|one-to-many    |
|`VGPU.GPU_group                        `|`GPU_group.VGPUs                       `|one-to-many    |
|`VGPU.type                             `|`VGPU_type.VGPUs                       `|one-to-many    |
|`VGPU.VM                               `|`VM.VGPUs                              `|one-to-many    |
|`VGPU.resident_on                      `|`PGPU.resident_VGPUs                   `|one-to-many    |
|`PGPU.supported_VGPU_types             `|`VGPU_type.supported_on_PGPUs          `|many-to-many   |
|`PGPU.enabled_VGPU_types               `|`VGPU_type.enabled_on_PGPUs            `|many-to-many   |
|`GPU_group.supported_VGPU_types        `|`VGPU_type.supported_on_GPU_groups     `|many-to-many   |
|`GPU_group.enabled_VGPU_types          `|`VGPU_type.enabled_on_GPU_groups       `|many-to-many   |
|`PCI.host                              `|`host.PCIs                             `|one-to-many    |
|`PGPU.host                             `|`host.PGPUs                            `|one-to-many    |
|`VDI.metadata_of_pool                  `|`pool.metadata_VDIs                    `|one-to-many    |
|`SR.introduced_by                      `|`DR_task.introduced_SRs                `|one-to-many    |
|`PVS_server.site                       `|`PVS_site.servers                      `|one-to-many    |
|`PVS_proxy.site                        `|`PVS_site.proxies                      `|one-to-many    |
|`PVS_cache_storage.site                `|`PVS_site.cache_storage                `|one-to-many    |
|`PUSB.host                             `|`host.PUSBs                            `|one-to-many    |
|`PUSB.USB_group                        `|`USB_group.PUSBs                       `|one-to-many    |
|`VUSB.USB_group                        `|`USB_group.VUSBs                       `|one-to-many    |
|`VUSB.VM                               `|`VM.VUSBs                              `|one-to-many    |
|`Feature.host                          `|`host.features                         `|one-to-many    |
|`network_sriov.physical_PIF            `|`PIF.sriov_physical_PIF_of             `|one-to-many    |
|`network_sriov.logical_PIF             `|`PIF.sriov_logical_PIF_of              `|one-to-many    |
|`Certificate.host                      `|`host.certificates                     `|one-to-many    |

The following figure represents bound fields (as specified above) diagramatically, using crow's foot notation to specify one-to-one, one-to-many or many-to-many relationships:

![Class relationships](classes.png 'Class relationships')

## Types

### Primitives

The following primitive types are used to specify methods and fields in the API Reference:

|Type    |Description                                 |
|:-------|:-------------------------------------------|
|string  |text strings                                |
|int     |64-bit integers                             |
|float   |IEEE double-precision floating-point numbers|
|bool    |boolean                                     |
|datetime|date and timestamp                          |

### Higher-order types

The following type constructors are used:

|Type              |Description                                             |
|:-----------------|:-------------------------------------------------------|
|_c_ ref           |reference to an object of class _c_                     |
|_t_ set           |a set of elements of type _t_                           |
|(_a &#45;&gt; b_) map     |a table mapping values of type _a_ to values of type _b_|

### Enumeration types

The following enumeration types are used:

|`enum after_apply_guidance             `|                                        |
|:---------------------------------------|:---------------------------------------|
|`restartHost                           `|This patch requires the host to be restarted once applied.|
|`restartHVM                            `|This patch requires HVM guests to be restarted once applied.|
|`restartPV                             `|This patch requires PV guests to be restarted once applied.|
|`restartXAPI                           `|This patch requires XAPI to be restarted once applied.|

|`enum allocation_algorithm             `|                                        |
|:---------------------------------------|:---------------------------------------|
|`breadth_first                         `|vGPUs of a given type are allocated evenly across supporting pGPUs.|
|`depth_first                           `|vGPUs of a given type are allocated on supporting pGPUs until they are full.|

|`enum bond_mode                        `|                                        |
|:---------------------------------------|:---------------------------------------|
|`active-backup                         `|Active/passive bonding: only one NIC is carrying traffic|
|`balance-slb                           `|Source&#45;level balancing              |
|`lacp                                  `|Link aggregation control protocol       |

|`enum cls                              `|                                        |
|:---------------------------------------|:---------------------------------------|
|`Host                                  `|Host                                    |
|`Pool                                  `|Pool                                    |
|`PVS_proxy                             `|PVS&#95;proxy                           |
|`SR                                    `|SR                                      |
|`VDI                                   `|VDI                                     |
|`VM                                    `|VM                                      |
|`VMPP                                  `|VMPP                                    |
|`VMSS                                  `|VMSS                                    |

|`enum cluster_host_operation           `|                                        |
|:---------------------------------------|:---------------------------------------|
|`destroy                               `|completely destroying a cluster host    |
|`disable                               `|disabling cluster membership on a particular host|
|`enable                                `|enabling cluster membership on a particular host|

|`enum cluster_operation                `|                                        |
|:---------------------------------------|:---------------------------------------|
|`add                                   `|adding a new member to the cluster      |
|`destroy                               `|completely destroying a cluster         |
|`disable                               `|disabling any cluster member            |
|`enable                                `|enabling any cluster member             |
|`remove                                `|removing a member from the cluster      |

|`enum console_protocol                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`rdp                                   `|Remote Desktop Protocol                 |
|`rfb                                   `|Remote FrameBuffer protocol &#40;as used in VNC&#41;|
|`vt100                                 `|VT100 terminal                          |

|`enum domain_type                      `|                                        |
|:---------------------------------------|:---------------------------------------|
|`hvm                                   `|HVM; Fully Virtualised                  |
|`pv                                    `|PV: Paravirtualised                     |
|`pv_in_pvh                             `|PV inside a PVH container               |
|`unspecified                           `|Not specified or unknown domain type    |

|`enum event_operation                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`add                                   `|An object has been created              |
|`del                                   `|An object has been deleted              |
|`mod                                   `|An object has been modified             |

|`enum host_allowed_operations          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`evacuate                              `|Indicates this host is evacuating       |
|`power_on                              `|Indicates this host is in the process of being powered on|
|`provision                             `|Indicates this host is able to provision another VM|
|`reboot                                `|Indicates this host is in the process of rebooting|
|`shutdown                              `|Indicates this host is in the process of shutting itself down|
|`vm_migrate                            `|This host is the migration target of a VM|
|`vm_resume                             `|This host is resuming a VM              |
|`vm_start                              `|This host is starting a VM              |

|`enum host_display                     `|                                        |
|:---------------------------------------|:---------------------------------------|
|`disable_on_reboot                     `|The host will stop outputting its console to a physical display device on next boot|
|`disabled                              `|This host is not outputting its console to a physical display device|
|`enable_on_reboot                      `|The host will start outputting its console to a physical display device on next boot|
|`enabled                               `|This host is outputting its console to a physical display device|

|`enum host_sched_gran                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`core                                  `|core scheduling                         |
|`cpu                                   `|CPU scheduling                          |
|`socket                                `|socket scheduling                       |

|`enum ip_configuration_mode            `|                                        |
|:---------------------------------------|:---------------------------------------|
|`DHCP                                  `|Acquire an IP address by DHCP           |
|`None                                  `|Do not acquire an IP address            |
|`Static                                `|Static IP address configuration         |

|`enum ipv6_configuration_mode          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`Autoconf                              `|Router assigned prefix delegation IPv6 allocation|
|`DHCP                                  `|Acquire an IPv6 address by DHCP         |
|`None                                  `|Do not acquire an IPv6 address          |
|`Static                                `|Static IPv6 address configuration       |

|`enum livepatch_status                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`ok                                    `|There is no applicable live patch       |
|`ok_livepatch_complete                 `|An applicable live patch exists for every required component|
|`ok_livepatch_incomplete               `|An applicable live patch exists but it is not sufficient|

|`enum network_default_locking_mode     `|                                        |
|:---------------------------------------|:---------------------------------------|
|`disabled                              `|Treat all VIFs on this network with locking&#95;mode = 'default' as if they have locking&#95;mode = 'disabled'|
|`unlocked                              `|Treat all VIFs on this network with locking&#95;mode = 'default' as if they have locking&#95;mode = 'unlocked'|

|`enum network_operations               `|                                        |
|:---------------------------------------|:---------------------------------------|
|`attaching                             `|Indicates this network is attaching to a VIF or PIF|

|`enum network_purpose                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`insecure_nbd                          `|Network Block Device service without integrity or confidentiality: NOT RECOMMENDED|
|`nbd                                   `|Network Block Device service using TLS  |

|`enum on_boot                          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`persist                               `|Standard behaviour.                     |
|`reset                                 `|When a VM containing this VDI is started, the contents of the VDI are reset to the state they were in when this flag was last set.|

|`enum on_crash_behaviour               `|                                        |
|:---------------------------------------|:---------------------------------------|
|`coredump_and_destroy                  `|record a coredump and then destroy the VM state|
|`coredump_and_restart                  `|record a coredump and then restart the VM|
|`destroy                               `|destroy the VM state                    |
|`preserve                              `|leave the crashed VM paused             |
|`rename_restart                        `|rename the crashed VM and start a new copy|
|`restart                               `|restart the VM                          |

|`enum on_normal_exit                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`destroy                               `|destroy the VM state                    |
|`restart                               `|restart the VM                          |

|`enum pgpu_dom0_access                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`disable_on_reboot                     `|On host reboot dom0 will be blocked from accessing this device|
|`disabled                              `|dom0 cannot access this device          |
|`enable_on_reboot                      `|On host reboot dom0 will be allowed to access this device|
|`enabled                               `|dom0 can access this device as normal   |

|`enum pif_igmp_status                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`disabled                              `|IGMP Snooping is disabled in the corresponding backend bridge.'|
|`enabled                               `|IGMP Snooping is enabled in the corresponding backend bridge.'|
|`unknown                               `|IGMP snooping status is unknown. If this is a VLAN master, then please consult the underlying VLAN slave PIF.|

|`enum pool_allowed_operations          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`cluster_create                        `|Indicates this pool is in the process of creating a cluster|
|`designate_new_master                  `|Indicates this pool is in the process of changing master|
|`ha_disable                            `|Indicates this pool is in the process of disabling HA|
|`ha_enable                             `|Indicates this pool is in the process of enabling HA|

|`enum primary_address_type             `|                                        |
|:---------------------------------------|:---------------------------------------|
|`IPv4                                  `|Primary address is the IPv4 address     |
|`IPv6                                  `|Primary address is the IPv6 address     |

|`enum pvs_proxy_status                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`caching                               `|The proxy is currently caching data     |
|`incompatible_protocol_version         `|The PVS protocol in use is not compatible with the PVS proxy|
|`incompatible_write_cache_mode         `|The PVS device is configured to use an incompatible write&#45;cache mode|
|`initialised                           `|The proxy is setup but has not yet cached anything|
|`stopped                               `|The proxy is not currently running      |

|`enum sdn_controller_protocol          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`pssl                                  `|Passive ssl connection                  |
|`ssl                                   `|Active ssl connection                   |

|`enum sr_health                        `|                                        |
|:---------------------------------------|:---------------------------------------|
|`healthy                               `|Storage is fully available              |
|`recovering                            `|Storage is busy recovering, e.g. rebuilding mirrors.|

|`enum sriov_configuration_mode         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`modprobe                              `|Configure network sriov by modprobe, need reboot|
|`sysfs                                 `|Configure network sriov by sysfs, do not need reboot|
|`unknown                               `|Unknown mode                            |

|`enum storage_operations               `|                                        |
|:---------------------------------------|:---------------------------------------|
|`destroy                               `|Destroying the SR                       |
|`forget                                `|Forgetting about SR                     |
|`pbd_create                            `|Creating a PBD for this SR              |
|`pbd_destroy                           `|Destroying one of this SR's PBDs        |
|`plug                                  `|Plugging a PBD into this SR             |
|`scan                                  `|Scanning backends for new or deleted VDIs|
|`unplug                                `|Unplugging a PBD from this SR           |
|`update                                `|Refresh the fields on the SR            |
|`vdi_clone                             `|Cloneing a VDI                          |
|`vdi_create                            `|Creating a new VDI                      |
|`vdi_data_destroy                      `|Deleting the data of the VDI            |
|`vdi_destroy                           `|Destroying a VDI                        |
|`vdi_disable_cbt                       `|Disabling changed block tracking for a VDI|
|`vdi_enable_cbt                        `|Enabling changed block tracking for a VDI|
|`vdi_introduce                         `|Introducing a new VDI                   |
|`vdi_list_changed_blocks               `|Exporting a bitmap that shows the changed blocks between two VDIs|
|`vdi_mirror                            `|Mirroring a VDI                         |
|`vdi_resize                            `|Resizing a VDI                          |
|`vdi_set_on_boot                       `|Setting the on&#95;boot field of the VDI|
|`vdi_snapshot                          `|Snapshotting a VDI                      |

|`enum task_allowed_operations          `|                                        |
|:---------------------------------------|:---------------------------------------|
|`cancel                                `|refers to the operation "cancel"        |
|`destroy                               `|refers to the operation "destroy"       |

|`enum task_status_type                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`cancelled                             `|task has been cancelled                 |
|`cancelling                            `|task is being cancelled                 |
|`failure                               `|task has failed                         |
|`pending                               `|task is in progress                     |
|`success                               `|task was completed successfully         |

|`enum tristate_type                    `|                                        |
|:---------------------------------------|:---------------------------------------|
|`no                                    `|Known to be false                       |
|`unspecified                           `|Unknown or unspecified                  |
|`yes                                   `|Known to be true                        |

|`enum tunnel_protocol                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`gre                                   `|GRE protocol                            |
|`vxlan                                 `|VxLAN Protocol                          |

|`enum update_after_apply_guidance      `|                                        |
|:---------------------------------------|:---------------------------------------|
|`restartHost                           `|This update requires the host to be restarted once applied.|
|`restartHVM                            `|This update requires HVM guests to be restarted once applied.|
|`restartPV                             `|This update requires PV guests to be restarted once applied.|
|`restartXAPI                           `|This update requires XAPI to be restarted once applied.|

|`enum vbd_mode                         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`RO                                    `|only read&#45;only access will be allowed|
|`RW                                    `|read&#45;write access will be allowed   |

|`enum vbd_operations                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`attach                                `|Attempting to attach this VBD to a VM   |
|`eject                                 `|Attempting to eject the media from this VBD|
|`insert                                `|Attempting to insert new media into this VBD|
|`pause                                 `|Attempting to pause a block device backend|
|`plug                                  `|Attempting to hotplug this VBD          |
|`unpause                               `|Attempting to unpause a block device backend|
|`unplug                                `|Attempting to hot unplug this VBD       |
|`unplug_force                          `|Attempting to forcibly unplug this VBD  |

|`enum vbd_type                         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`CD                                    `|VBD will appear to guest as CD          |
|`Disk                                  `|VBD will appear to guest as disk        |
|`Floppy                                `|VBD will appear as a floppy             |

|`enum vdi_operations                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`blocked                               `|Operations on this VDI are temporarily blocked|
|`clone                                 `|Cloning the VDI                         |
|`copy                                  `|Copying the VDI                         |
|`data_destroy                          `|Deleting the data of the VDI            |
|`destroy                               `|Destroying the VDI                      |
|`disable_cbt                           `|Disabling changed block tracking for a VDI|
|`enable_cbt                            `|Enabling changed block tracking for a VDI|
|`force_unlock                          `|Forcibly unlocking the VDI              |
|`forget                                `|Forget about the VDI                    |
|`generate_config                       `|Generating static configuration         |
|`list_changed_blocks                   `|Exporting a bitmap that shows the changed blocks between two VDIs|
|`mirror                                `|Mirroring the VDI                       |
|`resize                                `|Resizing the VDI                        |
|`resize_online                         `|Resizing the VDI which may or may not be online|
|`set_on_boot                           `|Setting the on&#95;boot field of the VDI|
|`snapshot                              `|Snapshotting the VDI                    |
|`update                                `|Refreshing the fields of the VDI        |

|`enum vdi_type                         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`cbt_metadata                          `|Metadata about a snapshot VDI that has been deleted: the set of blocks that changed between some previous version of the disk and the version tracked by the snapshot.|
|`crashdump                             `|a disk that stores VM crashdump information|
|`ephemeral                             `|a disk that may be reformatted on upgrade|
|`ha_statefile                          `|a disk used for HA storage heartbeating |
|`metadata                              `|a disk used for HA Pool metadata        |
|`pvs_cache                             `|a disk that stores PVS cache data       |
|`redo_log                              `|a disk used for a general metadata redo&#45;log|
|`rrd                                   `|a disk that stores SR&#45;level RRDs    |
|`suspend                               `|a disk that stores a suspend image      |
|`system                                `|a disk that may be replaced on upgrade  |
|`user                                  `|a disk that is always preserved on upgrade|

|`enum vgpu_type_implementation         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`gvt_g                                 `|vGPU using Intel GVT&#45;g              |
|`mxgpu                                 `|vGPU using AMD MxGPU                    |
|`nvidia                                `|vGPU using NVIDIA hardware              |
|`nvidia_sriov                          `|vGPU using NVIDIA hardware with SR&#45;IOV|
|`passthrough                           `|Pass through an entire physical GPU to a guest|

|`enum vif_ipv4_configuration_mode      `|                                        |
|:---------------------------------------|:---------------------------------------|
|`None                                  `|Follow the default IPv4 configuration of the guest &#40;this is guest&#45;dependent&#41;|
|`Static                                `|Static IPv4 address configuration       |

|`enum vif_ipv6_configuration_mode      `|                                        |
|:---------------------------------------|:---------------------------------------|
|`None                                  `|Follow the default IPv6 configuration of the guest &#40;this is guest&#45;dependent&#41;|
|`Static                                `|Static IPv6 address configuration       |

|`enum vif_locking_mode                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`disabled                              `|No traffic is permitted                 |
|`locked                                `|Only traffic to a specific MAC and a list of IPv4 or IPv6 addresses is permitted|
|`network_default                       `|No specific configuration set &#45; default network policy applies|
|`unlocked                              `|All traffic is permitted                |

|`enum vif_operations                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`attach                                `|Attempting to attach this VIF to a VM   |
|`plug                                  `|Attempting to hotplug this VIF          |
|`unplug                                `|Attempting to hot unplug this VIF       |

|`enum vm_appliance_operation           `|                                        |
|:---------------------------------------|:---------------------------------------|
|`clean_shutdown                        `|Clean shutdown                          |
|`hard_shutdown                         `|Hard shutdown                           |
|`shutdown                              `|Shutdown                                |
|`start                                 `|Start                                   |

|`enum vm_operations                    `|                                        |
|:---------------------------------------|:---------------------------------------|
|`assert_operation_valid                `|                                        |
|`awaiting_memory_live                  `|Waiting for the memory settings to change|
|`call_plugin                           `|refers to the operation "call&#95;plugin"|
|`changing_dynamic_range                `|Changing the memory dynamic range       |
|`changing_memory_limits                `|Changing the memory limits              |
|`changing_memory_live                  `|Changing the memory settings            |
|`changing_NVRAM                        `|Changing NVRAM for a halted VM.         |
|`changing_shadow_memory                `|Changing the shadow memory for a halted VM.|
|`changing_shadow_memory_live           `|Changing the shadow memory for a running VM.|
|`changing_static_range                 `|Changing the memory static range        |
|`changing_VCPUs                        `|Changing VCPU settings for a halted VM. |
|`changing_VCPUs_live                   `|Changing VCPU settings for a running VM.|
|`checkpoint                            `|refers to the operation "checkpoint"    |
|`clean_reboot                          `|refers to the operation "clean&#95;reboot"|
|`clean_shutdown                        `|refers to the operation "clean&#95;shutdown"|
|`clone                                 `|refers to the operation "clone"         |
|`copy                                  `|refers to the operation "copy"          |
|`create_template                       `|refers to the operation "create&#95;template"|
|`csvm                                  `|refers to the operation "csvm"          |
|`data_source_op                        `|Add, remove, query or list data sources |
|`destroy                               `|refers to the act of uninstalling the VM|
|`export                                `|exporting a VM to a network stream      |
|`get_boot_record                       `|refers to the operation "get&#95;boot&#95;record"|
|`hard_reboot                           `|refers to the operation "hard&#95;reboot"|
|`hard_shutdown                         `|refers to the operation "hard&#95;shutdown"|
|`import                                `|importing a VM from a network stream    |
|`make_into_template                    `|Turning this VM into a template         |
|`metadata_export                       `|exporting VM metadata to a network stream|
|`migrate_send                          `|refers to the operation "migrate&#95;send"|
|`pause                                 `|refers to the operation "pause"         |
|`pool_migrate                          `|refers to the operation "pool&#95;migrate"|
|`power_state_reset                     `|refers to the operation "power&#95;state&#95;reset"|
|`provision                             `|refers to the operation "provision"     |
|`query_services                        `|refers to the operation "query&#95;services"|
|`resume                                `|refers to the operation "resume"        |
|`resume_on                             `|refers to the operation "resume&#95;on" |
|`revert                                `|refers to the operation "revert"        |
|`reverting                             `|Reverting the VM to a previous snapshotted state|
|`send_sysrq                            `|refers to the operation "send&#95;sysrq"|
|`send_trigger                          `|refers to the operation "send&#95;trigger"|
|`shutdown                              `|refers to the operation "shutdown"      |
|`snapshot                              `|refers to the operation "snapshot"      |
|`snapshot_with_quiesce                 `|refers to the operation "snapshot&#95;with&#95;quiesce"|
|`start                                 `|refers to the operation "start"         |
|`start_on                              `|refers to the operation "start&#95;on"  |
|`suspend                               `|refers to the operation "suspend"       |
|`unpause                               `|refers to the operation "unpause"       |
|`update_allowed_operations             `|                                        |

|`enum vm_power_state                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`Halted                                `|VM is offline and not using any resources|
|`Paused                                `|All resources have been allocated but the VM itself is paused and its vCPUs are not running|
|`Running                               `|Running                                 |
|`Suspended                             `|VM state has been saved to disk and it is nolonger running. Note that disks remain in&#45;use while the VM is suspended.|

|`enum vmpp_archive_frequency           `|                                        |
|:---------------------------------------|:---------------------------------------|
|`always_after_backup                   `|Archive after backup                    |
|`daily                                 `|Daily archives                          |
|`never                                 `|Never archive                           |
|`weekly                                `|Weekly backups                          |

|`enum vmpp_archive_target_type         `|                                        |
|:---------------------------------------|:---------------------------------------|
|`cifs                                  `|CIFS target config                      |
|`nfs                                   `|NFS target config                       |
|`none                                  `|No target config                        |

|`enum vmpp_backup_frequency            `|                                        |
|:---------------------------------------|:---------------------------------------|
|`daily                                 `|Daily backups                           |
|`hourly                                `|Hourly backups                          |
|`weekly                                `|Weekly backups                          |

|`enum vmpp_backup_type                 `|                                        |
|:---------------------------------------|:---------------------------------------|
|`checkpoint                            `|The backup is a checkpoint              |
|`snapshot                              `|The backup is a snapshot                |

|`enum vmss_frequency                   `|                                        |
|:---------------------------------------|:---------------------------------------|
|`daily                                 `|Daily snapshots                         |
|`hourly                                `|Hourly snapshots                        |
|`weekly                                `|Weekly snapshots                        |

|`enum vmss_type                        `|                                        |
|:---------------------------------------|:---------------------------------------|
|`checkpoint                            `|The snapshot is a checkpoint            |
|`snapshot                              `|The snapshot is a disk snapshot         |
|`snapshot_with_quiesce                 `|Support for VSS has been removed.       |

|`enum vusb_operations                  `|                                        |
|:---------------------------------------|:---------------------------------------|
|`attach                                `|Attempting to attach this VUSB to a VM  |
|`plug                                  `|Attempting to plug this VUSB into a VM  |
|`unplug                                `|Attempting to hot unplug this VUSB      |

## Class: auth

Management of remote authentication services

### Fields for class: auth

Class auth has no fields.

### RPCs associated with class: auth

#### RPC name: get&#95;group&#95;membership

_Overview:_

This calls queries the external directory service to obtain the transitively&#45;closed set of groups that the the subject&#95;identifier is member of.

_Signature:_

```
string set get_group_membership (session ref session_id, string subject_identifier)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|subject&#95;identifier        |A string containing the subject&#95;identifier, unique in the external directory service|

_Minimum Role:_ read-only

_Return Type:_ `string set`

set of subject&#95;identifiers that provides the group membership of subject&#95;identifier passed as argument, it contains, recursively, all groups a subject&#95;identifier is member of.

#### RPC name: get&#95;subject&#95;identifier

_Overview:_

This call queries the external directory service to obtain the subject&#95;identifier as a string from the human&#45;readable subject&#95;name

_Signature:_

```
string get_subject_identifier (session ref session_id, string subject_name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|subject&#95;name              |The human&#45;readable subject&#95;name, such as a username or a groupname|

_Minimum Role:_ read-only

_Return Type:_ `string`

the subject&#95;identifier obtained from the external directory service

#### RPC name: get&#95;subject&#95;information&#95;from&#95;identifier

_Overview:_

This call queries the external directory service to obtain the user information &#40;e.g. username, organization etc&#41; from the specified subject&#95;identifier

_Signature:_

```
(string -> string) map get_subject_information_from_identifier (session ref session_id, string subject_identifier)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|subject&#95;identifier        |A string containing the subject&#95;identifier, unique in the external directory service|

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

key&#45;value pairs containing at least a key called subject&#95;name

## Class: blob

A placeholder for a binary blob

### Fields for class: blob

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|last&#95;updated    |`datetime          `|_RO/constructor_|Time at which the data in the blob was last updated|
|mime&#95;type       |`string            `|_RO/constructor_|The mime type associated with this object. Defaults to 'application/octet&#45;stream' if the empty string is supplied|
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|public              |`bool              `|_RW_           |True if the blob is publicly accessible |
|size                |`int               `|_RO/runtime_   |Size of the binary data, in bytes       |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: blob

#### RPC name: create

_Overview:_

Create a placeholder for a binary blob

_Signature:_

```
blob ref create (session ref session_id, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|mime&#95;type                 |The mime&#45;type of the blob. Defaults to 'application/octet&#45;stream' if the empty string is supplied|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference to the created blob

#### RPC name: destroy

_Overview:_



_Signature:_

```
void destroy (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |The reference of the blob to destroy    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the blobs known to the system.

_Signature:_

```
blob ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `blob ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of blob references to blob records for all blobs known to the system.

_Signature:_

```
(blob ref -> blob record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(blob ref -> blob record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the blob instances with the given label.

_Signature:_

```
blob ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `blob ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the blob instance with the specified UUID.

_Signature:_

```
blob ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `blob ref`

reference to the object

#### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given blob.

_Signature:_

```
datetime get_last_updated (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;mime&#95;type

_Overview:_

Get the mime&#95;type field of the given blob.

_Signature:_

```
string get_mime_type (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given blob.

_Signature:_

```
string get_name_description (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given blob.

_Signature:_

```
string get_name_label (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;public

_Overview:_

Get the public field of the given blob.

_Signature:_

```
bool get_public (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given blob.

_Signature:_

```
blob record get_record (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `blob record`

all fields from the object

#### RPC name: get&#95;size

_Overview:_

Get the size field of the given blob.

_Signature:_

```
int get_size (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given blob.

_Signature:_

```
string get_uuid (session ref session_id, blob ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given blob.

_Signature:_

```
void set_name_description (session ref session_id, blob ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given blob.

_Signature:_

```
void set_name_label (session ref session_id, blob ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;public

_Overview:_

Set the public field of the given blob.

_Signature:_

```
void set_public (session ref session_id, blob ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`blob ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: Bond



### Fields for class: Bond

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|auto&#95;update&#95;mac|`bool              `|_RO/runtime_   |true if the MAC was taken from the primary slave when the bond was created, and false if the client specified the MAC|
|links&#95;up        |`int               `|_RO/runtime_   |Number of links up in this bond         |
|master              |`PIF ref           `|_RO/constructor_|The bonded interface                    |
|mode                |`bond_mode         `|_RO/runtime_   |The algorithm used to distribute traffic among the bonded NICs|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|primary&#95;slave   |`PIF ref           `|_RO/runtime_   |The PIF of which the IP configuration and MAC were copied to the bond, and which will receive all configuration/VLANs/VIFs on the bond if the bond is destroyed|
|properties          |`(string -> string) map`|_RO/runtime_   |Additional configuration properties specific to the bond mode.|
|slaves              |`PIF ref set       `|_RO/runtime_   |The interfaces which are part of this bond|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: Bond

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given Bond.

_Signature:_

```
void add_to_other_config (session ref session_id, Bond ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create an interface bond

_Signature:_

```
Bond ref create (session ref session_id, network ref network, PIF ref set members, string MAC, bond_mode mode, (string -> string) map properties)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|network                       |Network to add the bonded PIF to        |
|`PIF ref set                 `|members                       |PIFs to add to this bond                |
|`string                      `|MAC                           |The MAC address to use on the bond itself. If this parameter is the empty string then the bond will inherit its MAC address from the primary slave.|
|`bond_mode                   `|mode                          |Bonding mode to use for the new bond    |
|`(string -> string) map      `|properties                    |Additional configuration parameters specific to the bond mode|

_Minimum Role:_ pool-operator

_Return Type:_ `Bond ref`

The reference of the created Bond object

#### RPC name: destroy

_Overview:_

Destroy an interface bond

_Signature:_

```
void destroy (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |Bond to destroy                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the Bonds known to the system.

_Signature:_

```
Bond ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `Bond ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Bond references to Bond records for all Bonds known to the system.

_Signature:_

```
(Bond ref -> Bond record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(Bond ref -> Bond record) map`

records of all objects

#### RPC name: get&#95;auto&#95;update&#95;mac

_Overview:_

Get the auto&#95;update&#95;mac field of the given Bond.

_Signature:_

```
bool get_auto_update_mac (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Bond instance with the specified UUID.

_Signature:_

```
Bond ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref`

reference to the object

#### RPC name: get&#95;links&#95;up

_Overview:_

Get the links&#95;up field of the given Bond.

_Signature:_

```
int get_links_up (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;master

_Overview:_

Get the master field of the given Bond.

_Signature:_

```
PIF ref get_master (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;mode

_Overview:_

Get the mode field of the given Bond.

_Signature:_

```
bond_mode get_mode (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bond_mode`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Bond.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;primary&#95;slave

_Overview:_

Get the primary&#95;slave field of the given Bond.

_Signature:_

```
PIF ref get_primary_slave (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;properties

_Overview:_

Get the properties field of the given Bond.

_Signature:_

```
(string -> string) map get_properties (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Bond.

_Signature:_

```
Bond record get_record (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond record`

all fields from the object

#### RPC name: get&#95;slaves

_Overview:_

Get the slaves field of the given Bond.

_Signature:_

```
PIF ref set get_slaves (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Bond.

_Signature:_

```
string get_uuid (session ref session_id, Bond ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given Bond.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, Bond ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;mode

_Overview:_

Change the bond mode

_Signature:_

```
void set_mode (session ref session_id, Bond ref self, bond_mode value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |The bond                                |
|`bond_mode                   `|value                         |The new bond mode                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given Bond.

_Signature:_

```
void set_other_config (session ref session_id, Bond ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;property

_Overview:_

Set the value of a property of the bond

_Signature:_

```
void set_property (session ref session_id, Bond ref self, string name, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Bond ref                    `|self                          |The bond                                |
|`string                      `|name                          |The property name                       |
|`string                      `|value                         |The property value                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: Certificate

Description

### Fields for class: Certificate

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|fingerprint         |`string            `|_RO/constructor_|The certificate's fingerprint / hash    |
|host                |`host ref          `|_RO/constructor_|The host where the certificate is installed|
|not&#95;after       |`datetime          `|_RO/constructor_|Date before which the certificate is valid|
|not&#95;before      |`datetime          `|_RO/constructor_|Date after which the certificate is valid|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: Certificate

#### RPC name: get&#95;all

_Overview:_

Return a list of all the Certificates known to the system.

_Signature:_

```
Certificate ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Certificate references to Certificate records for all Certificates known to the system.

_Signature:_

```
(Certificate ref -> Certificate record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(Certificate ref -> Certificate record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Certificate instance with the specified UUID.

_Signature:_

```
Certificate ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref`

reference to the object

#### RPC name: get&#95;fingerprint

_Overview:_

Get the fingerprint field of the given Certificate.

_Signature:_

```
string get_fingerprint (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given Certificate.

_Signature:_

```
host ref get_host (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;not&#95;after

_Overview:_

Get the not&#95;after field of the given Certificate.

_Signature:_

```
datetime get_not_after (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;not&#95;before

_Overview:_

Get the not&#95;before field of the given Certificate.

_Signature:_

```
datetime get_not_before (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Certificate.

_Signature:_

```
Certificate record get_record (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Certificate record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Certificate.

_Signature:_

```
string get_uuid (session ref session_id, Certificate ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Certificate ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: Cluster

Cluster&#45;wide Cluster metadata

### Fields for class: Cluster

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`cluster_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|cluster&#95;config  |`(string -> string) map`|_RO/constructor_|Contains read&#45;only settings for the cluster, such as timeouts and other options. It can only be set at cluster create time|
|cluster&#95;hosts   |`Cluster_host ref set`|_RO/runtime_   |A list of the cluster&#95;host objects associated with the Cluster|
|cluster&#95;stack   |`string            `|_RO/constructor_|Simply the string 'corosync'. No other cluster stacks are currently supported|
|cluster&#95;token   |`string            `|_RO/constructor_|The secret key used by xapi&#45;clusterd when it talks to itself on other hosts|
|current&#95;operations|`(string -> cluster_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|pending&#95;forget  |`string set        `|_RO/runtime_   |Internal field used by Host.destroy to store the IP of cluster members marked as permanently dead but not yet removed|
|pool&#95;auto&#95;join|`bool              `|_RO/constructor_|True if automatically joining new pool members to the cluster. This will be `true` in the first release|
|token&#95;timeout   |`float             `|_RO/constructor_|The corosync token timeout in seconds   |
|token&#95;timeout&#95;coefficient|`float             `|_RO/constructor_|The corosync token timeout coefficient in seconds|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: Cluster

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given Cluster.

_Signature:_

```
void add_to_other_config (session ref session_id, Cluster ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Creates a Cluster object and one Cluster&#95;host object as its first member

_Signature:_

```
Cluster ref create (session ref session_id, PIF ref PIF, string cluster_stack, bool pool_auto_join, float token_timeout, float token_timeout_coefficient)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|PIF                           |The PIF to connect the cluster's first cluster&#95;host to|
|`string                      `|cluster&#95;stack             |simply the string 'corosync'. No other cluster stacks are currently supported|
|`bool                        `|pool&#95;auto&#95;join        |true if xapi is automatically joining new pool members to the cluster|
|`float                       `|token&#95;timeout             |Corosync token timeout in seconds       |
|`float                       `|token&#95;timeout&#95;coefficient|Corosync token timeout coefficient in seconds|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster ref`

the new Cluster

_Possible Error Codes:_ `INVALID_CLUSTER_STACK`, `INVALID_VALUE`, `PIF_ALLOWS_UNPLUG`, `REQUIRED_PIF_IS_UNPLUGGED`

#### RPC name: destroy

_Overview:_

Destroys a Cluster object and the one remaining Cluster&#95;host member

_Signature:_

```
void destroy (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |the Cluster to destroy                  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_DOES_NOT_HAVE_ONE_NODE`, `CLUSTER_STACK_IN_USE`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the Clusters known to the system.

_Signature:_

```
Cluster ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Cluster references to Cluster records for all Clusters known to the system.

_Signature:_

```
(Cluster ref -> Cluster record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(Cluster ref -> Cluster record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given Cluster.

_Signature:_

```
cluster_operation set get_allowed_operations (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `cluster_operation set`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Cluster instance with the specified UUID.

_Signature:_

```
Cluster ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref`

reference to the object

#### RPC name: get&#95;cluster&#95;config

_Overview:_

Get the cluster&#95;config field of the given Cluster.

_Signature:_

```
(string -> string) map get_cluster_config (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;cluster&#95;hosts

_Overview:_

Get the cluster&#95;hosts field of the given Cluster.

_Signature:_

```
Cluster_host ref set get_cluster_hosts (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref set`

value of the field

#### RPC name: get&#95;cluster&#95;stack

_Overview:_

Get the cluster&#95;stack field of the given Cluster.

_Signature:_

```
string get_cluster_stack (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;cluster&#95;token

_Overview:_

Get the cluster&#95;token field of the given Cluster.

_Signature:_

```
string get_cluster_token (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given Cluster.

_Signature:_

```
(string -> cluster_operation) map get_current_operations (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> cluster_operation) map`

value of the field

#### RPC name: get&#95;network

_Overview:_

Returns the network used by the cluster for inter&#45;host communication, i.e. the network shared by all cluster host PIFs

_Signature:_

```
network ref get_network (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |the Cluster with the network            |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

network of cluster

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Cluster.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;pending&#95;forget

_Overview:_

Get the pending&#95;forget field of the given Cluster.

_Signature:_

```
string set get_pending_forget (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;pool&#95;auto&#95;join

_Overview:_

Get the pool&#95;auto&#95;join field of the given Cluster.

_Signature:_

```
bool get_pool_auto_join (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Cluster.

_Signature:_

```
Cluster record get_record (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster record`

all fields from the object

#### RPC name: get&#95;token&#95;timeout

_Overview:_

Get the token&#95;timeout field of the given Cluster.

_Signature:_

```
float get_token_timeout (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;token&#95;timeout&#95;coefficient

_Overview:_

Get the token&#95;timeout&#95;coefficient field of the given Cluster.

_Signature:_

```
float get_token_timeout_coefficient (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Cluster.

_Signature:_

```
string get_uuid (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: pool&#95;create

_Overview:_

Attempt to create a Cluster from the entire pool

_Signature:_

```
Cluster ref pool_create (session ref session_id, network ref network, string cluster_stack, float token_timeout, float token_timeout_coefficient)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|network                       |the single network on which corosync carries out its inter&#45;host communications|
|`string                      `|cluster&#95;stack             |simply the string 'corosync'. No other cluster stacks are currently supported|
|`float                       `|token&#95;timeout             |Corosync token timeout in seconds       |
|`float                       `|token&#95;timeout&#95;coefficient|Corosync token timeout coefficient in seconds|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster ref`

the new Cluster

#### RPC name: pool&#95;destroy

_Overview:_

Attempt to destroy the Cluster&#95;host objects for all hosts in the pool and then destroy the Cluster.

_Signature:_

```
void pool_destroy (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |The cluster to destroy.                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`, `CLUSTERING_DISABLED`, `CLUSTER_HOST_IS_LAST`

#### RPC name: pool&#95;force&#95;destroy

_Overview:_

Attempt to force destroy the Cluster&#95;host objects, and then destroy the Cluster.

_Signature:_

```
void pool_force_destroy (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |The cluster to force destroy.           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_FORCE_DESTROY_FAILED`

#### RPC name: pool&#95;resync

_Overview:_

Resynchronise the cluster&#95;host objects across the pool. Creates them where they need creating and then plugs them

_Signature:_

```
void pool_resync (session ref session_id, Cluster ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |The cluster to resync                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given Cluster.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, Cluster ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given Cluster.

_Signature:_

```
void set_other_config (session ref session_id, Cluster ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: Cluster&#95;host

Cluster member metadata

### Fields for class: Cluster&#95;host

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`cluster_host_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|cluster             |`Cluster ref       `|_RO/constructor_|Reference to the Cluster object         |
|current&#95;operations|`(string -> cluster_host_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|enabled             |`bool              `|_RO/constructor_|Whether the cluster host believes that clustering should be enabled on this host|
|host                |`host ref          `|_RO/constructor_|Reference to the Host object            |
|joined              |`bool              `|_RO/constructor_|Whether the cluster host has joined the cluster|
|other&#95;config    |`(string -> string) map`|_RO/constructor_|Additional configuration                |
|PIF                 |`PIF ref           `|_RO/constructor_|Reference to the PIF object             |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: Cluster&#95;host

#### RPC name: create

_Overview:_

Add a new host to an existing cluster.

_Signature:_

```
Cluster_host ref create (session ref session_id, Cluster ref cluster, host ref host, PIF ref pif)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster ref                 `|cluster                       |Cluster to join                         |
|`host ref                    `|host                          |new cluster member                      |
|`PIF ref                     `|pif                           |Network interface to use for communication|

_Minimum Role:_ pool-operator

_Return Type:_ `Cluster_host ref`

the newly created cluster&#95;host object

_Possible Error Codes:_ `PIF_NOT_ATTACHED_TO_HOST`, `NO_CLUSTER_HOSTS_REACHABLE`

#### RPC name: destroy

_Overview:_

Remove a host from an existing cluster.

_Signature:_

```
void destroy (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |the cluster&#95;host to remove from the cluster|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`, `CLUSTERING_DISABLED`, `CLUSTER_HOST_IS_LAST`

#### RPC name: disable

_Overview:_

Disable cluster membership for an enabled cluster host.

_Signature:_

```
void disable (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |the cluster&#95;host to disable         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`

#### RPC name: enable

_Overview:_

Enable cluster membership for a disabled cluster host.

_Signature:_

```
void enable (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |the cluster&#95;host to enable          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_ALLOWS_UNPLUG`, `REQUIRED_PIF_IS_UNPLUGGED`

#### RPC name: force&#95;destroy

_Overview:_

Remove a host from an existing cluster forcefully.

_Signature:_

```
void force_destroy (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |the cluster&#95;host to remove from the cluster|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTER_STACK_IN_USE`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the Cluster&#95;hosts known to the system.

_Signature:_

```
Cluster_host ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Cluster&#95;host references to Cluster&#95;host records for all Cluster&#95;hosts known to the system.

_Signature:_

```
(Cluster_host ref -> Cluster_host record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(Cluster_host ref -> Cluster_host record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given Cluster&#95;host.

_Signature:_

```
cluster_host_operation set get_allowed_operations (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `cluster_host_operation set`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Cluster&#95;host instance with the specified UUID.

_Signature:_

```
Cluster_host ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host ref`

reference to the object

#### RPC name: get&#95;cluster

_Overview:_

Get the cluster field of the given Cluster&#95;host.

_Signature:_

```
Cluster ref get_cluster (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster ref`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given Cluster&#95;host.

_Signature:_

```
(string -> cluster_host_operation) map get_current_operations (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> cluster_host_operation) map`

value of the field

#### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given Cluster&#95;host.

_Signature:_

```
bool get_enabled (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given Cluster&#95;host.

_Signature:_

```
host ref get_host (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;joined

_Overview:_

Get the joined field of the given Cluster&#95;host.

_Signature:_

```
bool get_joined (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given Cluster&#95;host.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PIF

_Overview:_

Get the PIF field of the given Cluster&#95;host.

_Signature:_

```
PIF ref get_PIF (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Cluster&#95;host.

_Signature:_

```
Cluster_host record get_record (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Cluster_host record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Cluster&#95;host.

_Signature:_

```
string get_uuid (session ref session_id, Cluster_host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Cluster_host ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: console

A console

### Fields for class: console

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|location            |`string            `|_RO/runtime_   |URI for the console service             |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|protocol            |`console_protocol  `|_RO/runtime_   |the protocol used by this console       |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VM                  |`VM ref            `|_RO/runtime_   |VM to which this console is attached    |

### RPCs associated with class: console

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given console.

_Signature:_

```
void add_to_other_config (session ref session_id, console ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new console instance, and return its handle.

_Signature:_

```
console ref create (session ref session_id, console record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console record              `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `console ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified console instance.

_Signature:_

```
void destroy (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the consoles known to the system.

_Signature:_

```
console ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `console ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of console references to console records for all consoles known to the system.

_Signature:_

```
(console ref -> console record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(console ref -> console record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the console instance with the specified UUID.

_Signature:_

```
console ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `console ref`

reference to the object

#### RPC name: get&#95;location

_Overview:_

Get the location field of the given console.

_Signature:_

```
string get_location (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given console.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given console.

_Signature:_

```
console_protocol get_protocol (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `console_protocol`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given console.

_Signature:_

```
console record get_record (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `console record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given console.

_Signature:_

```
string get_uuid (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given console.

_Signature:_

```
VM ref get_VM (session ref session_id, console ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given console.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, console ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given console.

_Signature:_

```
void set_other_config (session ref session_id, console ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`console ref                 `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: crashdump

**This class is deprecated.**

A VM crashdump

### Fields for class: crashdump

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|other&#95;config    |`(string -> string) map`|_RW_           |**Deprecated**. additional configuration|
|uuid                |`string            `|_RO/runtime_   |**Deprecated**. Unique identifier/object reference|
|VDI                 |`VDI ref           `|_RO/constructor_|**Deprecated**. the virtual disk        |
|VM                  |`VM ref            `|_RO/constructor_|**Deprecated**. the virtual machine     |

### RPCs associated with class: crashdump

#### RPC name: add&#95;to&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given crashdump.

_Signature:_

```
void add_to_other_config (session ref session_id, crashdump ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: destroy

**This message is deprecated.**

_Overview:_

Destroy the specified crashdump

_Signature:_

```
void destroy (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |The crashdump to destroy                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

**This message is deprecated.**

_Overview:_

Return a list of all the crashdumps known to the system.

_Signature:_

```
crashdump ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `crashdump ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is deprecated.**

_Overview:_

Return a map of crashdump references to crashdump records for all crashdumps known to the system.

_Signature:_

```
(crashdump ref -> crashdump record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(crashdump ref -> crashdump record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

**This message is deprecated.**

_Overview:_

Get a reference to the crashdump instance with the specified UUID.

_Signature:_

```
crashdump ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `crashdump ref`

reference to the object

#### RPC name: get&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Get the other&#95;config field of the given crashdump.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

**This message is deprecated.**

_Overview:_

Get a record containing the current state of the given crashdump.

_Signature:_

```
crashdump record get_record (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `crashdump record`

all fields from the object

#### RPC name: get&#95;uuid

**This message is deprecated.**

_Overview:_

Get the uuid field of the given crashdump.

_Signature:_

```
string get_uuid (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VDI

**This message is deprecated.**

_Overview:_

Get the VDI field of the given crashdump.

_Signature:_

```
VDI ref get_VDI (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;VM

**This message is deprecated.**

_Overview:_

Get the VM field of the given crashdump.

_Signature:_

```
VM ref get_VM (session ref session_id, crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given crashdump.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, crashdump ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Set the other&#95;config field of the given crashdump.

_Signature:_

```
void set_other_config (session ref session_id, crashdump ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`crashdump ref               `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: data&#95;source

Data sources for logging in RRDs

### Fields for class: data&#95;source

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|enabled             |`bool              `|_RO/runtime_   |true if the data source is being logged |
|max                 |`float             `|_RO/runtime_   |the maximum value of the data source    |
|min                 |`float             `|_RO/runtime_   |the minimum value of the data source    |
|name&#95;description|`string            `|_RO/runtime_   |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/runtime_   |a human&#45;readable name               |
|standard            |`bool              `|_RO/runtime_   |true if the data source is enabled by default. Non&#45;default data sources cannot be disabled|
|units               |`string            `|_RO/runtime_   |the units of the value                  |
|value               |`float             `|_RO/runtime_   |current value of the data source        |

### RPCs associated with class: data&#95;source

Class data&#95;source has no additional RPCs associated with it.

## Class: DR&#95;task

DR task

### Fields for class: DR&#95;task

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|introduced&#95;SRs  |`SR ref set        `|_RO/runtime_   |All SRs introduced by this appliance    |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: DR&#95;task

#### RPC name: create

_Overview:_

Create a disaster recovery task which will query the supplied list of devices

_Signature:_

```
DR_task ref create (session ref session_id, string type, (string -> string) map device_config, string set whitelist)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|type                          |The SR driver type of the SRs to introduce|
|`(string -> string) map      `|device&#95;config             |The device configuration of the SRs to introduce|
|`string set                  `|whitelist                     |The devices to use for disaster recovery|

_Minimum Role:_ pool-operator

_Return Type:_ `DR_task ref`

The reference to the created task

#### RPC name: destroy

_Overview:_

Destroy the disaster recovery task, detaching and forgetting any SRs introduced which are no longer required

_Signature:_

```
void destroy (session ref session_id, DR_task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`DR_task ref                 `|self                          |The disaster recovery task to destroy   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the DR&#95;tasks known to the system.

_Signature:_

```
DR_task ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of DR&#95;task references to DR&#95;task records for all DR&#95;tasks known to the system.

_Signature:_

```
(DR_task ref -> DR_task record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(DR_task ref -> DR_task record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the DR&#95;task instance with the specified UUID.

_Signature:_

```
DR_task ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref`

reference to the object

#### RPC name: get&#95;introduced&#95;SRs

_Overview:_

Get the introduced&#95;SRs field of the given DR&#95;task.

_Signature:_

```
SR ref set get_introduced_SRs (session ref session_id, DR_task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`DR_task ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given DR&#95;task.

_Signature:_

```
DR_task record get_record (session ref session_id, DR_task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`DR_task ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `DR_task record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given DR&#95;task.

_Signature:_

```
string get_uuid (session ref session_id, DR_task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`DR_task ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: event

Asynchronous event registration and handling

### Fields for class: event

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|class               |`string            `|_RO/constructor_|The name of the class of the object that changed|
|id                  |`int               `|_RO/constructor_|An ID, monotonically increasing, and local to the current session|
|obj&#95;uuid        |`string            `|_RO/constructor_|**Deprecated**. The uuid of the object that changed|
|operation           |`event_operation   `|_RO/constructor_|The operation that was performed        |
|ref                 |`string            `|_RO/constructor_|A reference to the object that changed  |
|timestamp           |`datetime          `|_RO/constructor_|**Deprecated**. The time at which the event occurred|
|snapshot            |`<object record>   `|_RO/runtime_   |The record of the database object that was added, changed or deleted|

### RPCs associated with class: event

#### RPC name: from

_Overview:_

Blocking call which returns a new token and a &#40;possibly empty&#41; batch of events. The returned token can be used in subsequent calls to this function.

_Signature:_

```
<event batch> from (session ref session_id, string set classes, string token, float timeout)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string set                  `|classes                       |register for events for the indicated classes|
|`string                      `|token                         |A token representing the point from which to generate database events. The empty string represents the beginning.|
|`float                       `|timeout                       |Return after this many seconds if no events match|

_Minimum Role:_ read-only

_Return Type:_ an event batch

a structure consisting of a token &#40;'token'&#41;, a map of valid references per object type &#40;'valid&#95;ref&#95;counts'&#41;, and a set of event records &#40;'events'&#41;.

_Possible Error Codes:_ `SESSION_NOT_REGISTERED`, `EVENTS_LOST`

#### RPC name: get&#95;current&#95;id

_Overview:_

Return the ID of the next event to be generated by the system

_Signature:_

```
int get_current_id (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `int`

the event ID

#### RPC name: inject

_Overview:_

Injects an artificial event on the given object and returns the corresponding ID in the form of a token, which can be used as a point of reference for database events. For example, to check whether an object has reached the right state before attempting an operation, one can inject an artificial event on the object and wait until the token returned by consecutive event.from calls is lexicographically greater than the one returned by event.inject.

_Signature:_

```
string inject (session ref session_id, string class, string ref)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|class                         |class of the object                     |
|`string                      `|ref                           |A reference to the object that will be changed.|

_Minimum Role:_ read-only

_Return Type:_ `string`

the event ID in the form of a token

#### RPC name: next

**This message is deprecated.**

_Overview:_

Blocking call which returns a &#40;possibly empty&#41; batch of events. This method is only recommended for legacy use. New development should use event.from which supercedes this method.

_Signature:_

```
event record set next (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `event record set`

A set of events

_Possible Error Codes:_ `SESSION_NOT_REGISTERED`, `EVENTS_LOST`

#### RPC name: register

**This message is deprecated.**

_Overview:_

Registers this session with the event system for a set of given classes. This method is only recommended for legacy use in conjunction with event.next.

_Signature:_

```
void register (session ref session_id, string set classes)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string set                  `|classes                       |the classes for which the session will register with the event system; specifying &#42; as the desired class will register for all classes|

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: unregister

**This message is deprecated.**

_Overview:_

Removes this session's registration with the event system for a set of given classes. This method is only recommended for legacy use in conjunction with event.next.

_Signature:_

```
void unregister (session ref session_id, string set classes)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string set                  `|classes                       |the classes for which the session's registration with the event system will be removed|

_Minimum Role:_ read-only

_Return Type:_ `void`

## Class: Feature

A new piece of functionality

### Fields for class: Feature

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|enabled             |`bool              `|_RO/runtime_   |Indicates whether the feature is enabled|
|experimental        |`bool              `|_RO/constructor_|Indicates whether the feature is experimental &#40;as opposed to stable and fully supported&#41;|
|host                |`host ref          `|_RO/runtime_   |The host where this feature is available|
|name&#95;description|`string            `|_RO/constructor_|a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|a human&#45;readable name               |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|version             |`string            `|_RO/constructor_|The version of this feature             |

### RPCs associated with class: Feature

#### RPC name: get&#95;all

_Overview:_

Return a list of all the Features known to the system.

_Signature:_

```
Feature ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of Feature references to Feature records for all Features known to the system.

_Signature:_

```
(Feature ref -> Feature record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(Feature ref -> Feature record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the Feature instances with the given label.

_Signature:_

```
Feature ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the Feature instance with the specified UUID.

_Signature:_

```
Feature ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref`

reference to the object

#### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given Feature.

_Signature:_

```
bool get_enabled (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;experimental

_Overview:_

Get the experimental field of the given Feature.

_Signature:_

```
bool get_experimental (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given Feature.

_Signature:_

```
host ref get_host (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given Feature.

_Signature:_

```
string get_name_description (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given Feature.

_Signature:_

```
string get_name_label (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given Feature.

_Signature:_

```
Feature record get_record (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Feature record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given Feature.

_Signature:_

```
string get_uuid (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;version

_Overview:_

Get the version field of the given Feature.

_Signature:_

```
string get_version (session ref session_id, Feature ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`Feature ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: GPU&#95;group

A group of compatible GPUs across the resource pool

### Fields for class: GPU&#95;group

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allocation&#95;algorithm|`allocation_algorithm`|_RW_           |Current allocation of vGPUs to pGPUs for this group|
|enabled&#95;VGPU&#95;types|`VGPU_type ref set `|_RO/runtime_   |vGPU types supported on at least one of the pGPUs in this group|
|GPU&#95;types       |`string set        `|_RO/runtime_   |List of GPU types &#40;vendor&#43;device ID&#41; that can be in this group|
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|PGPUs               |`PGPU ref set      `|_RO/runtime_   |List of pGPUs in the group              |
|supported&#95;VGPU&#95;types|`VGPU_type ref set `|_RO/runtime_   |vGPU types supported on at least one of the pGPUs in this group|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VGPUs               |`VGPU ref set      `|_RO/runtime_   |List of vGPUs using the group           |

### RPCs associated with class: GPU&#95;group

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
void add_to_other_config (session ref session_id, GPU_group ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_



_Signature:_

```
GPU_group ref create (session ref session_id, string name_label, string name_description, (string -> string) map other_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name&#95;label                |                                        |
|`string                      `|name&#95;description          |                                        |
|`(string -> string) map      `|other&#95;config              |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `GPU_group ref`

#### RPC name: destroy

_Overview:_



_Signature:_

```
void destroy (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |The GPU group to destroy                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the GPU&#95;groups known to the system.

_Signature:_

```
GPU_group ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of GPU&#95;group references to GPU&#95;group records for all GPU&#95;groups known to the system.

_Signature:_

```
(GPU_group ref -> GPU_group record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(GPU_group ref -> GPU_group record) map`

records of all objects

#### RPC name: get&#95;allocation&#95;algorithm

_Overview:_

Get the allocation&#95;algorithm field of the given GPU&#95;group.

_Signature:_

```
allocation_algorithm get_allocation_algorithm (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `allocation_algorithm`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the GPU&#95;group instances with the given label.

_Signature:_

```
GPU_group ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the GPU&#95;group instance with the specified UUID.

_Signature:_

```
GPU_group ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

reference to the object

#### RPC name: get&#95;enabled&#95;VGPU&#95;types

_Overview:_

Get the enabled&#95;VGPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
VGPU_type ref set get_enabled_VGPU_types (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

#### RPC name: get&#95;GPU&#95;types

_Overview:_

Get the GPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
string set get_GPU_types (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given GPU&#95;group.

_Signature:_

```
string get_name_description (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given GPU&#95;group.

_Signature:_

```
string get_name_label (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PGPUs

_Overview:_

Get the PGPUs field of the given GPU&#95;group.

_Signature:_

```
PGPU ref set get_PGPUs (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given GPU&#95;group.

_Signature:_

```
GPU_group record get_record (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group record`

all fields from the object

#### RPC name: get&#95;remaining&#95;capacity

_Overview:_



_Signature:_

```
int get_remaining_capacity (session ref session_id, GPU_group ref self, VGPU_type ref vgpu_type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |The GPU group to query                  |
|`VGPU_type ref               `|vgpu&#95;type                 |The VGPU&#95;type for which the remaining capacity will be calculated|

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of VGPUs of the given type which can still be started on the PGPUs in the group

#### RPC name: get&#95;supported&#95;VGPU&#95;types

_Overview:_

Get the supported&#95;VGPU&#95;types field of the given GPU&#95;group.

_Signature:_

```
VGPU_type ref set get_supported_VGPU_types (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given GPU&#95;group.

_Signature:_

```
string get_uuid (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VGPUs

_Overview:_

Get the VGPUs field of the given GPU&#95;group.

_Signature:_

```
VGPU ref set get_VGPUs (session ref session_id, GPU_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given GPU&#95;group.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, GPU_group ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;allocation&#95;algorithm

_Overview:_

Set the allocation&#95;algorithm field of the given GPU&#95;group.

_Signature:_

```
void set_allocation_algorithm (session ref session_id, GPU_group ref self, allocation_algorithm value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`allocation_algorithm        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given GPU&#95;group.

_Signature:_

```
void set_name_description (session ref session_id, GPU_group ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given GPU&#95;group.

_Signature:_

```
void set_name_label (session ref session_id, GPU_group ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given GPU&#95;group.

_Signature:_

```
void set_other_config (session ref session_id, GPU_group ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`GPU_group ref               `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: host

A physical host

### Fields for class: host

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|address             |`string            `|_RW_           |The address by which this host can be contacted from any other host in the pool|
|allowed&#95;operations|`host_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|API&#95;version&#95;major|`int               `|_RO/runtime_   |major version number                    |
|API&#95;version&#95;minor|`int               `|_RO/runtime_   |minor version number                    |
|API&#95;version&#95;vendor|`string            `|_RO/runtime_   |identification of vendor                |
|API&#95;version&#95;vendor&#95;implementation|`(string -> string) map`|_RO/runtime_   |details of vendor implementation        |
|bios&#95;strings    |`(string -> string) map`|_RO/runtime_   |BIOS strings                            |
|blobs               |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this host  |
|capabilities        |`string set        `|_RO/constructor_|Xen capabilities                        |
|certificates        |`Certificate ref set`|_RO/runtime_   |List of certificates installed in the host|
|chipset&#95;info    |`(string -> string) map`|_RO/runtime_   |Information about chipset features      |
|control&#95;domain  |`VM ref            `|_RO/runtime_   |The control domain &#40;domain 0&#41;   |
|cpu&#95;configuration|`(string -> string) map`|_RO/runtime_   |The CPU configuration on this host.  May contain keys such as "nr&#95;nodes", "sockets&#95;per&#95;node", "cores&#95;per&#95;socket", or "threads&#95;per&#95;core"|
|cpu&#95;info        |`(string -> string) map`|_RO/runtime_   |Details about the physical CPUs on this host|
|crash&#95;dump&#95;sr|`SR ref            `|_RW_           |The SR in which VDIs for crash dumps are created|
|crashdumps          |`host_crashdump ref set`|_RO/runtime_   |Set of host crash dumps                 |
|current&#95;operations|`(string -> host_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|display             |`host_display      `|_RW_           |indicates whether the host is configured to output its console to a physical display device|
|edition             |`string            `|_RO/runtime_   |Product edition                         |
|editions            |`string set        `|_RO/runtime_   |List of all available product editions  |
|enabled             |`bool              `|_RO/runtime_   |True if the host is currently enabled   |
|external&#95;auth&#95;configuration|`(string -> string) map`|_RO/runtime_   |configuration specific to external authentication service|
|external&#95;auth&#95;service&#95;name|`string            `|_RO/runtime_   |name of external authentication service configured; empty if none configured.|
|external&#95;auth&#95;type|`string            `|_RO/runtime_   |type of external authentication service configured; empty if none configured.|
|features            |`Feature ref set   `|_RO/runtime_   |List of features available on this host |
|guest&#95;VCPUs&#95;params|`(string -> string) map`|_RW_           |VCPUs params to apply to all resident guests|
|ha&#95;network&#95;peers|`string set        `|_RO/runtime_   |The set of hosts visible via the network from this host|
|ha&#95;statefiles   |`string set        `|_RO/runtime_   |The set of statefiles accessible from this host|
|host&#95;CPUs       |`host_cpu ref set  `|_RO/runtime_   |The physical CPUs on this host          |
|hostname            |`string            `|_RW_           |The hostname of this host               |
|iscsi&#95;iqn       |`string            `|_RO/constructor_|The initiator IQN for the host          |
|license&#95;params  |`(string -> string) map`|_RO/runtime_   |State of the current license            |
|license&#95;server  |`(string -> string) map`|_RW_           |Contact information of the license server|
|local&#95;cache&#95;sr|`SR ref            `|_RO/constructor_|The SR that is used as a local cache    |
|logging             |`(string -> string) map`|_RW_           |logging configuration                   |
|memory&#95;overhead |`int               `|_RO/runtime_   |Virtualization memory overhead &#40;bytes&#41;.|
|metrics             |`host_metrics ref  `|_RO/runtime_   |metrics associated with this host       |
|multipathing        |`bool              `|_RO/constructor_|Specifies whether multipathing is enabled|
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|patches             |`host_patch ref set`|_RO/runtime_   |**Deprecated**. Set of host patches     |
|PBDs                |`PBD ref set       `|_RO/runtime_   |physical blockdevices                   |
|PCIs                |`PCI ref set       `|_RO/runtime_   |List of PCI devices in the host         |
|PGPUs               |`PGPU ref set      `|_RO/runtime_   |List of physical GPUs in the host       |
|PIFs                |`PIF ref set       `|_RO/runtime_   |physical network interfaces             |
|power&#95;on&#95;config|`(string -> string) map`|_RO/runtime_   |The power on config                     |
|power&#95;on&#95;mode|`string            `|_RO/runtime_   |The power on mode                       |
|PUSBs               |`PUSB ref set      `|_RO/runtime_   |List of physical USBs in the host       |
|resident&#95;VMs    |`VM ref set        `|_RO/runtime_   |list of VMs currently resident on host  |
|sched&#95;policy    |`string            `|_RO/runtime_   |Scheduler policy currently in force on this host|
|software&#95;version|`(string -> string) map`|_RO/constructor_|version strings                         |
|ssl&#95;legacy      |`bool              `|_RO/constructor_|**Deprecated**. Allow SSLv3 protocol and ciphersuites as used by older server versions. This controls both incoming and outgoing connections. When this is set to a different value, the host immediately restarts its SSL/TLS listening service; typically this takes less than a second but existing connections to it will be broken. API login sessions will remain valid.|
|supported&#95;bootloaders|`string set        `|_RO/runtime_   |a list of the bootloaders installed on the machine|
|suspend&#95;image&#95;sr|`SR ref            `|_RW_           |The SR in which VDIs for suspend images are created|
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|uefi&#95;certificates|`string            `|_RO/constructor_|The UEFI certificates allowing Secure Boot|
|updates             |`pool_update ref set`|_RO/runtime_   |Set of updates                          |
|updates&#95;requiring&#95;reboot|`pool_update ref set`|_RO/runtime_   |List of updates which require reboot    |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|virtual&#95;hardware&#95;platform&#95;versions|`int set           `|_RO/runtime_   |The set of versions of the virtual hardware platform that the host can offer to its guests|

### RPCs associated with class: host

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given host.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;guest&#95;VCPUs&#95;params

_Overview:_

Add the given key&#45;value pair to the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
void add_to_guest_VCPUs_params (session ref session_id, host ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;license&#95;server

_Overview:_

Add the given key&#45;value pair to the license&#95;server field of the given host.

_Signature:_

```
void add_to_license_server (session ref session_id, host ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;logging

_Overview:_

Add the given key&#45;value pair to the logging field of the given host.

_Signature:_

```
void add_to_logging (session ref session_id, host ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host.

_Signature:_

```
void add_to_other_config (session ref session_id, host ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: apply&#95;edition

_Overview:_

Change to another edition, or reactivate the current edition after a license has expired. This may be subject to the successful checkout of an appropriate license.

_Signature:_

```
void apply_edition (session ref session_id, host ref host, string edition, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|edition                       |The requested edition                   |
|`bool                        `|force                         |Update the license params even if the apply call fails|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: assert&#95;can&#95;evacuate

_Overview:_

Check this host can be evacuated.

_Signature:_

```
void assert_can_evacuate (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to evacuate                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: backup&#95;rrds

_Overview:_

This causes the RRDs to be backed up to the master

_Signature:_

```
void backup_rrds (session ref session_id, host ref host, float delay)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |Schedule a backup of the RRDs of this host|
|`float                       `|delay                         |Delay in seconds from when the call is received to perform the backup|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: bugreport&#95;upload

_Overview:_

Run xen&#45;bugtool &#45;&#45;yestoall and upload the output to support

_Signature:_

```
void bugreport_upload (session ref session_id, host ref host, string url, (string -> string) map options)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host on which to run xen&#45;bugtool|
|`string                      `|url                           |The URL to upload to                    |
|`(string -> string) map      `|options                       |Extra configuration operations          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: call&#95;extension

_Overview:_

Call an API extension on this host

_Signature:_

```
string call_extension (session ref session_id, host ref host, string call)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|call                          |Rpc call for the extension              |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Result from the extension

#### RPC name: call&#95;plugin

_Overview:_

Call an API plugin on this host

_Signature:_

```
string call_plugin (session ref session_id, host ref host, string plugin, string fn, (string -> string) map args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|plugin                        |The name of the plugin                  |
|`string                      `|fn                            |The name of the function within the plugin|
|`(string -> string) map      `|args                          |Arguments for the function              |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Result from the plugin

#### RPC name: compute&#95;free&#95;memory

_Overview:_

Computes the amount of free memory on the host.

_Signature:_

```
int compute_free_memory (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to send the request to         |

_Minimum Role:_ read-only

_Return Type:_ `int`

the amount of free memory on the host.

#### RPC name: compute&#95;memory&#95;overhead

_Overview:_

Computes the virtualization memory overhead of a host.

_Signature:_

```
int compute_memory_overhead (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host for which to compute the memory overhead|

_Minimum Role:_ read-only

_Return Type:_ `int`

the virtualization memory overhead of the host.

#### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this host

_Signature:_

```
blob ref create_new_blob (session ref session_id, host ref host, string name, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|name                          |The name associated with the blob       |
|`string                      `|mime&#95;type                 |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

#### RPC name: declare&#95;dead

_Overview:_

Declare that a host is dead. This is a dangerous operation, and should only be called if the administrator is absolutely sure the host is definitely dead

_Signature:_

```
void declare_dead (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to declare is dead             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: destroy

_Overview:_

Destroy specified host record in database

_Signature:_

```
void destroy (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host record to remove               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable

_Overview:_

Puts the host into a state in which no new VMs can be started. Currently active VMs on the host continue to execute.

_Signature:_

```
void disable (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to disable                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;display

_Overview:_

Disable console output to the physical display device next time this host boots

_Signature:_

```
host_display disable_display (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `host_display`

This host's physical display usage

#### RPC name: disable&#95;external&#95;auth

_Overview:_

This call disables external authentication on the local host

_Signature:_

```
void disable_external_auth (session ref session_id, host ref host, (string -> string) map config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host whose external authentication should be disabled|
|`(string -> string) map      `|config                        |Optional parameters as a list of key&#45;values containing the configuration data|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: disable&#95;local&#95;storage&#95;caching

_Overview:_

Disable the use of a local SR for caching purposes

_Signature:_

```
void disable_local_storage_caching (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: dmesg

_Overview:_

Get the host xen dmesg.

_Signature:_

```
string dmesg (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to query                       |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

dmesg string

#### RPC name: dmesg&#95;clear

_Overview:_

Get the host xen dmesg, and clear the buffer.

_Signature:_

```
string dmesg_clear (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to query                       |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

dmesg string

#### RPC name: emergency&#95;ha&#95;disable

_Overview:_

This call disables HA on the local host. This should only be used with extreme care.

_Signature:_

```
void emergency_ha_disable (session ref session_id, bool soft)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`bool                        `|soft                          |Disable HA temporarily, revert upon host reboot or further changes, idempotent|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: emergency&#95;reset&#95;server&#95;certificate

_Overview:_

Delete the current TLS server certificate and replace by a new, self&#45;signed one. This should only be used with extreme care.

_Signature:_

```
void emergency_reset_server_certificate (session ref session_id)
```

_Return Type:_ `void`

#### RPC name: enable

_Overview:_

Puts the host into a state in which new VMs can be started.

_Signature:_

```
void enable (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to enable                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;display

_Overview:_

Enable console output to the physical display device next time this host boots

_Signature:_

```
host_display enable_display (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `host_display`

This host's physical display usage

#### RPC name: enable&#95;external&#95;auth

_Overview:_

This call enables external authentication on a host

_Signature:_

```
void enable_external_auth (session ref session_id, host ref host, (string -> string) map config, string service_name, string auth_type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host whose external authentication should be enabled|
|`(string -> string) map      `|config                        |A list of key&#45;values containing the configuration data|
|`string                      `|service&#95;name              |The name of the service                 |
|`string                      `|auth&#95;type                 |The type of authentication &#40;e.g. AD for Active Directory&#41;|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: enable&#95;local&#95;storage&#95;caching

_Overview:_

Enable the use of a local SR for caching purposes

_Signature:_

```
void enable_local_storage_caching (session ref session_id, host ref host, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`SR ref                      `|sr                            |The SR to use as a local cache          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: evacuate

_Overview:_

Migrate all VMs off of this host, where possible.

_Signature:_

```
void evacuate (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to evacuate                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: forget&#95;data&#95;source&#95;archives

_Overview:_

Forget the recorded statistics related to the specified data source

_Signature:_

```
void forget_data_source_archives (session ref session_id, host ref host, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|data&#95;source               |The data source whose archives are to be forgotten|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;address

_Overview:_

Get the address field of the given host.

_Signature:_

```
string get_address (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the hosts known to the system.

_Signature:_

```
host ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host references to host records for all hosts known to the system.

_Signature:_

```
(host ref -> host record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(host ref -> host record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given host.

_Signature:_

```
host_allowed_operations set get_allowed_operations (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_allowed_operations set`

value of the field

#### RPC name: get&#95;API&#95;version&#95;major

_Overview:_

Get the API&#95;version/major field of the given host.

_Signature:_

```
int get_API_version_major (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;API&#95;version&#95;minor

_Overview:_

Get the API&#95;version/minor field of the given host.

_Signature:_

```
int get_API_version_minor (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;API&#95;version&#95;vendor

_Overview:_

Get the API&#95;version/vendor field of the given host.

_Signature:_

```
string get_API_version_vendor (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;API&#95;version&#95;vendor&#95;implementation

_Overview:_

Get the API&#95;version/vendor&#95;implementation field of the given host.

_Signature:_

```
(string -> string) map get_API_version_vendor_implementation (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;bios&#95;strings

_Overview:_

Get the bios&#95;strings field of the given host.

_Signature:_

```
(string -> string) map get_bios_strings (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given host.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the host instances with the given label.

_Signature:_

```
host ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host instance with the specified UUID.

_Signature:_

```
host ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

reference to the object

#### RPC name: get&#95;capabilities

_Overview:_

Get the capabilities field of the given host.

_Signature:_

```
string set get_capabilities (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;certificates

_Overview:_

Get the certificates field of the given host.

_Signature:_

```
Certificate ref set get_certificates (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Certificate ref set`

value of the field

#### RPC name: get&#95;chipset&#95;info

_Overview:_

Get the chipset&#95;info field of the given host.

_Signature:_

```
(string -> string) map get_chipset_info (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;control&#95;domain

_Overview:_

Get the control&#95;domain field of the given host.

_Signature:_

```
VM ref get_control_domain (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: get&#95;cpu&#95;configuration

_Overview:_

Get the cpu&#95;configuration field of the given host.

_Signature:_

```
(string -> string) map get_cpu_configuration (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;cpu&#95;info

_Overview:_

Get the cpu&#95;info field of the given host.

_Signature:_

```
(string -> string) map get_cpu_info (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;crash&#95;dump&#95;sr

_Overview:_

Get the crash&#95;dump&#95;sr field of the given host.

_Signature:_

```
SR ref get_crash_dump_sr (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;crashdumps

_Overview:_

Get the crashdumps field of the given host.

_Signature:_

```
host_crashdump ref set get_crashdumps (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref set`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given host.

_Signature:_

```
(string -> host_allowed_operations) map get_current_operations (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> host_allowed_operations) map`

value of the field

#### RPC name: get&#95;data&#95;sources

_Overview:_



_Signature:_

```
data_source record set get_data_sources (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to interrogate                 |

_Minimum Role:_ read-only

_Return Type:_ `data_source record set`

A set of data sources

#### RPC name: get&#95;display

_Overview:_

Get the display field of the given host.

_Signature:_

```
host_display get_display (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_display`

value of the field

#### RPC name: get&#95;edition

_Overview:_

Get the edition field of the given host.

_Signature:_

```
string get_edition (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;editions

_Overview:_

Get the editions field of the given host.

_Signature:_

```
string set get_editions (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given host.

_Signature:_

```
bool get_enabled (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;external&#95;auth&#95;configuration

_Overview:_

Get the external&#95;auth&#95;configuration field of the given host.

_Signature:_

```
(string -> string) map get_external_auth_configuration (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;external&#95;auth&#95;service&#95;name

_Overview:_

Get the external&#95;auth&#95;service&#95;name field of the given host.

_Signature:_

```
string get_external_auth_service_name (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;external&#95;auth&#95;type

_Overview:_

Get the external&#95;auth&#95;type field of the given host.

_Signature:_

```
string get_external_auth_type (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;features

_Overview:_

Get the features field of the given host.

_Signature:_

```
Feature ref set get_features (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Feature ref set`

value of the field

#### RPC name: get&#95;guest&#95;VCPUs&#95;params

_Overview:_

Get the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
(string -> string) map get_guest_VCPUs_params (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;ha&#95;network&#95;peers

_Overview:_

Get the ha&#95;network&#95;peers field of the given host.

_Signature:_

```
string set get_ha_network_peers (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ha&#95;statefiles

_Overview:_

Get the ha&#95;statefiles field of the given host.

_Signature:_

```
string set get_ha_statefiles (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;host&#95;CPUs

_Overview:_

Get the host&#95;CPUs field of the given host.

_Signature:_

```
host_cpu ref set get_host_CPUs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_cpu ref set`

value of the field

#### RPC name: get&#95;hostname

_Overview:_

Get the hostname field of the given host.

_Signature:_

```
string get_hostname (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;iscsi&#95;iqn

_Overview:_

Get the iscsi&#95;iqn field of the given host.

_Signature:_

```
string get_iscsi_iqn (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;license&#95;params

_Overview:_

Get the license&#95;params field of the given host.

_Signature:_

```
(string -> string) map get_license_params (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;license&#95;server

_Overview:_

Get the license&#95;server field of the given host.

_Signature:_

```
(string -> string) map get_license_server (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;local&#95;cache&#95;sr

_Overview:_

Get the local&#95;cache&#95;sr field of the given host.

_Signature:_

```
SR ref get_local_cache_sr (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;log

_Overview:_

Get the host's log file

_Signature:_

```
string get_log (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `string`

The contents of the host's primary log file

#### RPC name: get&#95;logging

_Overview:_

Get the logging field of the given host.

_Signature:_

```
(string -> string) map get_logging (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;management&#95;interface

_Overview:_

Returns the management interface for the specified host

_Signature:_

```
PIF ref get_management_interface (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |Which host's management interface is required|

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The management interface for the host

#### RPC name: get&#95;memory&#95;overhead

_Overview:_

Get the memory/overhead field of the given host.

_Signature:_

```
int get_memory_overhead (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;metrics

_Overview:_

Get the metrics field of the given host.

_Signature:_

```
host_metrics ref get_metrics (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref`

value of the field

#### RPC name: get&#95;multipathing

_Overview:_

Get the multipathing field of the given host.

_Signature:_

```
bool get_multipathing (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given host.

_Signature:_

```
string get_name_description (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given host.

_Signature:_

```
string get_name_label (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;patches

**This message is deprecated.**

_Overview:_

Get the patches field of the given host.

_Signature:_

```
host_patch ref set get_patches (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref set`

value of the field

#### RPC name: get&#95;PBDs

_Overview:_

Get the PBDs field of the given host.

_Signature:_

```
PBD ref set get_PBDs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

value of the field

#### RPC name: get&#95;PCIs

_Overview:_

Get the PCIs field of the given host.

_Signature:_

```
PCI ref set get_PCIs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

value of the field

#### RPC name: get&#95;PGPUs

_Overview:_

Get the PGPUs field of the given host.

_Signature:_

```
PGPU ref set get_PGPUs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

#### RPC name: get&#95;PIFs

_Overview:_

Get the PIFs field of the given host.

_Signature:_

```
PIF ref set get_PIFs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

#### RPC name: get&#95;power&#95;on&#95;config

_Overview:_

Get the power&#95;on&#95;config field of the given host.

_Signature:_

```
(string -> string) map get_power_on_config (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;power&#95;on&#95;mode

_Overview:_

Get the power&#95;on&#95;mode field of the given host.

_Signature:_

```
string get_power_on_mode (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PUSBs

_Overview:_

Get the PUSBs field of the given host.

_Signature:_

```
PUSB ref set get_PUSBs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host.

_Signature:_

```
host record get_record (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host record`

all fields from the object

#### RPC name: get&#95;resident&#95;VMs

_Overview:_

Get the resident&#95;VMs field of the given host.

_Signature:_

```
VM ref set get_resident_VMs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: get&#95;sched&#95;gran

_Overview:_

Gets xen's sched&#45;gran on a host

_Signature:_

```
host_sched_gran get_sched_gran (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host                                |

_Return Type:_ `host_sched_gran`

The host's sched&#45;gran

#### RPC name: get&#95;sched&#95;policy

_Overview:_

Get the sched&#95;policy field of the given host.

_Signature:_

```
string get_sched_policy (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;server&#95;certificate

_Overview:_

Get the installed server public TLS certificate.

_Signature:_

```
string get_server_certificate (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ read-only

_Return Type:_ `string`

The installed server public TLS certificate, in PEM form.

#### RPC name: get&#95;server&#95;localtime

_Overview:_

This call queries the host's clock for the current time in the host's local timezone

_Signature:_

```
datetime get_server_localtime (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host whose clock should be queried  |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

The current local time

#### RPC name: get&#95;servertime

_Overview:_

This call queries the host's clock for the current time

_Signature:_

```
datetime get_servertime (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host whose clock should be queried  |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

The current time

#### RPC name: get&#95;software&#95;version

_Overview:_

Get the software&#95;version field of the given host.

_Signature:_

```
(string -> string) map get_software_version (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;ssl&#95;legacy

**This message is deprecated.**

_Overview:_

Get the ssl&#95;legacy field of the given host.

_Signature:_

```
bool get_ssl_legacy (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;supported&#95;bootloaders

_Overview:_

Get the supported&#95;bootloaders field of the given host.

_Signature:_

```
string set get_supported_bootloaders (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;suspend&#95;image&#95;sr

_Overview:_

Get the suspend&#95;image&#95;sr field of the given host.

_Signature:_

```
SR ref get_suspend_image_sr (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;system&#95;status&#95;capabilities

_Overview:_



_Signature:_

```
string get_system_status_capabilities (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to interrogate                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

An XML fragment containing the system status capabilities.

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given host.

_Signature:_

```
string set get_tags (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;uefi&#95;certificates

_Overview:_

Get the uefi&#95;certificates field of the given host.

_Signature:_

```
string get_uefi_certificates (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uncooperative&#95;resident&#95;VMs

**This message is deprecated.**

_Overview:_

Return a set of VMs which are not co&#45;operating with the host's memory control system

_Signature:_

```
VM ref set get_uncooperative_resident_VMs (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

VMs which are not co&#45;operating

#### RPC name: get&#95;updates

_Overview:_

Get the updates field of the given host.

_Signature:_

```
pool_update ref set get_updates (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

value of the field

#### RPC name: get&#95;updates&#95;requiring&#95;reboot

_Overview:_

Get the updates&#95;requiring&#95;reboot field of the given host.

_Signature:_

```
pool_update ref set get_updates_requiring_reboot (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host.

_Signature:_

```
string get_uuid (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;virtual&#95;hardware&#95;platform&#95;versions

_Overview:_

Get the virtual&#95;hardware&#95;platform&#95;versions field of the given host.

_Signature:_

```
int set get_virtual_hardware_platform_versions (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int set`

value of the field

#### RPC name: get&#95;vms&#95;which&#95;prevent&#95;evacuation

_Overview:_

Return a set of VMs which prevent the host being evacuated, with per&#45;VM error codes

_Signature:_

```
(VM ref -> string set) map get_vms_which_prevent_evacuation (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

VMs which block evacuation together with reasons

#### RPC name: has&#95;extension

_Overview:_

Return true if the extension is available on the host

_Signature:_

```
bool has_extension (session ref session_id, host ref host, string name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|name                          |The name of the API call                |

_Minimum Role:_ pool-admin

_Return Type:_ `bool`

True if the extension exists, false otherwise

#### RPC name: install&#95;server&#95;certificate

_Overview:_

Install the TLS server certificate.

_Signature:_

```
void install_server_certificate (session ref session_id, host ref host, string certificate, string private_key, string certificate_chain)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|certificate                   |The server certificate, in PEM form     |
|`string                      `|private&#95;key               |The unencrypted private key used to sign the certificate, in PKCS&#35;8 form|
|`string                      `|certificate&#95;chain         |The certificate chain, in PEM form      |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: license&#95;add

_Overview:_

Apply a new license to a host

_Signature:_

```
void license_add (session ref session_id, host ref host, string contents)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to upload the license to       |
|`string                      `|contents                      |The contents of the license file, base64 encoded|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `LICENSE_PROCESSING_ERROR`

#### RPC name: license&#95;apply

**This message is removed.**

_Overview:_

Apply a new license to a host

_Signature:_

```
void license_apply (session ref session_id, host ref host, string contents)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to upload the license to       |
|`string                      `|contents                      |The contents of the license file, base64 encoded|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `LICENSE_PROCESSING_ERROR`

#### RPC name: license&#95;remove

_Overview:_

Remove any license file from the specified host, and switch that host to the unlicensed edition

_Signature:_

```
void license_remove (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host from which any license will be removed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: list&#95;methods

_Overview:_

List all supported methods

_Signature:_

```
string set list_methods (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `string set`

The name of every supported method.

#### RPC name: local&#95;management&#95;reconfigure

_Overview:_

Reconfigure the management network interface. Should only be used if Host.management&#95;reconfigure is impossible because the network configuration is broken.

_Signature:_

```
void local_management_reconfigure (session ref session_id, string interface)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|interface                     |name of the interface to use as a management interface|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: management&#95;disable

_Overview:_

Disable the management network interface

_Signature:_

```
void management_disable (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: management&#95;reconfigure

_Overview:_

Reconfigure the management network interface

_Signature:_

```
void management_reconfigure (session ref session_id, PIF ref pif)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|pif                           |reference to a PIF object corresponding to the management interface|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: migrate&#95;receive

_Overview:_

Prepare to receive a VM, returning a token which can be passed to VM.migrate.

_Signature:_

```
(string -> string) map migrate_receive (session ref session_id, host ref host, network ref network, (string -> string) map options)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The target host                         |
|`network ref                 `|network                       |The network through which migration traffic should be received.|
|`(string -> string) map      `|options                       |Extra configuration operations          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `(string -> string) map`

A value which should be passed to VM.migrate

#### RPC name: power&#95;on

_Overview:_

Attempt to power&#45;on the host &#40;if the capability exists&#41;.

_Signature:_

```
void power_on (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to power on                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: query&#95;data&#95;source

_Overview:_

Query the latest value of the specified data source

_Signature:_

```
float query_data_source (session ref session_id, host ref host, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|data&#95;source               |The data source to query                |

_Minimum Role:_ read-only

_Return Type:_ `float`

The latest value, averaged over the last 5 seconds

#### RPC name: reboot

_Overview:_

Reboot the host. &#40;This function can only be called if there are no currently running VMs on the host and it is disabled.&#41;

_Signature:_

```
void reboot (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to reboot                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: record&#95;data&#95;source

_Overview:_

Start recording the specified data source

_Signature:_

```
void record_data_source (session ref session_id, host ref host, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|data&#95;source               |The data source to record               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: refresh&#95;pack&#95;info

**This message is deprecated.**

_Overview:_

Refresh the list of installed Supplemental Packs.

_Signature:_

```
void refresh_pack_info (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to modify                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;guest&#95;VCPUs&#95;params

_Overview:_

Remove the given key and its corresponding value from the guest&#95;VCPUs&#95;params field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_guest_VCPUs_params (session ref session_id, host ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;license&#95;server

_Overview:_

Remove the given key and its corresponding value from the license&#95;server field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_license_server (session ref session_id, host ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;logging

_Overview:_

Remove the given key and its corresponding value from the logging field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_logging (session ref session_id, host ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, host ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given host.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: reset&#95;cpu&#95;features

**This message is removed.**

_Overview:_

Remove the feature mask, such that after a reboot all features of the CPU are enabled.

_Signature:_

```
void reset_cpu_features (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: restart&#95;agent

_Overview:_

Restarts the agent after a 10 second pause. WARNING: this is a dangerous operation. Any operations in progress will be aborted, and unrecoverable data loss may occur. The caller is responsible for ensuring that there are no operations in progress when this method is called.

_Signature:_

```
void restart_agent (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host on which you want to restart the agent|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: retrieve&#95;wlb&#95;evacuate&#95;recommendations

_Overview:_

Retrieves recommended host migrations to perform when evacuating the host from the wlb server. If a VM cannot be migrated from the host the reason is listed instead of a recommendation.

_Signature:_

```
(VM ref -> string set) map retrieve_wlb_evacuate_recommendations (session ref session_id, host ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host to query                       |

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

VMs and the reasons why they would block evacuation, or their target host recommended by the wlb server

#### RPC name: send&#95;debug&#95;keys

_Overview:_

Inject the given string as debugging keys into Xen

_Signature:_

```
void send_debug_keys (session ref session_id, host ref host, string keys)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|keys                          |The keys to send                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;address

_Overview:_

Set the address field of the given host.

_Signature:_

```
void set_address (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;cpu&#95;features

**This message is removed.**

_Overview:_

Set the CPU features to be used after a reboot, if the given features string is valid.

_Signature:_

```
void set_cpu_features (session ref session_id, host ref host, string features)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|features                      |The features string &#40;32 hexadecimal digits&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;crash&#95;dump&#95;sr

_Overview:_

Set the crash&#95;dump&#95;sr field of the given host.

_Signature:_

```
void set_crash_dump_sr (session ref session_id, host ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;display

_Overview:_

Set the display field of the given host.

_Signature:_

```
void set_display (session ref session_id, host ref self, host_display value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`host_display                `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;guest&#95;VCPUs&#95;params

_Overview:_

Set the guest&#95;VCPUs&#95;params field of the given host.

_Signature:_

```
void set_guest_VCPUs_params (session ref session_id, host ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;hostname

_Overview:_

Set the hostname field of the given host.

_Signature:_

```
void set_hostname (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;hostname&#95;live

_Overview:_

Sets the host name to the specified string.  Both the API and lower&#45;level system hostname are changed immediately.

_Signature:_

```
void set_hostname_live (session ref session_id, host ref host, string hostname)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host whose host name to set         |
|`string                      `|hostname                      |The new host name                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HOST_NAME_INVALID`

#### RPC name: set&#95;iscsi&#95;iqn

_Overview:_

Sets the initiator IQN for the host

_Signature:_

```
void set_iscsi_iqn (session ref session_id, host ref host, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|value                         |The value to which the IQN should be set|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;license&#95;server

_Overview:_

Set the license&#95;server field of the given host.

_Signature:_

```
void set_license_server (session ref session_id, host ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;logging

_Overview:_

Set the logging field of the given host.

_Signature:_

```
void set_logging (session ref session_id, host ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;multipathing

_Overview:_

Specifies whether multipathing is enabled

_Signature:_

```
void set_multipathing (session ref session_id, host ref host, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`bool                        `|value                         |Whether multipathing should be enabled  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given host.

_Signature:_

```
void set_name_description (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given host.

_Signature:_

```
void set_name_label (session ref session_id, host ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host.

_Signature:_

```
void set_other_config (session ref session_id, host ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;power&#95;on&#95;mode

_Overview:_

Set the power&#45;on&#45;mode, host, user and password 

_Signature:_

```
void set_power_on_mode (session ref session_id, host ref self, string power_on_mode, (string -> string) map power_on_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host                                |
|`string                      `|power&#95;on&#95;mode         |power&#45;on&#45;mode can be empty, wake&#45;on&#45;lan, DRAC or other|
|`(string -> string) map      `|power&#95;on&#95;config       |Power on config                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;sched&#95;gran

_Overview:_

Sets xen's sched&#45;gran on a host. See: https://xenbits.xen.org/docs/unstable/misc/xen&#45;command&#45;line.html&#35;sched&#45;gran&#45;x86

_Signature:_

```
void set_sched_gran (session ref session_id, host ref self, host_sched_gran value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host                                |
|`host_sched_gran             `|value                         |The sched&#45;gran to apply to a host   |

_Return Type:_ `void`

#### RPC name: set&#95;ssl&#95;legacy

_Overview:_

Enable/disable SSLv3 for interoperability with older server versions. When this is set to a different value, the host immediately restarts its SSL/TLS listening service; typically this takes less than a second but existing connections to it will be broken. API login sessions will remain valid.

_Signature:_

```
void set_ssl_legacy (session ref session_id, host ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |The host                                |
|`bool                        `|value                         |True to allow SSLv3 and ciphersuites as used in old XenServer versions|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;suspend&#95;image&#95;sr

_Overview:_

Set the suspend&#95;image&#95;sr field of the given host.

_Signature:_

```
void set_suspend_image_sr (session ref session_id, host ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given host.

_Signature:_

```
void set_tags (session ref session_id, host ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;uefi&#95;certificates

_Overview:_

Sets the UEFI certificates on a host

_Signature:_

```
void set_uefi_certificates (session ref session_id, host ref host, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |
|`string                      `|value                         |The certificates to apply to a host     |

_Return Type:_ `void`

#### RPC name: shutdown

_Overview:_

Shutdown the host. &#40;This function can only be called if there are no currently running VMs on the host and it is disabled.&#41;

_Signature:_

```
void shutdown (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The Host to shutdown                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: shutdown&#95;agent

_Overview:_

Shuts the agent down after a 10 second pause. WARNING: this is a dangerous operation. Any operations in progress will be aborted, and unrecoverable data loss may occur. The caller is responsible for ensuring that there are no operations in progress when this method is called.

_Signature:_

```
void shutdown_agent (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: sync&#95;data

_Overview:_

This causes the synchronisation of the non&#45;database data &#40;messages, RRDs and so on&#41; stored on the master to be synchronised with the host

_Signature:_

```
void sync_data (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to whom the data should be sent|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: syslog&#95;reconfigure

_Overview:_

Re&#45;configure syslog logging

_Signature:_

```
void syslog_reconfigure (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |Tell the host to reread its Host.logging parameters and reconfigure itself accordingly|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: host&#95;cpu

**This class is deprecated.**

A physical CPU

### Fields for class: host&#95;cpu

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|family              |`int               `|_RO/runtime_   |**Deprecated**. the family &#40;number&#41; of the physical CPU|
|features            |`string            `|_RO/runtime_   |**Deprecated**. the physical CPU feature bitmap|
|flags               |`string            `|_RO/runtime_   |**Deprecated**. the flags of the physical CPU &#40;a decoded version of the features field&#41;|
|host                |`host ref          `|_RO/runtime_   |**Deprecated**. the host the CPU is in  |
|model               |`int               `|_RO/runtime_   |**Deprecated**. the model number of the physical CPU|
|modelname           |`string            `|_RO/runtime_   |**Deprecated**. the model name of the physical CPU|
|number              |`int               `|_RO/runtime_   |**Deprecated**. the number of the physical CPU within the host|
|other&#95;config    |`(string -> string) map`|_RW_           |**Deprecated**. additional configuration|
|speed               |`int               `|_RO/runtime_   |**Deprecated**. the speed of the physical CPU|
|stepping            |`string            `|_RO/runtime_   |**Deprecated**. the stepping of the physical CPU|
|utilisation         |`float             `|_RO/runtime_   |**Deprecated**. the current CPU utilisation|
|uuid                |`string            `|_RO/runtime_   |**Deprecated**. Unique identifier/object reference|
|vendor              |`string            `|_RO/runtime_   |**Deprecated**. the vendor of the physical CPU|

### RPCs associated with class: host&#95;cpu

#### RPC name: add&#95;to&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;cpu.

_Signature:_

```
void add_to_other_config (session ref session_id, host_cpu ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

**This message is deprecated.**

_Overview:_

Return a list of all the host&#95;cpus known to the system.

_Signature:_

```
host_cpu ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `host_cpu ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is deprecated.**

_Overview:_

Return a map of host&#95;cpu references to host&#95;cpu records for all host&#95;cpus known to the system.

_Signature:_

```
(host_cpu ref -> host_cpu record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(host_cpu ref -> host_cpu record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

**This message is deprecated.**

_Overview:_

Get a reference to the host&#95;cpu instance with the specified UUID.

_Signature:_

```
host_cpu ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_cpu ref`

reference to the object

#### RPC name: get&#95;family

**This message is deprecated.**

_Overview:_

Get the family field of the given host&#95;cpu.

_Signature:_

```
int get_family (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;features

**This message is deprecated.**

_Overview:_

Get the features field of the given host&#95;cpu.

_Signature:_

```
string get_features (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;flags

**This message is deprecated.**

_Overview:_

Get the flags field of the given host&#95;cpu.

_Signature:_

```
string get_flags (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;host

**This message is deprecated.**

_Overview:_

Get the host field of the given host&#95;cpu.

_Signature:_

```
host ref get_host (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;model

**This message is deprecated.**

_Overview:_

Get the model field of the given host&#95;cpu.

_Signature:_

```
int get_model (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;modelname

**This message is deprecated.**

_Overview:_

Get the modelname field of the given host&#95;cpu.

_Signature:_

```
string get_modelname (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;number

**This message is deprecated.**

_Overview:_

Get the number field of the given host&#95;cpu.

_Signature:_

```
int get_number (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Get the other&#95;config field of the given host&#95;cpu.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

**This message is deprecated.**

_Overview:_

Get a record containing the current state of the given host&#95;cpu.

_Signature:_

```
host_cpu record get_record (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_cpu record`

all fields from the object

#### RPC name: get&#95;speed

**This message is deprecated.**

_Overview:_

Get the speed field of the given host&#95;cpu.

_Signature:_

```
int get_speed (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;stepping

**This message is deprecated.**

_Overview:_

Get the stepping field of the given host&#95;cpu.

_Signature:_

```
string get_stepping (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;utilisation

**This message is deprecated.**

_Overview:_

Get the utilisation field of the given host&#95;cpu.

_Signature:_

```
float get_utilisation (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;uuid

**This message is deprecated.**

_Overview:_

Get the uuid field of the given host&#95;cpu.

_Signature:_

```
string get_uuid (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor

**This message is deprecated.**

_Overview:_

Get the vendor field of the given host&#95;cpu.

_Signature:_

```
string get_vendor (session ref session_id, host_cpu ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;cpu.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, host_cpu ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Set the other&#95;config field of the given host&#95;cpu.

_Signature:_

```
void set_other_config (session ref session_id, host_cpu ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_cpu ref                `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: host&#95;crashdump

Represents a host crash dump

### Fields for class: host&#95;crashdump

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|host                |`host ref          `|_RO/constructor_|Host the crashdump relates to           |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|size                |`int               `|_RO/runtime_   |Size of the crashdump                   |
|timestamp           |`datetime          `|_RO/runtime_   |Time the crash happened                 |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: host&#95;crashdump

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
void add_to_other_config (session ref session_id, host_crashdump ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: destroy

_Overview:_

Destroy specified host crash dump, removing it from the disk.

_Signature:_

```
void destroy (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |The host crashdump to destroy           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the host&#95;crashdumps known to the system.

_Signature:_

```
host_crashdump ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host&#95;crashdump references to host&#95;crashdump records for all host&#95;crashdumps known to the system.

_Signature:_

```
(host_crashdump ref -> host_crashdump record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(host_crashdump ref -> host_crashdump record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host&#95;crashdump instance with the specified UUID.

_Signature:_

```
host_crashdump ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump ref`

reference to the object

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given host&#95;crashdump.

_Signature:_

```
host ref get_host (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host&#95;crashdump.

_Signature:_

```
host_crashdump record get_record (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_crashdump record`

all fields from the object

#### RPC name: get&#95;size

_Overview:_

Get the size field of the given host&#95;crashdump.

_Signature:_

```
int get_size (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;timestamp

_Overview:_

Get the timestamp field of the given host&#95;crashdump.

_Signature:_

```
datetime get_timestamp (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host&#95;crashdump.

_Signature:_

```
string get_uuid (session ref session_id, host_crashdump ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;crashdump.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, host_crashdump ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host&#95;crashdump.

_Signature:_

```
void set_other_config (session ref session_id, host_crashdump ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: upload

_Overview:_

Upload the specified host crash dump to a specified URL

_Signature:_

```
void upload (session ref session_id, host_crashdump ref self, string url, (string -> string) map options)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_crashdump ref          `|self                          |The host crashdump to upload            |
|`string                      `|url                           |The URL to upload to                    |
|`(string -> string) map      `|options                       |Extra configuration operations          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: host&#95;metrics

The metrics associated with a host

### Fields for class: host&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|last&#95;updated    |`datetime          `|_RO/runtime_   |Time at which this information was last updated|
|live                |`bool              `|_RO/runtime_   |Pool master thinks this host is live    |
|memory&#95;free     |`int               `|_RO/runtime_   |**Removed**. Free host memory &#40;bytes&#41;|
|memory&#95;total    |`int               `|_RO/runtime_   |Total host memory &#40;bytes&#41;       |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: host&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, host_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the host&#95;metrics instances known to the system.

_Signature:_

```
host_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of host&#95;metrics references to host&#95;metrics records for all host&#95;metrics instances known to the system.

_Signature:_

```
(host_metrics ref -> host_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(host_metrics ref -> host_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the host&#95;metrics instance with the specified UUID.

_Signature:_

```
host_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics ref`

reference to the object

#### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given host&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;live

_Overview:_

Get the live field of the given host&#95;metrics.

_Signature:_

```
bool get_live (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;memory&#95;free

**This message is removed.**

_Overview:_

Get the memory/free field of the given host&#95;metrics.

_Signature:_

```
int get_memory_free (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;total

_Overview:_

Get the memory/total field of the given host&#95;metrics.

_Signature:_

```
int get_memory_total (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given host&#95;metrics.

_Signature:_

```
host_metrics record get_record (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_metrics record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given host&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, host_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, host_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given host&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, host_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_metrics ref            `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: host&#95;patch

**This class is deprecated.**

Represents a patch stored on a server

### Fields for class: host&#95;patch

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|applied             |`bool              `|_RO/runtime_   |**Deprecated**. True if the patch has been applied|
|host                |`host ref          `|_RO/constructor_|**Deprecated**. Host the patch relates to|
|name&#95;description|`string            `|_RO/constructor_|**Deprecated**. a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|**Deprecated**. a human&#45;readable name|
|other&#95;config    |`(string -> string) map`|_RW_           |**Deprecated**. additional configuration|
|pool&#95;patch      |`pool_patch ref    `|_RO/constructor_|**Deprecated**. The patch applied       |
|size                |`int               `|_RO/runtime_   |**Deprecated**. Size of the patch       |
|timestamp&#95;applied|`datetime          `|_RO/runtime_   |**Deprecated**. Time the patch was applied|
|uuid                |`string            `|_RO/runtime_   |**Deprecated**. Unique identifier/object reference|
|version             |`string            `|_RO/constructor_|**Deprecated**. Patch version number    |

### RPCs associated with class: host&#95;patch

#### RPC name: add&#95;to&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given host&#95;patch.

_Signature:_

```
void add_to_other_config (session ref session_id, host_patch ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: apply

**This message is deprecated.**

_Overview:_

Apply the selected patch and return its output

_Signature:_

```
string apply (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |The patch to apply                      |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

the output of the patch application process

#### RPC name: destroy

**This message is deprecated.**

_Overview:_

Destroy the specified host patch, removing it from the disk. This does NOT reverse the patch

_Signature:_

```
void destroy (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |The patch to destroy                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

**This message is deprecated.**

_Overview:_

Return a list of all the host&#95;patchs known to the system.

_Signature:_

```
host_patch ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is deprecated.**

_Overview:_

Return a map of host&#95;patch references to host&#95;patch records for all host&#95;patchs known to the system.

_Signature:_

```
(host_patch ref -> host_patch record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(host_patch ref -> host_patch record) map`

records of all objects

#### RPC name: get&#95;applied

**This message is deprecated.**

_Overview:_

Get the applied field of the given host&#95;patch.

_Signature:_

```
bool get_applied (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

**This message is deprecated.**

_Overview:_

Get all the host&#95;patch instances with the given label.

_Signature:_

```
host_patch ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

**This message is deprecated.**

_Overview:_

Get a reference to the host&#95;patch instance with the specified UUID.

_Signature:_

```
host_patch ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref`

reference to the object

#### RPC name: get&#95;host

**This message is deprecated.**

_Overview:_

Get the host field of the given host&#95;patch.

_Signature:_

```
host ref get_host (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;name&#95;description

**This message is deprecated.**

_Overview:_

Get the name/description field of the given host&#95;patch.

_Signature:_

```
string get_name_description (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

**This message is deprecated.**

_Overview:_

Get the name/label field of the given host&#95;patch.

_Signature:_

```
string get_name_label (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Get the other&#95;config field of the given host&#95;patch.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;pool&#95;patch

**This message is deprecated.**

_Overview:_

Get the pool&#95;patch field of the given host&#95;patch.

_Signature:_

```
pool_patch ref get_pool_patch (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_patch ref`

value of the field

#### RPC name: get&#95;record

**This message is deprecated.**

_Overview:_

Get a record containing the current state of the given host&#95;patch.

_Signature:_

```
host_patch record get_record (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_patch record`

all fields from the object

#### RPC name: get&#95;size

**This message is deprecated.**

_Overview:_

Get the size field of the given host&#95;patch.

_Signature:_

```
int get_size (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;timestamp&#95;applied

**This message is deprecated.**

_Overview:_

Get the timestamp&#95;applied field of the given host&#95;patch.

_Signature:_

```
datetime get_timestamp_applied (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;uuid

**This message is deprecated.**

_Overview:_

Get the uuid field of the given host&#95;patch.

_Signature:_

```
string get_uuid (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;version

**This message is deprecated.**

_Overview:_

Get the version field of the given host&#95;patch.

_Signature:_

```
string get_version (session ref session_id, host_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given host&#95;patch.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, host_patch ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Set the other&#95;config field of the given host&#95;patch.

_Signature:_

```
void set_other_config (session ref session_id, host_patch ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host_patch ref              `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: LVHD

LVHD SR specific operations

### Fields for class: LVHD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: LVHD

#### RPC name: enable&#95;thin&#95;provisioning

_Overview:_

Upgrades an LVHD SR to enable thin&#45;provisioning. Future VDIs created in this SR will be thinly&#45;provisioned, although existing VDIs will be left alone. Note that the SR must be attached to the SRmaster for upgrade to work.

_Signature:_

```
string enable_thin_provisioning (session ref session_id, host ref host, SR ref SR, int initial_allocation, int allocation_quantum)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The LVHD Host to upgrade to being thin&#45;provisioned.|
|`SR ref                      `|SR                            |The LVHD SR to upgrade to being thin&#45;provisioned.|
|`int                         `|initial&#95;allocation        |The initial amount of space to allocate to a newly&#45;created VDI in bytes|
|`int                         `|allocation&#95;quantum        |The amount of space to allocate to a VDI when it needs to be enlarged in bytes|

_Minimum Role:_ pool-admin

_Return Type:_ `string`

Message from LVHD.enable&#95;thin&#95;provisioning extension

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the LVHD instance with the specified UUID.

_Signature:_

```
LVHD ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `LVHD ref`

reference to the object

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given LVHD.

_Signature:_

```
LVHD record get_record (session ref session_id, LVHD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`LVHD ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `LVHD record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given LVHD.

_Signature:_

```
string get_uuid (session ref session_id, LVHD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`LVHD ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: message

An message for the attention of the administrator

### Fields for class: message

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|body                |`string            `|_RO/runtime_   |The body of the message                 |
|cls                 |`cls               `|_RO/runtime_   |The class of the object this message is associated with|
|name                |`string            `|_RO/runtime_   |The name of the message                 |
|obj&#95;uuid        |`string            `|_RO/runtime_   |The uuid of the object this message is associated with|
|priority            |`int               `|_RO/runtime_   |The message priority, 0 being low priority|
|timestamp           |`datetime          `|_RO/runtime_   |The time at which the message was created|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: message

#### RPC name: create

_Overview:_



_Signature:_

```
message ref create (session ref session_id, string name, int priority, cls cls, string obj_uuid, string body)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name                          |The name of the message                 |
|`int                         `|priority                      |The priority of the message             |
|`cls                         `|cls                           |The class of object this message is associated with|
|`string                      `|obj&#95;uuid                  |The uuid of the object this message is associated with|
|`string                      `|body                          |The body of the message                 |

_Minimum Role:_ pool-operator

_Return Type:_ `message ref`

The reference of the created message

#### RPC name: destroy

_Overview:_



_Signature:_

```
void destroy (session ref session_id, message ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`message ref                 `|self                          |The reference of the message to destroy |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get

_Overview:_



_Signature:_

```
(message ref -> message record) map get (session ref session_id, cls cls, string obj_uuid, datetime since)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`cls                         `|cls                           |The class of object                     |
|`string                      `|obj&#95;uuid                  |The uuid of the object                  |
|`datetime                    `|since                         |The cutoff time                         |

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The relevant messages

#### RPC name: get&#95;all

_Overview:_



_Signature:_

```
message ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `message ref set`

The references to the messages

#### RPC name: get&#95;all&#95;records

_Overview:_



_Signature:_

```
(message ref -> message record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The messages

#### RPC name: get&#95;all&#95;records&#95;where

_Overview:_



_Signature:_

```
(message ref -> message record) map get_all_records_where (session ref session_id, string expr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|expr                          |The expression to match &#40;not currently used&#41;|

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The messages

#### RPC name: get&#95;by&#95;uuid

_Overview:_



_Signature:_

```
message ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |The uuid of the message                 |

_Minimum Role:_ read-only

_Return Type:_ `message ref`

The message reference

#### RPC name: get&#95;record

_Overview:_



_Signature:_

```
message record get_record (session ref session_id, message ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`message ref                 `|self                          |The reference to the message            |

_Minimum Role:_ read-only

_Return Type:_ `message record`

The message record

#### RPC name: get&#95;since

_Overview:_



_Signature:_

```
(message ref -> message record) map get_since (session ref session_id, datetime since)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`datetime                    `|since                         |The cutoff time                         |

_Minimum Role:_ read-only

_Return Type:_ `(message ref -> message record) map`

The relevant messages

## Class: network

A virtual network

### Fields for class: network

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`network_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|assigned&#95;ips    |`(VIF ref -> string) map`|_RO/runtime_   |The IP addresses assigned to VIFs on networks that have active xapi&#45;managed DHCP|
|blobs               |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this network|
|bridge              |`string            `|_RO/constructor_|name of the bridge corresponding to this network on the local host|
|current&#95;operations|`(string -> network_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|default&#95;locking&#95;mode|`network_default_locking_mode`|_RO/runtime_   |The network will use this value to determine the behaviour of all VIFs where locking&#95;mode = default|
|managed             |`bool              `|_RO/constructor_|true if the bridge is managed by xapi   |
|MTU                 |`int               `|_RW_           |MTU in octets                           |
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|PIFs                |`PIF ref set       `|_RO/runtime_   |list of connected pifs                  |
|purpose             |`network_purpose set`|_RO/runtime_   |Set of purposes for which the server will use this network|
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VIFs                |`VIF ref set       `|_RO/runtime_   |list of connected vifs                  |

### RPCs associated with class: network

#### RPC name: add&#95;purpose

_Overview:_

Give a network a new purpose &#40;if not present already&#41;

_Signature:_

```
void add_purpose (session ref session_id, network ref self, network_purpose value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |The network                             |
|`network_purpose             `|value                         |The purpose to add                      |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `NETWORK_INCOMPATIBLE_PURPOSES`

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given network.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, network ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given network.

_Signature:_

```
void add_to_other_config (session ref session_id, network ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new network instance, and return its handle.

_Signature:_

```
network ref create (session ref session_id, network record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network record              `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `network ref`

reference to the newly created object

#### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this pool

_Signature:_

```
blob ref create_new_blob (session ref session_id, network ref network, string name, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|network                       |The network                             |
|`string                      `|name                          |The name associated with the blob       |
|`string                      `|mime&#95;type                 |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

#### RPC name: destroy

_Overview:_

Destroy the specified network instance.

_Signature:_

```
void destroy (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the networks known to the system.

_Signature:_

```
network ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `network ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of network references to network records for all networks known to the system.

_Signature:_

```
(network ref -> network record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(network ref -> network record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given network.

_Signature:_

```
network_operations set get_allowed_operations (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_operations set`

value of the field

#### RPC name: get&#95;assigned&#95;ips

_Overview:_

Get the assigned&#95;ips field of the given network.

_Signature:_

```
(VIF ref -> string) map get_assigned_ips (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(VIF ref -> string) map`

value of the field

#### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given network.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

#### RPC name: get&#95;bridge

_Overview:_

Get the bridge field of the given network.

_Signature:_

```
string get_bridge (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the network instances with the given label.

_Signature:_

```
network ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `network ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the network instance with the specified UUID.

_Signature:_

```
network ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

reference to the object

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given network.

_Signature:_

```
(string -> network_operations) map get_current_operations (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> network_operations) map`

value of the field

#### RPC name: get&#95;default&#95;locking&#95;mode

_Overview:_

Get the default&#95;locking&#95;mode field of the given network.

_Signature:_

```
network_default_locking_mode get_default_locking_mode (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_default_locking_mode`

value of the field

#### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given network.

_Signature:_

```
bool get_managed (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given network.

_Signature:_

```
int get_MTU (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given network.

_Signature:_

```
string get_name_description (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given network.

_Signature:_

```
string get_name_label (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given network.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PIFs

_Overview:_

Get the PIFs field of the given network.

_Signature:_

```
PIF ref set get_PIFs (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

value of the field

#### RPC name: get&#95;purpose

_Overview:_

Get the purpose field of the given network.

_Signature:_

```
network_purpose set get_purpose (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_purpose set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given network.

_Signature:_

```
network record get_record (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network record`

all fields from the object

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given network.

_Signature:_

```
string set get_tags (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given network.

_Signature:_

```
string get_uuid (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VIFs

_Overview:_

Get the VIFs field of the given network.

_Signature:_

```
VIF ref set get_VIFs (session ref session_id, network ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref set`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given network.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, network ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;purpose

_Overview:_

Remove a purpose from a network &#40;if present&#41;

_Signature:_

```
void remove_purpose (session ref session_id, network ref self, network_purpose value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |The network                             |
|`network_purpose             `|value                         |The purpose to remove                   |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given network.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, network ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;default&#95;locking&#95;mode

_Overview:_

Set the default locking mode for VIFs attached to this network

_Signature:_

```
void set_default_locking_mode (session ref session_id, network ref network, network_default_locking_mode value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|network                       |The network                             |
|`network_default_locking_mode`|value                         |The default locking mode for VIFs attached to this network.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;MTU

_Overview:_

Set the MTU field of the given network.

_Signature:_

```
void set_MTU (session ref session_id, network ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`int                         `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given network.

_Signature:_

```
void set_name_description (session ref session_id, network ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given network.

_Signature:_

```
void set_name_label (session ref session_id, network ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given network.

_Signature:_

```
void set_other_config (session ref session_id, network ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given network.

_Signature:_

```
void set_tags (session ref session_id, network ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

## Class: network&#95;sriov

network&#45;sriov which connects logical pif and physical pif

### Fields for class: network&#95;sriov

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|configuration&#95;mode|`sriov_configuration_mode`|_RO/runtime_   |The mode for configure network sriov    |
|logical&#95;PIF     |`PIF ref           `|_RO/constructor_|The logical PIF to connect to the SR&#45;IOV network after enable SR&#45;IOV on the physical PIF|
|physical&#95;PIF    |`PIF ref           `|_RO/constructor_|The PIF that has SR&#45;IOV enabled     |
|requires&#95;reboot |`bool              `|_RO/runtime_   |Indicates whether the host need to be rebooted before SR&#45;IOV is enabled on the physical PIF|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: network&#95;sriov

#### RPC name: create

_Overview:_

Enable SR&#45;IOV on the specific PIF. It will create a network&#45;sriov based on the specific PIF and automatically create a logical PIF to connect the specific network.

_Signature:_

```
network_sriov ref create (session ref session_id, PIF ref pif, network ref network)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|pif                           |PIF on which to enable SR&#45;IOV       |
|`network ref                 `|network                       |Network to connect SR&#45;IOV virtual functions with VM VIFs|

_Minimum Role:_ pool-operator

_Return Type:_ `network_sriov ref`

The reference of the created network&#95;sriov object

#### RPC name: destroy

_Overview:_

Disable SR&#45;IOV on the specific PIF. It will destroy the network&#45;sriov and the logical PIF accordingly.

_Signature:_

```
void destroy (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |SRIOV to destroy                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the network&#95;sriovs known to the system.

_Signature:_

```
network_sriov ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of network&#95;sriov references to network&#95;sriov records for all network&#95;sriovs known to the system.

_Signature:_

```
(network_sriov ref -> network_sriov record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(network_sriov ref -> network_sriov record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the network&#95;sriov instance with the specified UUID.

_Signature:_

```
network_sriov ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref`

reference to the object

#### RPC name: get&#95;configuration&#95;mode

_Overview:_

Get the configuration&#95;mode field of the given network&#95;sriov.

_Signature:_

```
sriov_configuration_mode get_configuration_mode (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `sriov_configuration_mode`

value of the field

#### RPC name: get&#95;logical&#95;PIF

_Overview:_

Get the logical&#95;PIF field of the given network&#95;sriov.

_Signature:_

```
PIF ref get_logical_PIF (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;physical&#95;PIF

_Overview:_

Get the physical&#95;PIF field of the given network&#95;sriov.

_Signature:_

```
PIF ref get_physical_PIF (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given network&#95;sriov.

_Signature:_

```
network_sriov record get_record (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov record`

all fields from the object

#### RPC name: get&#95;remaining&#95;capacity

_Overview:_

Get the number of free SR&#45;IOV VFs on the associated PIF

_Signature:_

```
int get_remaining_capacity (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |the NETWORK&#95;SRIOV object            |

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of free SR&#45;IOV VFs on the associated PIF

#### RPC name: get&#95;requires&#95;reboot

_Overview:_

Get the requires&#95;reboot field of the given network&#95;sriov.

_Signature:_

```
bool get_requires_reboot (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given network&#95;sriov.

_Signature:_

```
string get_uuid (session ref session_id, network_sriov ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network_sriov ref           `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: PBD

The physical block devices through which hosts access SRs

### Fields for class: PBD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|currently&#95;attached|`bool              `|_RO/runtime_   |is the SR currently attached on this host?|
|device&#95;config   |`(string -> string) map`|_RO/constructor_|a config string to string map that is provided to the host's SR&#45;backend&#45;driver|
|host                |`host ref          `|_RO/constructor_|physical machine on which the pbd is available|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|SR                  |`SR ref            `|_RO/constructor_|the storage repository that the pbd realises|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: PBD

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PBD.

_Signature:_

```
void add_to_other_config (session ref session_id, PBD ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new PBD instance, and return its handle.

_Signature:_

```
PBD ref create (session ref session_id, PBD record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD record                  `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `PBD ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified PBD instance.

_Signature:_

```
void destroy (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PBDs known to the system.

_Signature:_

```
PBD ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PBD references to PBD records for all PBDs known to the system.

_Signature:_

```
(PBD ref -> PBD record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PBD ref -> PBD record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PBD instance with the specified UUID.

_Signature:_

```
PBD ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref`

reference to the object

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PBD.

_Signature:_

```
bool get_currently_attached (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device&#95;config

_Overview:_

Get the device&#95;config field of the given PBD.

_Signature:_

```
(string -> string) map get_device_config (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PBD.

_Signature:_

```
host ref get_host (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PBD.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PBD.

_Signature:_

```
PBD record get_record (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD record`

all fields from the object

#### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given PBD.

_Signature:_

```
SR ref get_SR (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PBD.

_Signature:_

```
string get_uuid (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: plug

_Overview:_

Activate the specified PBD, causing the referenced SR to be attached and scanned

_Signature:_

```
void plug (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |The PBD to activate                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_UNKNOWN_DRIVER`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PBD ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;device&#95;config

_Overview:_

Sets the PBD's device&#95;config field

_Signature:_

```
void set_device_config (session ref session_id, PBD ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |The PBD to modify                       |
|`(string -> string) map      `|value                         |The new value of the PBD's device&#95;config|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PBD.

_Signature:_

```
void set_other_config (session ref session_id, PBD ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: unplug

_Overview:_

Deactivate the specified PBD, causing the referenced SR to be detached and nolonger scanned

_Signature:_

```
void unplug (session ref session_id, PBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PBD ref                     `|self                          |The PBD to deactivate                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: PCI

A PCI device

### Fields for class: PCI

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|class&#95;name      |`string            `|_RO/constructor_|PCI class name                          |
|dependencies        |`PCI ref set       `|_RO/runtime_   |List of dependent PCI devices           |
|device&#95;name     |`string            `|_RO/constructor_|Device name                             |
|driver&#95;name     |`string            `|_RO/constructor_|Driver name                             |
|host                |`host ref          `|_RO/constructor_|Physical machine that owns the PCI device|
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|pci&#95;id          |`string            `|_RO/constructor_|PCI ID of the physical device           |
|subsystem&#95;device&#95;name|`string            `|_RO/constructor_|Subsystem device name                   |
|subsystem&#95;vendor&#95;name|`string            `|_RO/constructor_|Subsystem vendor name                   |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vendor&#95;name     |`string            `|_RO/constructor_|Vendor name                             |

### RPCs associated with class: PCI

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PCI.

_Signature:_

```
void add_to_other_config (session ref session_id, PCI ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PCIs known to the system.

_Signature:_

```
PCI ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PCI references to PCI records for all PCIs known to the system.

_Signature:_

```
(PCI ref -> PCI record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PCI ref -> PCI record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PCI instance with the specified UUID.

_Signature:_

```
PCI ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

reference to the object

#### RPC name: get&#95;class&#95;name

_Overview:_

Get the class&#95;name field of the given PCI.

_Signature:_

```
string get_class_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;dependencies

_Overview:_

Get the dependencies field of the given PCI.

_Signature:_

```
PCI ref set get_dependencies (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

value of the field

#### RPC name: get&#95;device&#95;name

_Overview:_

Get the device&#95;name field of the given PCI.

_Signature:_

```
string get_device_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;driver&#95;name

_Overview:_

Get the driver&#95;name field of the given PCI.

_Signature:_

```
string get_driver_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PCI.

_Signature:_

```
host ref get_host (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PCI.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;pci&#95;id

_Overview:_

Get the pci&#95;id field of the given PCI.

_Signature:_

```
string get_pci_id (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PCI.

_Signature:_

```
PCI record get_record (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI record`

all fields from the object

#### RPC name: get&#95;subsystem&#95;device&#95;name

_Overview:_

Get the subsystem&#95;device&#95;name field of the given PCI.

_Signature:_

```
string get_subsystem_device_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;subsystem&#95;vendor&#95;name

_Overview:_

Get the subsystem&#95;vendor&#95;name field of the given PCI.

_Signature:_

```
string get_subsystem_vendor_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PCI.

_Signature:_

```
string get_uuid (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given PCI.

_Signature:_

```
string get_vendor_name (session ref session_id, PCI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PCI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PCI ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PCI.

_Signature:_

```
void set_other_config (session ref session_id, PCI ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PCI ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: PGPU

A physical GPU &#40;pGPU&#41;

### Fields for class: PGPU

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|compatibility&#95;metadata|`(string -> string) map`|_RO/runtime_   |PGPU metadata to determine whether a VGPU can migrate between two PGPUs|
|dom0&#95;access     |`pgpu_dom0_access  `|_RO/runtime_   |The accessibility of this device from dom0|
|enabled&#95;VGPU&#95;types|`VGPU_type ref set `|_RO/runtime_   |List of VGPU types which have been enabled for this PGPU|
|GPU&#95;group       |`GPU_group ref     `|_RO/constructor_|GPU group the pGPU is contained in      |
|host                |`host ref          `|_RO/runtime_   |Host that owns the GPU                  |
|is&#95;system&#95;display&#95;device|`bool              `|_RO/runtime_   |Is this device the system display device|
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|PCI                 |`PCI ref           `|_RO/constructor_|Link to underlying PCI device           |
|resident&#95;VGPUs  |`VGPU ref set      `|_RO/runtime_   |List of VGPUs running on this PGPU      |
|supported&#95;VGPU&#95;max&#95;capacities|`(VGPU_type ref -> int) map`|_RO/runtime_   |A map relating each VGPU type supported on this GPU to the maximum number of VGPUs of that type which can run simultaneously on this GPU|
|supported&#95;VGPU&#95;types|`VGPU_type ref set `|_RO/runtime_   |List of VGPU types supported by the underlying hardware|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: PGPU

#### RPC name: add&#95;enabled&#95;VGPU&#95;types

_Overview:_



_Signature:_

```
void add_enabled_VGPU_types (session ref session_id, PGPU ref self, VGPU_type ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU to which we are adding an enabled VGPU type|
|`VGPU_type ref               `|value                         |The VGPU type to enable                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PGPU.

_Signature:_

```
void add_to_other_config (session ref session_id, PGPU ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;dom0&#95;access

_Overview:_



_Signature:_

```
pgpu_dom0_access disable_dom0_access (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU to which dom0 will be denied access|

_Minimum Role:_ pool-operator

_Return Type:_ `pgpu_dom0_access`

The accessibility of this PGPU from dom0

#### RPC name: enable&#95;dom0&#95;access

_Overview:_



_Signature:_

```
pgpu_dom0_access enable_dom0_access (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU to which dom0 will be granted access|

_Minimum Role:_ pool-operator

_Return Type:_ `pgpu_dom0_access`

The accessibility of this PGPU from dom0

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PGPUs known to the system.

_Signature:_

```
PGPU ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PGPU references to PGPU records for all PGPUs known to the system.

_Signature:_

```
(PGPU ref -> PGPU record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PGPU ref -> PGPU record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PGPU instance with the specified UUID.

_Signature:_

```
PGPU ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

reference to the object

#### RPC name: get&#95;compatibility&#95;metadata

_Overview:_

Get the compatibility&#95;metadata field of the given PGPU.

_Signature:_

```
(string -> string) map get_compatibility_metadata (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;dom0&#95;access

_Overview:_

Get the dom0&#95;access field of the given PGPU.

_Signature:_

```
pgpu_dom0_access get_dom0_access (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pgpu_dom0_access`

value of the field

#### RPC name: get&#95;enabled&#95;VGPU&#95;types

_Overview:_

Get the enabled&#95;VGPU&#95;types field of the given PGPU.

_Signature:_

```
VGPU_type ref set get_enabled_VGPU_types (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

#### RPC name: get&#95;GPU&#95;group

_Overview:_

Get the GPU&#95;group field of the given PGPU.

_Signature:_

```
GPU_group ref get_GPU_group (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PGPU.

_Signature:_

```
host ref get_host (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;is&#95;system&#95;display&#95;device

_Overview:_

Get the is&#95;system&#95;display&#95;device field of the given PGPU.

_Signature:_

```
bool get_is_system_display_device (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PGPU.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given PGPU.

_Signature:_

```
PCI ref get_PCI (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PGPU.

_Signature:_

```
PGPU record get_record (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU record`

all fields from the object

#### RPC name: get&#95;remaining&#95;capacity

_Overview:_



_Signature:_

```
int get_remaining_capacity (session ref session_id, PGPU ref self, VGPU_type ref vgpu_type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU to query                       |
|`VGPU_type ref               `|vgpu&#95;type                 |The VGPU type for which we want to find the number of VGPUs which can still be started on this PGPU|

_Minimum Role:_ read-only

_Return Type:_ `int`

The number of VGPUs of the specified type which can still be started on this PGPU

#### RPC name: get&#95;resident&#95;VGPUs

_Overview:_

Get the resident&#95;VGPUs field of the given PGPU.

_Signature:_

```
VGPU ref set get_resident_VGPUs (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

#### RPC name: get&#95;supported&#95;VGPU&#95;max&#95;capacities

_Overview:_

Get the supported&#95;VGPU&#95;max&#95;capacities field of the given PGPU.

_Signature:_

```
(VGPU_type ref -> int) map get_supported_VGPU_max_capacities (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(VGPU_type ref -> int) map`

value of the field

#### RPC name: get&#95;supported&#95;VGPU&#95;types

_Overview:_

Get the supported&#95;VGPU&#95;types field of the given PGPU.

_Signature:_

```
VGPU_type ref set get_supported_VGPU_types (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PGPU.

_Signature:_

```
string get_uuid (session ref session_id, PGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;enabled&#95;VGPU&#95;types

_Overview:_



_Signature:_

```
void remove_enabled_VGPU_types (session ref session_id, PGPU ref self, VGPU_type ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU from which we are removing an enabled VGPU type|
|`VGPU_type ref               `|value                         |The VGPU type to disable                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PGPU.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PGPU ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;enabled&#95;VGPU&#95;types

_Overview:_



_Signature:_

```
void set_enabled_VGPU_types (session ref session_id, PGPU ref self, VGPU_type ref set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU on which we are enabling a set of VGPU types|
|`VGPU_type ref set           `|value                         |The VGPU types to enable                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;GPU&#95;group

_Overview:_



_Signature:_

```
void set_GPU_group (session ref session_id, PGPU ref self, GPU_group ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |The PGPU to move to a new group         |
|`GPU_group ref               `|value                         |The group to which the PGPU will be moved|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PGPU.

_Signature:_

```
void set_other_config (session ref session_id, PGPU ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PGPU ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: PIF

A physical network interface &#40;note separate VLANs are represented as several PIFs&#41;

### Fields for class: PIF

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|bond&#95;master&#95;of|`Bond ref set      `|_RO/runtime_   |Indicates this PIF represents the results of a bond|
|bond&#95;slave&#95;of|`Bond ref          `|_RO/runtime_   |Indicates which bond this interface is part of|
|capabilities        |`string set        `|_RO/runtime_   |Additional capabilities on the interface.|
|currently&#95;attached|`bool              `|_RO/runtime_   |true if this interface is online        |
|device              |`string            `|_RO/constructor_|machine&#45;readable name of the interface &#40;e.g. eth0&#41;|
|disallow&#95;unplug |`bool              `|_RO/runtime_   |Prevent this PIF from being unplugged; set this to notify the management tool&#45;stack that the PIF has a special use and should not be unplugged under any circumstances &#40;e.g. because you're running storage traffic over it&#41;|
|DNS                 |`string            `|_RO/runtime_   |Comma separated list of the IP addresses of the DNS servers to use|
|gateway             |`string            `|_RO/runtime_   |IP gateway                              |
|host                |`host ref          `|_RO/constructor_|physical machine to which this pif is connected|
|igmp&#95;snooping&#95;status|`pif_igmp_status   `|_RO/runtime_   |The IGMP snooping status of the corresponding network bridge|
|IP                  |`string            `|_RO/runtime_   |IP address                              |
|ip&#95;configuration&#95;mode|`ip_configuration_mode`|_RO/runtime_   |Sets if and how this interface gets an IP address|
|IPv6                |`string set        `|_RO/runtime_   |IPv6 address                            |
|ipv6&#95;configuration&#95;mode|`ipv6_configuration_mode`|_RO/runtime_   |Sets if and how this interface gets an IPv6 address|
|ipv6&#95;gateway    |`string            `|_RO/runtime_   |IPv6 gateway                            |
|MAC                 |`string            `|_RO/constructor_|ethernet MAC address of physical interface|
|managed             |`bool              `|_RO/constructor_|Indicates whether the interface is managed by xapi. If it is not, then xapi will not configure the interface, the commands PIF.plug/unplug/reconfigure&#95;ip&#40;v6&#41; cannot be used, nor can the interface be bonded or have VLANs based on top through xapi.|
|management          |`bool              `|_RO/runtime_   |Indicates whether the control software is listening for connections on this interface|
|metrics             |`PIF_metrics ref   `|_RO/runtime_   |metrics associated with this PIF        |
|MTU                 |`int               `|_RO/constructor_|MTU in octets                           |
|netmask             |`string            `|_RO/runtime_   |IP netmask                              |
|network             |`network ref       `|_RO/constructor_|virtual network to which this pif is connected|
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|PCI                 |`PCI ref           `|_RO/runtime_   |Link to underlying PCI device           |
|physical            |`bool              `|_RO/runtime_   |true if this represents a physical network interface|
|primary&#95;address&#95;type|`primary_address_type`|_RO/runtime_   |Which protocol should define the primary address of this interface|
|properties          |`(string -> string) map`|_RO/runtime_   |Additional configuration properties for the interface.|
|sriov&#95;logical&#95;PIF&#95;of|`network_sriov ref set`|_RO/runtime_   |Indicates which network&#95;sriov this interface is logical of|
|sriov&#95;physical&#95;PIF&#95;of|`network_sriov ref set`|_RO/runtime_   |Indicates which network&#95;sriov this interface is physical of|
|tunnel&#95;access&#95;PIF&#95;of|`tunnel ref set    `|_RO/runtime_   |Indicates to which tunnel this PIF gives access|
|tunnel&#95;transport&#95;PIF&#95;of|`tunnel ref set    `|_RO/runtime_   |Indicates to which tunnel this PIF provides transport|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VLAN                |`int               `|_RO/constructor_|VLAN tag for all traffic passing through this interface|
|VLAN&#95;master&#95;of|`VLAN ref          `|_RO/runtime_   |Indicates wich VLAN this interface receives untagged traffic from|
|VLAN&#95;slave&#95;of|`VLAN ref set      `|_RO/runtime_   |Indicates which VLANs this interface transmits tagged traffic to|

### RPCs associated with class: PIF

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PIF.

_Signature:_

```
void add_to_other_config (session ref session_id, PIF ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create&#95;VLAN

**This message is deprecated.**

_Overview:_

Create a VLAN interface from an existing physical interface. This call is deprecated: use VLAN.create instead

_Signature:_

```
PIF ref create_VLAN (session ref session_id, string device, network ref network, host ref host, int VLAN)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|device                        |physical interface on which to create the VLAN interface|
|`network ref                 `|network                       |network to which this interface should be connected|
|`host ref                    `|host                          |physical machine to which this PIF is connected|
|`int                         `|VLAN                          |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The reference of the created PIF object

_Possible Error Codes:_ `VLAN_TAG_INVALID`

#### RPC name: db&#95;forget

_Overview:_

Destroy a PIF database record.

_Signature:_

```
void db_forget (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |The ref of the PIF whose database record should be destroyed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: db&#95;introduce

_Overview:_

Create a new PIF record in the database only

_Signature:_

```
PIF ref db_introduce (session ref session_id, string device, network ref network, host ref host, string MAC, int MTU, int VLAN, bool physical, ip_configuration_mode ip_configuration_mode, string IP, string netmask, string gateway, string DNS, Bond ref bond_slave_of, VLAN ref VLAN_master_of, bool management, (string -> string) map other_config, bool disallow_unplug, ipv6_configuration_mode ipv6_configuration_mode, string set IPv6, string ipv6_gateway, primary_address_type primary_address_type, bool managed, (string -> string) map properties)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|device                        |                                        |
|`network ref                 `|network                       |                                        |
|`host ref                    `|host                          |                                        |
|`string                      `|MAC                           |                                        |
|`int                         `|MTU                           |                                        |
|`int                         `|VLAN                          |                                        |
|`bool                        `|physical                      |                                        |
|`ip_configuration_mode       `|ip&#95;configuration&#95;mode |                                        |
|`string                      `|IP                            |                                        |
|`string                      `|netmask                       |                                        |
|`string                      `|gateway                       |                                        |
|`string                      `|DNS                           |                                        |
|`Bond ref                    `|bond&#95;slave&#95;of         |                                        |
|`VLAN ref                    `|VLAN&#95;master&#95;of        |                                        |
|`bool                        `|management                    |                                        |
|`(string -> string) map      `|other&#95;config              |                                        |
|`bool                        `|disallow&#95;unplug           |                                        |
|`ipv6_configuration_mode     `|ipv6&#95;configuration&#95;mode|                                        |
|`string set                  `|IPv6                          |                                        |
|`string                      `|ipv6&#95;gateway              |                                        |
|`primary_address_type        `|primary&#95;address&#95;type  |                                        |
|`bool                        `|managed                       |                                        |
|`(string -> string) map      `|properties                    |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The ref of the newly created PIF record.

#### RPC name: destroy

**This message is deprecated.**

_Overview:_

Destroy the PIF object &#40;provided it is a VLAN interface&#41;. This call is deprecated: use VLAN.destroy or Bond.destroy instead

_Signature:_

```
void destroy (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to destroy               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_IS_PHYSICAL`

#### RPC name: forget

_Overview:_

Destroy the PIF object matching a particular network interface

_Signature:_

```
void forget (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |The PIF object to destroy               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PIF_TUNNEL_STILL_EXISTS`, `CLUSTERING_ENABLED`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PIFs known to the system.

_Signature:_

```
PIF ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PIF ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PIF references to PIF records for all PIFs known to the system.

_Signature:_

```
(PIF ref -> PIF record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PIF ref -> PIF record) map`

records of all objects

#### RPC name: get&#95;bond&#95;master&#95;of

_Overview:_

Get the bond&#95;master&#95;of field of the given PIF.

_Signature:_

```
Bond ref set get_bond_master_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref set`

value of the field

#### RPC name: get&#95;bond&#95;slave&#95;of

_Overview:_

Get the bond&#95;slave&#95;of field of the given PIF.

_Signature:_

```
Bond ref get_bond_slave_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `Bond ref`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PIF instance with the specified UUID.

_Signature:_

```
PIF ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

reference to the object

#### RPC name: get&#95;capabilities

_Overview:_

Get the capabilities field of the given PIF.

_Signature:_

```
string set get_capabilities (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PIF.

_Signature:_

```
bool get_currently_attached (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device

_Overview:_

Get the device field of the given PIF.

_Signature:_

```
string get_device (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;disallow&#95;unplug

_Overview:_

Get the disallow&#95;unplug field of the given PIF.

_Signature:_

```
bool get_disallow_unplug (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;DNS

_Overview:_

Get the DNS field of the given PIF.

_Signature:_

```
string get_DNS (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;gateway

_Overview:_

Get the gateway field of the given PIF.

_Signature:_

```
string get_gateway (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PIF.

_Signature:_

```
host ref get_host (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;igmp&#95;snooping&#95;status

_Overview:_

Get the igmp&#95;snooping&#95;status field of the given PIF.

_Signature:_

```
pif_igmp_status get_igmp_snooping_status (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pif_igmp_status`

value of the field

#### RPC name: get&#95;IP

_Overview:_

Get the IP field of the given PIF.

_Signature:_

```
string get_IP (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;ip&#95;configuration&#95;mode

_Overview:_

Get the ip&#95;configuration&#95;mode field of the given PIF.

_Signature:_

```
ip_configuration_mode get_ip_configuration_mode (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `ip_configuration_mode`

value of the field

#### RPC name: get&#95;IPv6

_Overview:_

Get the IPv6 field of the given PIF.

_Signature:_

```
string set get_IPv6 (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ipv6&#95;configuration&#95;mode

_Overview:_

Get the ipv6&#95;configuration&#95;mode field of the given PIF.

_Signature:_

```
ipv6_configuration_mode get_ipv6_configuration_mode (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `ipv6_configuration_mode`

value of the field

#### RPC name: get&#95;ipv6&#95;gateway

_Overview:_

Get the ipv6&#95;gateway field of the given PIF.

_Signature:_

```
string get_ipv6_gateway (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;MAC

_Overview:_

Get the MAC field of the given PIF.

_Signature:_

```
string get_MAC (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given PIF.

_Signature:_

```
bool get_managed (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;management

_Overview:_

Get the management field of the given PIF.

_Signature:_

```
bool get_management (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;metrics

_Overview:_

Get the metrics field of the given PIF.

_Signature:_

```
PIF_metrics ref get_metrics (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref`

value of the field

#### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given PIF.

_Signature:_

```
int get_MTU (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;netmask

_Overview:_

Get the netmask field of the given PIF.

_Signature:_

```
string get_netmask (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;network

_Overview:_

Get the network field of the given PIF.

_Signature:_

```
network ref get_network (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PIF.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given PIF.

_Signature:_

```
PCI ref get_PCI (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

#### RPC name: get&#95;physical

_Overview:_

Get the physical field of the given PIF.

_Signature:_

```
bool get_physical (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;primary&#95;address&#95;type

_Overview:_

Get the primary&#95;address&#95;type field of the given PIF.

_Signature:_

```
primary_address_type get_primary_address_type (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `primary_address_type`

value of the field

#### RPC name: get&#95;properties

_Overview:_

Get the properties field of the given PIF.

_Signature:_

```
(string -> string) map get_properties (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PIF.

_Signature:_

```
PIF record get_record (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF record`

all fields from the object

#### RPC name: get&#95;sriov&#95;logical&#95;PIF&#95;of

_Overview:_

Get the sriov&#95;logical&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
network_sriov ref set get_sriov_logical_PIF_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

value of the field

#### RPC name: get&#95;sriov&#95;physical&#95;PIF&#95;of

_Overview:_

Get the sriov&#95;physical&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
network_sriov ref set get_sriov_physical_PIF_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network_sriov ref set`

value of the field

#### RPC name: get&#95;tunnel&#95;access&#95;PIF&#95;of

_Overview:_

Get the tunnel&#95;access&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
tunnel ref set get_tunnel_access_PIF_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

value of the field

#### RPC name: get&#95;tunnel&#95;transport&#95;PIF&#95;of

_Overview:_

Get the tunnel&#95;transport&#95;PIF&#95;of field of the given PIF.

_Signature:_

```
tunnel ref set get_tunnel_transport_PIF_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PIF.

_Signature:_

```
string get_uuid (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VLAN

_Overview:_

Get the VLAN field of the given PIF.

_Signature:_

```
int get_VLAN (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;VLAN&#95;master&#95;of

_Overview:_

Get the VLAN&#95;master&#95;of field of the given PIF.

_Signature:_

```
VLAN ref get_VLAN_master_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref`

value of the field

#### RPC name: get&#95;VLAN&#95;slave&#95;of

_Overview:_

Get the VLAN&#95;slave&#95;of field of the given PIF.

_Signature:_

```
VLAN ref set get_VLAN_slave_of (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref set`

value of the field

#### RPC name: introduce

_Overview:_

Create a PIF object matching a particular network interface

_Signature:_

```
PIF ref introduce (session ref session_id, host ref host, string MAC, string device, bool managed)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host on which the interface exists  |
|`string                      `|MAC                           |The MAC address of the interface        |
|`string                      `|device                        |The device name to use for the interface|
|`bool                        `|managed                       |Indicates whether the interface is managed by xapi &#40;defaults to "true"&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref`

The reference of the created PIF object

#### RPC name: plug

_Overview:_

Attempt to bring up a physical interface

_Signature:_

```
void plug (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to plug                  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `TRANSPORT_PIF_NOT_CONFIGURED`

#### RPC name: reconfigure&#95;ip

_Overview:_

Reconfigure the IP address settings for this interface

_Signature:_

```
void reconfigure_ip (session ref session_id, PIF ref self, ip_configuration_mode mode, string IP, string netmask, string gateway, string DNS)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to reconfigure           |
|`ip_configuration_mode       `|mode                          |whether to use dynamic/static/no&#45;assignment|
|`string                      `|IP                            |the new IP address                      |
|`string                      `|netmask                       |the new netmask                         |
|`string                      `|gateway                       |the new gateway                         |
|`string                      `|DNS                           |the new DNS settings                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTERING_ENABLED`

#### RPC name: reconfigure&#95;ipv6

_Overview:_

Reconfigure the IPv6 address settings for this interface

_Signature:_

```
void reconfigure_ipv6 (session ref session_id, PIF ref self, ipv6_configuration_mode mode, string IPv6, string gateway, string DNS)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to reconfigure           |
|`ipv6_configuration_mode     `|mode                          |whether to use dynamic/static/no&#45;assignment|
|`string                      `|IPv6                          |the new IPv6 address &#40;in &lt;addr&gt;/&lt;prefix length&gt; format&#41;|
|`string                      `|gateway                       |the new gateway                         |
|`string                      `|DNS                           |the new DNS settings                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `CLUSTERING_ENABLED`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PIF ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: scan

_Overview:_

Scan for physical interfaces on a host and create PIF objects to represent them

_Signature:_

```
void scan (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host on which to scan               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;disallow&#95;unplug

_Overview:_

Set whether unplugging the PIF is allowed

_Signature:_

```
void set_disallow_unplug (session ref session_id, PIF ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |Reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OTHER_OPERATION_IN_PROGRESS`, `CLUSTERING_ENABLED`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PIF.

_Signature:_

```
void set_other_config (session ref session_id, PIF ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;primary&#95;address&#95;type

_Overview:_

Change the primary address type used by this PIF

_Signature:_

```
void set_primary_address_type (session ref session_id, PIF ref self, primary_address_type primary_address_type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to reconfigure           |
|`primary_address_type        `|primary&#95;address&#95;type  |Whether to prefer IPv4 or IPv6 connections|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;property

_Overview:_

Set the value of a property of the PIF

_Signature:_

```
void set_property (session ref session_id, PIF ref self, string name, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |The PIF                                 |
|`string                      `|name                          |The property name                       |
|`string                      `|value                         |The property value                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: unplug

_Overview:_

Attempt to bring down a physical interface

_Signature:_

```
void unplug (session ref session_id, PIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|self                          |the PIF object to unplug                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HA_OPERATION_WOULD_BREAK_FAILOVER_PLAN`, `VIF_IN_USE`, `PIF_DOES_NOT_ALLOW_UNPLUG`, `PIF_HAS_FCOE_SR_IN_USE`

## Class: PIF&#95;metrics

The metrics associated with a physical network interface

### Fields for class: PIF&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|carrier             |`bool              `|_RO/runtime_   |Report if the PIF got a carrier or not  |
|device&#95;id       |`string            `|_RO/runtime_   |Report device ID                        |
|device&#95;name     |`string            `|_RO/runtime_   |Report device name                      |
|duplex              |`bool              `|_RO/runtime_   |Full duplex capability of the link &#40;if available&#41;|
|io&#95;read&#95;kbs |`float             `|_RO/runtime_   |**Removed**. Read bandwidth &#40;KiB/s&#41;|
|io&#95;write&#95;kbs|`float             `|_RO/runtime_   |**Removed**. Write bandwidth &#40;KiB/s&#41;|
|last&#95;updated    |`datetime          `|_RO/runtime_   |Time at which this information was last updated|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|pci&#95;bus&#95;path|`string            `|_RO/runtime_   |PCI bus path of the pif &#40;if available&#41;|
|speed               |`int               `|_RO/runtime_   |Speed of the link &#40;if available&#41;|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vendor&#95;id       |`string            `|_RO/runtime_   |Report vendor ID                        |
|vendor&#95;name     |`string            `|_RO/runtime_   |Report vendor name                      |

### RPCs associated with class: PIF&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, PIF_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PIF&#95;metrics instances known to the system.

_Signature:_

```
PIF_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PIF&#95;metrics references to PIF&#95;metrics records for all PIF&#95;metrics instances known to the system.

_Signature:_

```
(PIF_metrics ref -> PIF_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PIF_metrics ref -> PIF_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PIF&#95;metrics instance with the specified UUID.

_Signature:_

```
PIF_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics ref`

reference to the object

#### RPC name: get&#95;carrier

_Overview:_

Get the carrier field of the given PIF&#95;metrics.

_Signature:_

```
bool get_carrier (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device&#95;id

_Overview:_

Get the device&#95;id field of the given PIF&#95;metrics.

_Signature:_

```
string get_device_id (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;device&#95;name

_Overview:_

Get the device&#95;name field of the given PIF&#95;metrics.

_Signature:_

```
string get_device_name (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;duplex

_Overview:_

Get the duplex field of the given PIF&#95;metrics.

_Signature:_

```
bool get_duplex (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;io&#95;read&#95;kbs

**This message is removed.**

_Overview:_

Get the io/read&#95;kbs field of the given PIF&#95;metrics.

_Signature:_

```
float get_io_read_kbs (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;io&#95;write&#95;kbs

**This message is removed.**

_Overview:_

Get the io/write&#95;kbs field of the given PIF&#95;metrics.

_Signature:_

```
float get_io_write_kbs (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given PIF&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;pci&#95;bus&#95;path

_Overview:_

Get the pci&#95;bus&#95;path field of the given PIF&#95;metrics.

_Signature:_

```
string get_pci_bus_path (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PIF&#95;metrics.

_Signature:_

```
PIF_metrics record get_record (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF_metrics record`

all fields from the object

#### RPC name: get&#95;speed

_Overview:_

Get the speed field of the given PIF&#95;metrics.

_Signature:_

```
int get_speed (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PIF&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;id

_Overview:_

Get the vendor&#95;id field of the given PIF&#95;metrics.

_Signature:_

```
string get_vendor_id (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given PIF&#95;metrics.

_Signature:_

```
string get_vendor_name (session ref session_id, PIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PIF&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PIF_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PIF&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, PIF_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF_metrics ref             `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: pool

Pool&#45;wide information

### Fields for class: pool

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`pool_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|blobs               |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this pool  |
|cpu&#95;info        |`(string -> string) map`|_RO/runtime_   |Details about the physical CPUs on the pool|
|crash&#95;dump&#95;SR|`SR ref            `|_RW_           |The SR in which VDIs for crash dumps are created|
|current&#95;operations|`(string -> pool_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|default&#95;SR      |`SR ref            `|_RW_           |Default SR for VDIs                     |
|guest&#95;agent&#95;config|`(string -> string) map`|_RO/runtime_   |Pool&#45;wide guest agent configuration information|
|gui&#95;config      |`(string -> string) map`|_RW_           |gui&#45;specific configuration for pool |
|ha&#95;allow&#95;overcommit|`bool              `|_RW_           |If set to false then operations which would cause the Pool to become overcommitted will be blocked.|
|ha&#95;cluster&#95;stack|`string            `|_RO/runtime_   |The HA cluster stack that is currently in use. Only valid when HA is enabled.|
|ha&#95;configuration|`(string -> string) map`|_RO/runtime_   |The current HA configuration            |
|ha&#95;enabled      |`bool              `|_RO/runtime_   |true if HA is enabled on the pool, false otherwise|
|ha&#95;host&#95;failures&#95;to&#95;tolerate|`int               `|_RO/runtime_   |Number of host failures to tolerate before the Pool is declared to be overcommitted|
|ha&#95;overcommitted|`bool              `|_RO/runtime_   |True if the Pool is considered to be overcommitted i.e. if there exist insufficient physical resources to tolerate the configured number of host failures|
|ha&#95;plan&#95;exists&#95;for|`int               `|_RO/runtime_   |Number of future host failures we have managed to find a plan for. Once this reaches zero any future host failures will cause the failure of protected VMs.|
|ha&#95;statefiles   |`string set        `|_RO/runtime_   |HA statefile VDIs in use                |
|health&#95;check&#95;config|`(string -> string) map`|_RW_           |Configuration for the automatic health check feature|
|igmp&#95;snooping&#95;enabled|`bool              `|_RO/runtime_   |true if IGMP snooping is enabled in the pool, false otherwise.|
|is&#95;psr&#95;pending|`bool              `|_RW_           |True if either a PSR is running or we are waiting for a PSR to be re&#45;run|
|live&#95;patching&#95;disabled|`bool              `|_RW_           |The pool&#45;wide flag to show if the live patching feauture is disabled or not.|
|master              |`host ref          `|_RO/runtime_   |The host that is pool master            |
|metadata&#95;VDIs   |`VDI ref set       `|_RO/runtime_   |The set of currently known metadata VDIs for this pool|
|name&#95;description|`string            `|_RW_           |Description                             |
|name&#95;label      |`string            `|_RW_           |Short name                              |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|policy&#95;no&#95;vendor&#95;device|`bool              `|_RW_           |The pool&#45;wide policy for clients on whether to use the vendor device or not on newly created VMs. This field will also be consulted if the 'has&#95;vendor&#95;device' field is not specified in the VM.create call.|
|redo&#95;log&#95;enabled|`bool              `|_RO/runtime_   |true a redo&#45;log is to be used other than when HA is enabled, false otherwise|
|redo&#95;log&#95;vdi|`VDI ref           `|_RO/runtime_   |indicates the VDI to use for the redo&#45;log other than when HA is enabled|
|restrictions        |`(string -> string) map`|_RO/runtime_   |Pool&#45;wide restrictions currently in effect|
|suspend&#95;image&#95;SR|`SR ref            `|_RW_           |The SR in which VDIs for suspend images are created|
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|uefi&#95;certificates|`string            `|_RW_           |The UEFI certificates allowing Secure Boot|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vswitch&#95;controller|`string            `|_RO/runtime_   |**Deprecated**. address of the vswitch controller|
|wlb&#95;enabled     |`bool              `|_RW_           |true if workload balancing is enabled on the pool, false otherwise|
|wlb&#95;url         |`string            `|_RO/runtime_   |Url for the configured workload balancing host|
|wlb&#95;username    |`string            `|_RO/runtime_   |Username for accessing the workload balancing host|
|wlb&#95;verify&#95;cert|`bool              `|_RW_           |true if communication with the WLB server should enforce TLS certificate verification.|

### RPCs associated with class: pool

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given pool.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, pool ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;guest&#95;agent&#95;config

_Overview:_

Add a key&#45;value pair to the pool&#45;wide guest agent configuration

_Signature:_

```
void add_to_guest_agent_config (session ref session_id, pool ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |The pool                                |
|`string                      `|key                           |The key to add                          |
|`string                      `|value                         |The value to add                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;gui&#95;config

_Overview:_

Add the given key&#45;value pair to the gui&#95;config field of the given pool.

_Signature:_

```
void add_to_gui_config (session ref session_id, pool ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;health&#95;check&#95;config

_Overview:_

Add the given key&#45;value pair to the health&#95;check&#95;config field of the given pool.

_Signature:_

```
void add_to_health_check_config (session ref session_id, pool ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given pool.

_Signature:_

```
void add_to_other_config (session ref session_id, pool ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: apply&#95;edition

_Overview:_

Apply an edition to all hosts in the pool

_Signature:_

```
void apply_edition (session ref session_id, pool ref self, string edition)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |Reference to the pool                   |
|`string                      `|edition                       |The requested edition                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: certificate&#95;install

_Overview:_

Install a TLS CA certificate, pool&#45;wide.

_Signature:_

```
void certificate_install (session ref session_id, string name, string cert)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name                          |A name to give the certificate          |
|`string                      `|cert                          |The certificate                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: certificate&#95;list

_Overview:_

List the names of all installed TLS CA certificates.

_Signature:_

```
string set certificate_list (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `string set`

All installed certificates

#### RPC name: certificate&#95;sync

_Overview:_

Copy the TLS CA certificates and CRLs of the master to all slaves.

_Signature:_

```
void certificate_sync (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: certificate&#95;uninstall

_Overview:_

Remove a pool&#45;wide TLS CA certificate.

_Signature:_

```
void certificate_uninstall (session ref session_id, string name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name                          |The certificate name                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this pool

_Signature:_

```
blob ref create_new_blob (session ref session_id, pool ref pool, string name, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|pool                          |The pool                                |
|`string                      `|name                          |The name associated with the blob       |
|`string                      `|mime&#95;type                 |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

#### RPC name: create&#95;VLAN

_Overview:_

Create PIFs, mapping a network to the same physical interface/VLAN on each host. This call is deprecated: use Pool.create&#95;VLAN&#95;from&#95;PIF instead.

_Signature:_

```
PIF ref set create_VLAN (session ref session_id, string device, network ref network, int VLAN)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|device                        |physical interface on which to create the VLAN interface|
|`network ref                 `|network                       |network to which this interface should be connected|
|`int                         `|VLAN                          |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref set`

The references of the created PIF objects

_Possible Error Codes:_ `VLAN_TAG_INVALID`

#### RPC name: create&#95;VLAN&#95;from&#95;PIF

_Overview:_

Create a pool&#45;wide VLAN by taking the PIF.

_Signature:_

```
PIF ref set create_VLAN_from_PIF (session ref session_id, PIF ref pif, network ref network, int VLAN)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|pif                           |physical interface on any particular host, that identifies the PIF on which to create the &#40;pool&#45;wide&#41; VLAN interface|
|`network ref                 `|network                       |network to which this interface should be connected|
|`int                         `|VLAN                          |VLAN tag for the new interface          |

_Minimum Role:_ pool-operator

_Return Type:_ `PIF ref set`

The references of the created PIF objects

_Possible Error Codes:_ `VLAN_TAG_INVALID`

#### RPC name: crl&#95;install

_Overview:_

Install a TLS Certificate Revocation List, pool&#45;wide.

_Signature:_

```
void crl_install (session ref session_id, string name, string cert)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name                          |A name to give the CRL                  |
|`string                      `|cert                          |The CRL                                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: crl&#95;list

_Overview:_

List the names of all installed TLS Certificate Revocation Lists.

_Signature:_

```
string set crl_list (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `string set`

The names of all installed CRLs

#### RPC name: crl&#95;uninstall

_Overview:_

Remove a pool&#45;wide TLS Certificate Revocation List.

_Signature:_

```
void crl_uninstall (session ref session_id, string name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name                          |The CRL name                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: deconfigure&#95;wlb

_Overview:_

Permanently deconfigures workload balancing monitoring on this pool

_Signature:_

```
void deconfigure_wlb (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: designate&#95;new&#95;master

_Overview:_

Perform an orderly handover of the role of master to the referenced host.

_Signature:_

```
void designate_new_master (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host who should become the new master|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: detect&#95;nonhomogeneous&#95;external&#95;auth

_Overview:_

This call asynchronously detects if the external authentication configuration in any slave is different from that in the master and raises appropriate alerts

_Signature:_

```
void detect_nonhomogeneous_external_auth (session ref session_id, pool ref pool)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|pool                          |The pool where to detect non&#45;homogeneous external authentication configuration|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;external&#95;auth

_Overview:_

This call disables external authentication on all the hosts of the pool

_Signature:_

```
void disable_external_auth (session ref session_id, pool ref pool, (string -> string) map config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|pool                          |The pool whose external authentication should be disabled|
|`(string -> string) map      `|config                        |Optional parameters as a list of key&#45;values containing the configuration data|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: disable&#95;ha

_Overview:_

Turn off High Availability mode

_Signature:_

```
void disable_ha (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;local&#95;storage&#95;caching

_Overview:_

This call disables pool&#45;wide local storage caching

_Signature:_

```
void disable_local_storage_caching (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |Reference to the pool                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;redo&#95;log

_Overview:_

Disable the redo log if in use, unless HA is enabled.

_Signature:_

```
void disable_redo_log (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: disable&#95;ssl&#95;legacy

**This message is deprecated.**

_Overview:_

Sets ssl&#95;legacy false on each host, pool&#45;master last. See Host.ssl&#95;legacy and Host.set&#95;ssl&#95;legacy.

_Signature:_

```
void disable_ssl_legacy (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |&#40;ignored&#41;                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: eject

_Overview:_

Instruct a pool master to eject a host from the pool

_Signature:_

```
void eject (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to eject                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: emergency&#95;reset&#95;master

_Overview:_

Instruct a slave already in a pool that the master has changed

_Signature:_

```
void emergency_reset_master (session ref session_id, string master_address)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|master&#95;address            |The hostname of the master              |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: emergency&#95;transition&#95;to&#95;master

_Overview:_

Instruct host that's currently a slave to transition to being master

_Signature:_

```
void emergency_transition_to_master (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;external&#95;auth

_Overview:_

This call enables external authentication on all the hosts of the pool

_Signature:_

```
void enable_external_auth (session ref session_id, pool ref pool, (string -> string) map config, string service_name, string auth_type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|pool                          |The pool whose external authentication should be enabled|
|`(string -> string) map      `|config                        |A list of key&#45;values containing the configuration data|
|`string                      `|service&#95;name              |The name of the service                 |
|`string                      `|auth&#95;type                 |The type of authentication &#40;e.g. AD for Active Directory&#41;|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: enable&#95;ha

_Overview:_

Turn on High Availability mode

_Signature:_

```
void enable_ha (session ref session_id, SR ref set heartbeat_srs, (string -> string) map configuration)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref set                  `|heartbeat&#95;srs             |Set of SRs to use for storage heartbeating|
|`(string -> string) map      `|configuration                 |Detailed HA configuration to apply      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;local&#95;storage&#95;caching

_Overview:_

This call attempts to enable pool&#45;wide local storage caching

_Signature:_

```
void enable_local_storage_caching (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |Reference to the pool                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;redo&#95;log

_Overview:_

Enable the redo log on the given SR and start using it, unless HA is enabled.

_Signature:_

```
void enable_redo_log (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |SR to hold the redo log.                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;ssl&#95;legacy

**This message is removed.**

_Overview:_

Sets ssl&#95;legacy true on each host, pool&#45;master last. See Host.ssl&#95;legacy and Host.set&#95;ssl&#95;legacy.

_Signature:_

```
void enable_ssl_legacy (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |&#40;ignored&#41;                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the pools known to the system.

_Signature:_

```
pool ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `pool ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of pool references to pool records for all pools known to the system.

_Signature:_

```
(pool ref -> pool record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(pool ref -> pool record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given pool.

_Signature:_

```
pool_allowed_operations set get_allowed_operations (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_allowed_operations set`

value of the field

#### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given pool.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the pool instance with the specified UUID.

_Signature:_

```
pool ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `pool ref`

reference to the object

#### RPC name: get&#95;cpu&#95;info

_Overview:_

Get the cpu&#95;info field of the given pool.

_Signature:_

```
(string -> string) map get_cpu_info (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;crash&#95;dump&#95;SR

_Overview:_

Get the crash&#95;dump&#95;SR field of the given pool.

_Signature:_

```
SR ref get_crash_dump_SR (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given pool.

_Signature:_

```
(string -> pool_allowed_operations) map get_current_operations (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> pool_allowed_operations) map`

value of the field

#### RPC name: get&#95;default&#95;SR

_Overview:_

Get the default&#95;SR field of the given pool.

_Signature:_

```
SR ref get_default_SR (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;guest&#95;agent&#95;config

_Overview:_

Get the guest&#95;agent&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_guest_agent_config (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;gui&#95;config

_Overview:_

Get the gui&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_gui_config (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;ha&#95;allow&#95;overcommit

_Overview:_

Get the ha&#95;allow&#95;overcommit field of the given pool.

_Signature:_

```
bool get_ha_allow_overcommit (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;ha&#95;cluster&#95;stack

_Overview:_

Get the ha&#95;cluster&#95;stack field of the given pool.

_Signature:_

```
string get_ha_cluster_stack (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;ha&#95;configuration

_Overview:_

Get the ha&#95;configuration field of the given pool.

_Signature:_

```
(string -> string) map get_ha_configuration (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;ha&#95;enabled

_Overview:_

Get the ha&#95;enabled field of the given pool.

_Signature:_

```
bool get_ha_enabled (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;ha&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Get the ha&#95;host&#95;failures&#95;to&#95;tolerate field of the given pool.

_Signature:_

```
int get_ha_host_failures_to_tolerate (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;ha&#95;overcommitted

_Overview:_

Get the ha&#95;overcommitted field of the given pool.

_Signature:_

```
bool get_ha_overcommitted (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;ha&#95;plan&#95;exists&#95;for

_Overview:_

Get the ha&#95;plan&#95;exists&#95;for field of the given pool.

_Signature:_

```
int get_ha_plan_exists_for (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;ha&#95;statefiles

_Overview:_

Get the ha&#95;statefiles field of the given pool.

_Signature:_

```
string set get_ha_statefiles (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;health&#95;check&#95;config

_Overview:_

Get the health&#95;check&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_health_check_config (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;igmp&#95;snooping&#95;enabled

_Overview:_

Get the igmp&#95;snooping&#95;enabled field of the given pool.

_Signature:_

```
bool get_igmp_snooping_enabled (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;psr&#95;pending

_Overview:_

Get the is&#95;psr&#95;pending field of the given pool.

_Signature:_

```
bool get_is_psr_pending (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;license&#95;state

_Overview:_

This call returns the license state for the pool

_Signature:_

```
(string -> string) map get_license_state (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |Reference to the pool                   |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

The pool's license state

#### RPC name: get&#95;live&#95;patching&#95;disabled

_Overview:_

Get the live&#95;patching&#95;disabled field of the given pool.

_Signature:_

```
bool get_live_patching_disabled (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;master

_Overview:_

Get the master field of the given pool.

_Signature:_

```
host ref get_master (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;metadata&#95;VDIs

_Overview:_

Get the metadata&#95;VDIs field of the given pool.

_Signature:_

```
VDI ref set get_metadata_VDIs (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name&#95;description field of the given pool.

_Signature:_

```
string get_name_description (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name&#95;label field of the given pool.

_Signature:_

```
string get_name_label (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given pool.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;policy&#95;no&#95;vendor&#95;device

_Overview:_

Get the policy&#95;no&#95;vendor&#95;device field of the given pool.

_Signature:_

```
bool get_policy_no_vendor_device (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given pool.

_Signature:_

```
pool record get_record (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool record`

all fields from the object

#### RPC name: get&#95;redo&#95;log&#95;enabled

_Overview:_

Get the redo&#95;log&#95;enabled field of the given pool.

_Signature:_

```
bool get_redo_log_enabled (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;redo&#95;log&#95;vdi

_Overview:_

Get the redo&#95;log&#95;vdi field of the given pool.

_Signature:_

```
VDI ref get_redo_log_vdi (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;restrictions

_Overview:_

Get the restrictions field of the given pool.

_Signature:_

```
(string -> string) map get_restrictions (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;suspend&#95;image&#95;SR

_Overview:_

Get the suspend&#95;image&#95;SR field of the given pool.

_Signature:_

```
SR ref get_suspend_image_SR (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given pool.

_Signature:_

```
string set get_tags (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;uefi&#95;certificates

_Overview:_

Get the uefi&#95;certificates field of the given pool.

_Signature:_

```
string get_uefi_certificates (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given pool.

_Signature:_

```
string get_uuid (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vswitch&#95;controller

**This message is deprecated.**

_Overview:_

Get the vswitch&#95;controller field of the given pool.

_Signature:_

```
string get_vswitch_controller (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;wlb&#95;enabled

_Overview:_

Get the wlb&#95;enabled field of the given pool.

_Signature:_

```
bool get_wlb_enabled (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;wlb&#95;url

_Overview:_

Get the wlb&#95;url field of the given pool.

_Signature:_

```
string get_wlb_url (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;wlb&#95;username

_Overview:_

Get the wlb&#95;username field of the given pool.

_Signature:_

```
string get_wlb_username (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;wlb&#95;verify&#95;cert

_Overview:_

Get the wlb&#95;verify&#95;cert field of the given pool.

_Signature:_

```
bool get_wlb_verify_cert (session ref session_id, pool ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: ha&#95;compute&#95;hypothetical&#95;max&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Returns the maximum number of host failures we could tolerate before we would be unable to restart the provided VMs

_Signature:_

```
int ha_compute_hypothetical_max_host_failures_to_tolerate (session ref session_id, (VM ref -> string) map configuration)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`(VM ref -> string) map      `|configuration                 |Map of protected VM reference to restart priority|

_Minimum Role:_ read-only

_Return Type:_ `int`

maximum value for ha&#95;host&#95;failures&#95;to&#95;tolerate given provided configuration

#### RPC name: ha&#95;compute&#95;max&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Returns the maximum number of host failures we could tolerate before we would be unable to restart configured VMs

_Signature:_

```
int ha_compute_max_host_failures_to_tolerate (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `int`

maximum value for ha&#95;host&#95;failures&#95;to&#95;tolerate given current configuration

#### RPC name: ha&#95;compute&#95;vm&#95;failover&#95;plan

_Overview:_

Return a VM failover plan assuming a given subset of hosts fail

_Signature:_

```
(VM ref -> (string -> string) map) map ha_compute_vm_failover_plan (session ref session_id, host ref set failed_hosts, VM ref set failed_vms)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref set                `|failed&#95;hosts              |The set of hosts to assume have failed  |
|`VM ref set                  `|failed&#95;vms                |The set of VMs to restart               |

_Minimum Role:_ pool-operator

_Return Type:_ `(VM ref -> (string -> string) map) map`

VM failover plan: a map of VM to host to restart the host on

#### RPC name: ha&#95;failover&#95;plan&#95;exists

_Overview:_

Returns true if a VM failover plan exists for up to 'n' host failures

_Signature:_

```
bool ha_failover_plan_exists (session ref session_id, int n)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`int                         `|n                             |The number of host failures to plan for |

_Minimum Role:_ pool-operator

_Return Type:_ `bool`

true if a failover plan exists for the supplied number of host failures

#### RPC name: ha&#95;prevent&#95;restarts&#95;for

_Overview:_

When this call returns the VM restart logic will not run for the requested number of seconds. If the argument is zero then the restart thread is immediately unblocked

_Signature:_

```
void ha_prevent_restarts_for (session ref session_id, int seconds)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`int                         `|seconds                       |The number of seconds to block the restart thread for|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: has&#95;extension

_Overview:_

Return true if the extension is available on the pool

_Signature:_

```
bool has_extension (session ref session_id, pool ref self, string name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |The pool                                |
|`string                      `|name                          |The name of the API call                |

_Minimum Role:_ pool-admin

_Return Type:_ `bool`

True if the extension exists, false otherwise

#### RPC name: initialize&#95;wlb

_Overview:_

Initializes workload balancing monitoring on this pool with the specified wlb server

_Signature:_

```
void initialize_wlb (session ref session_id, string wlb_url, string wlb_username, string wlb_password, string xenserver_username, string xenserver_password)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|wlb&#95;url                   |The ip address and port to use when accessing the wlb server|
|`string                      `|wlb&#95;username              |The username used to authenticate with the wlb server|
|`string                      `|wlb&#95;password              |The password used to authenticate with the wlb server|
|`string                      `|xenserver&#95;username        |The username used by the wlb server to authenticate with the xenserver|
|`string                      `|xenserver&#95;password        |The password used by the wlb server to authenticate with the xenserver|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: join

_Overview:_

Instruct host to join a new pool

_Signature:_

```
void join (session ref session_id, string master_address, string master_username, string master_password)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|master&#95;address            |The hostname of the master of the pool to join|
|`string                      `|master&#95;username           |The username of the master &#40;for initial authentication&#41;|
|`string                      `|master&#95;password           |The password for the master &#40;for initial authentication&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `JOINING_HOST_CANNOT_CONTAIN_SHARED_SRS`

#### RPC name: join&#95;force

_Overview:_

Instruct host to join a new pool

_Signature:_

```
void join_force (session ref session_id, string master_address, string master_username, string master_password)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|master&#95;address            |The hostname of the master of the pool to join|
|`string                      `|master&#95;username           |The username of the master &#40;for initial authentication&#41;|
|`string                      `|master&#95;password           |The password for the master &#40;for initial authentication&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: management&#95;reconfigure

_Overview:_

Reconfigure the management network interface for all Hosts in the Pool

_Signature:_

```
void management_reconfigure (session ref session_id, network ref network)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`network ref                 `|network                       |The network                             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `HA_IS_ENABLED`, `PIF_NOT_PRESENT`, `CANNOT_PLUG_BOND_SLAVE`, `PIF_INCOMPATIBLE_PRIMARY_ADDRESS_TYPE`, `PIF_HAS_NO_NETWORK_CONFIGURATION`, `PIF_HAS_NO_V6_NETWORK_CONFIGURATION`

#### RPC name: recover&#95;slaves

_Overview:_

Instruct a pool master, M, to try and contact its slaves and, if slaves are in emergency mode, reset their master address to M.

_Signature:_

```
host ref set recover_slaves (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `host ref set`

list of hosts whose master address were successfully reset

#### RPC name: remove&#95;from&#95;guest&#95;agent&#95;config

_Overview:_

Remove a key&#45;value pair from the pool&#45;wide guest agent configuration

_Signature:_

```
void remove_from_guest_agent_config (session ref session_id, pool ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |The pool                                |
|`string                      `|key                           |The key to remove                       |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;gui&#95;config

_Overview:_

Remove the given key and its corresponding value from the gui&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_gui_config (session ref session_id, pool ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;health&#95;check&#95;config

_Overview:_

Remove the given key and its corresponding value from the health&#95;check&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_health_check_config (session ref session_id, pool ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given pool.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, pool ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given pool.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, pool ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: retrieve&#95;wlb&#95;configuration

_Overview:_

Retrieves the pool optimization criteria from the workload balancing server

_Signature:_

```
(string -> string) map retrieve_wlb_configuration (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

The configuration used in optimizing this pool

#### RPC name: retrieve&#95;wlb&#95;recommendations

_Overview:_

Retrieves vm migrate recommendations for the pool from the workload balancing server

_Signature:_

```
(VM ref -> string set) map retrieve_wlb_recommendations (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> string set) map`

The list of vm migration recommendations

#### RPC name: rotate&#95;secret

_Overview:_



_Signature:_

```
void rotate_secret (session ref session_id)
```

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `INTERNAL_ERROR`, `HOST_IS_SLAVE`, `CANNOT_CONTACT_HOST`, `HA_IS_ENABLED`, `NOT_SUPPORTED_DURING_UPGRADE`

#### RPC name: send&#95;test&#95;post

_Overview:_

Send the given body to the given host and port, using HTTPS, and print the response.  This is used for debugging the SSL layer.

_Signature:_

```
string send_test_post (session ref session_id, string host, int port, string body)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|host                          |                                        |
|`int                         `|port                          |                                        |
|`string                      `|body                          |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `string`

The response

#### RPC name: send&#95;wlb&#95;configuration

_Overview:_

Sets the pool optimization criteria for the workload balancing server

_Signature:_

```
void send_wlb_configuration (session ref session_id, (string -> string) map config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`(string -> string) map      `|config                        |The configuration to use in optimizing this pool|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;crash&#95;dump&#95;SR

_Overview:_

Set the crash&#95;dump&#95;SR field of the given pool.

_Signature:_

```
void set_crash_dump_SR (session ref session_id, pool ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;default&#95;SR

_Overview:_

Set the default&#95;SR field of the given pool.

_Signature:_

```
void set_default_SR (session ref session_id, pool ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;gui&#95;config

_Overview:_

Set the gui&#95;config field of the given pool.

_Signature:_

```
void set_gui_config (session ref session_id, pool ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;ha&#95;allow&#95;overcommit

_Overview:_

Set the ha&#95;allow&#95;overcommit field of the given pool.

_Signature:_

```
void set_ha_allow_overcommit (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;ha&#95;host&#95;failures&#95;to&#95;tolerate

_Overview:_

Set the maximum number of host failures to consider in the HA VM restart planner

_Signature:_

```
void set_ha_host_failures_to_tolerate (session ref session_id, pool ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |The pool                                |
|`int                         `|value                         |New number of host failures to consider |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;health&#95;check&#95;config

_Overview:_

Set the health&#95;check&#95;config field of the given pool.

_Signature:_

```
void set_health_check_config (session ref session_id, pool ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;igmp&#95;snooping&#95;enabled

_Overview:_

Enable or disable IGMP Snooping on the pool.

_Signature:_

```
void set_igmp_snooping_enabled (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |The pool                                |
|`bool                        `|value                         |Enable or disable IGMP Snooping on the pool|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;is&#95;psr&#95;pending

_Overview:_

Set the is&#95;psr&#95;pending field of the given pool.

_Signature:_

```
void set_is_psr_pending (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;live&#95;patching&#95;disabled

_Overview:_

Set the live&#95;patching&#95;disabled field of the given pool.

_Signature:_

```
void set_live_patching_disabled (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name&#95;description field of the given pool.

_Signature:_

```
void set_name_description (session ref session_id, pool ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name&#95;label field of the given pool.

_Signature:_

```
void set_name_label (session ref session_id, pool ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given pool.

_Signature:_

```
void set_other_config (session ref session_id, pool ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;policy&#95;no&#95;vendor&#95;device

_Overview:_

Set the policy&#95;no&#95;vendor&#95;device field of the given pool.

_Signature:_

```
void set_policy_no_vendor_device (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;suspend&#95;image&#95;SR

_Overview:_

Set the suspend&#95;image&#95;SR field of the given pool.

_Signature:_

```
void set_suspend_image_SR (session ref session_id, pool ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given pool.

_Signature:_

```
void set_tags (session ref session_id, pool ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;uefi&#95;certificates

_Overview:_

Set the uefi&#95;certificates field of the given pool.

_Signature:_

```
void set_uefi_certificates (session ref session_id, pool ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;vswitch&#95;controller

**This message is deprecated.**

_Overview:_

Set the IP address of the vswitch controller.

_Signature:_

```
void set_vswitch_controller (session ref session_id, string address)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|address                       |IP address of the vswitch controller.   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;wlb&#95;enabled

_Overview:_

Set the wlb&#95;enabled field of the given pool.

_Signature:_

```
void set_wlb_enabled (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;wlb&#95;verify&#95;cert

_Overview:_

Set the wlb&#95;verify&#95;cert field of the given pool.

_Signature:_

```
void set_wlb_verify_cert (session ref session_id, pool ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: sync&#95;database

_Overview:_

Forcibly synchronise the database now

_Signature:_

```
void sync_database (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: test&#95;archive&#95;target

_Overview:_

This call tests if a location is valid

_Signature:_

```
string test_archive_target (session ref session_id, pool ref self, (string -> string) map config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool ref                    `|self                          |Reference to the pool                   |
|`(string -> string) map      `|config                        |Location config settings to test        |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XMLRPC result

## Class: pool&#95;patch

**This class is deprecated.**

Pool&#45;wide patches

### Fields for class: pool&#95;patch

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|after&#95;apply&#95;guidance|`after_apply_guidance set`|_RO/runtime_   |**Deprecated**. What the client should do after this patch has been applied.|
|host&#95;patches    |`host_patch ref set`|_RO/runtime_   |**Deprecated**. This hosts this patch is applied to.|
|name&#95;description|`string            `|_RO/constructor_|**Deprecated**. a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|**Deprecated**. a human&#45;readable name|
|other&#95;config    |`(string -> string) map`|_RW_           |**Deprecated**. additional configuration|
|pool&#95;applied    |`bool              `|_RO/runtime_   |**Deprecated**. This patch should be applied across the entire pool|
|pool&#95;update     |`pool_update ref   `|_RO/constructor_|**Deprecated**. A reference to the associated pool&#95;update object|
|size                |`int               `|_RO/runtime_   |**Deprecated**. Size of the patch       |
|uuid                |`string            `|_RO/runtime_   |**Deprecated**. Unique identifier/object reference|
|version             |`string            `|_RO/constructor_|**Deprecated**. Patch version number    |

### RPCs associated with class: pool&#95;patch

#### RPC name: add&#95;to&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given pool&#95;patch.

_Signature:_

```
void add_to_other_config (session ref session_id, pool_patch ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: apply

**This message is deprecated.**

_Overview:_

Apply the selected patch to a host and return its output

_Signature:_

```
string apply (session ref session_id, pool_patch ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to apply                      |
|`host ref                    `|host                          |The host to apply the patch too         |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

the output of the patch application process

#### RPC name: clean

**This message is deprecated.**

_Overview:_

Removes the patch's files from the server

_Signature:_

```
void clean (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to clean up                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: clean&#95;on&#95;host

**This message is deprecated.**

_Overview:_

Removes the patch's files from the specified host

_Signature:_

```
void clean_on_host (session ref session_id, pool_patch ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to clean up                   |
|`host ref                    `|host                          |The host on which to clean the patch    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: destroy

**This message is deprecated.**

_Overview:_

Removes the patch's files from all hosts in the pool, and removes the database entries.  Only works on unapplied patches.

_Signature:_

```
void destroy (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to destroy                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;after&#95;apply&#95;guidance

**This message is deprecated.**

_Overview:_

Get the after&#95;apply&#95;guidance field of the given pool&#95;patch.

_Signature:_

```
after_apply_guidance set get_after_apply_guidance (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `after_apply_guidance set`

value of the field

#### RPC name: get&#95;all

**This message is deprecated.**

_Overview:_

Return a list of all the pool&#95;patchs known to the system.

_Signature:_

```
pool_patch ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `pool_patch ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is deprecated.**

_Overview:_

Return a map of pool&#95;patch references to pool&#95;patch records for all pool&#95;patchs known to the system.

_Signature:_

```
(pool_patch ref -> pool_patch record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(pool_patch ref -> pool_patch record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

**This message is deprecated.**

_Overview:_

Get all the pool&#95;patch instances with the given label.

_Signature:_

```
pool_patch ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `pool_patch ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

**This message is deprecated.**

_Overview:_

Get a reference to the pool&#95;patch instance with the specified UUID.

_Signature:_

```
pool_patch ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `pool_patch ref`

reference to the object

#### RPC name: get&#95;host&#95;patches

**This message is deprecated.**

_Overview:_

Get the host&#95;patches field of the given pool&#95;patch.

_Signature:_

```
host_patch ref set get_host_patches (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host_patch ref set`

value of the field

#### RPC name: get&#95;name&#95;description

**This message is deprecated.**

_Overview:_

Get the name/description field of the given pool&#95;patch.

_Signature:_

```
string get_name_description (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

**This message is deprecated.**

_Overview:_

Get the name/label field of the given pool&#95;patch.

_Signature:_

```
string get_name_label (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Get the other&#95;config field of the given pool&#95;patch.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;pool&#95;applied

**This message is deprecated.**

_Overview:_

Get the pool&#95;applied field of the given pool&#95;patch.

_Signature:_

```
bool get_pool_applied (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;pool&#95;update

**This message is deprecated.**

_Overview:_

Get the pool&#95;update field of the given pool&#95;patch.

_Signature:_

```
pool_update ref get_pool_update (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref`

value of the field

#### RPC name: get&#95;record

**This message is deprecated.**

_Overview:_

Get a record containing the current state of the given pool&#95;patch.

_Signature:_

```
pool_patch record get_record (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_patch record`

all fields from the object

#### RPC name: get&#95;size

**This message is deprecated.**

_Overview:_

Get the size field of the given pool&#95;patch.

_Signature:_

```
int get_size (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;uuid

**This message is deprecated.**

_Overview:_

Get the uuid field of the given pool&#95;patch.

_Signature:_

```
string get_uuid (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;version

**This message is deprecated.**

_Overview:_

Get the version field of the given pool&#95;patch.

_Signature:_

```
string get_version (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: pool&#95;apply

**This message is deprecated.**

_Overview:_

Apply the selected patch to all hosts in the pool and return a map of host&#95;ref &#45;&gt; patch output

_Signature:_

```
void pool_apply (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to apply                      |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: pool&#95;clean

**This message is deprecated.**

_Overview:_

Removes the patch's files from all hosts in the pool, but does not remove the database entries

_Signature:_

```
void pool_clean (session ref session_id, pool_patch ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch to clean up                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: precheck

**This message is deprecated.**

_Overview:_

Execute the precheck stage of the selected patch on a host and return its output

_Signature:_

```
string precheck (session ref session_id, pool_patch ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |The patch whose prechecks will be run   |
|`host ref                    `|host                          |The host to run the prechecks on        |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

the output of the patch prechecks

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given pool&#95;patch.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, pool_patch ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Set the other&#95;config field of the given pool&#95;patch.

_Signature:_

```
void set_other_config (session ref session_id, pool_patch ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_patch ref              `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: pool&#95;update

Pool&#45;wide updates to the host software

### Fields for class: pool&#95;update

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|after&#95;apply&#95;guidance|`update_after_apply_guidance set`|_RO/constructor_|What the client should do after this update has been applied.|
|enforce&#95;homogeneity|`bool              `|_RO/constructor_|Flag &#45; if true, all hosts in a pool must apply this update|
|hosts               |`host ref set      `|_RO/runtime_   |The hosts that have applied this update.|
|installation&#95;size|`int               `|_RO/constructor_|Size of the update in bytes             |
|key                 |`string            `|_RO/constructor_|GPG key of the update                   |
|name&#95;description|`string            `|_RO/constructor_|a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vdi                 |`VDI ref           `|_RO/constructor_|VDI the update was uploaded to          |
|version             |`string            `|_RO/constructor_|Update version number                   |

### RPCs associated with class: pool&#95;update

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given pool&#95;update.

_Signature:_

```
void add_to_other_config (session ref session_id, pool_update ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: apply

_Overview:_

Apply the selected update to a host

_Signature:_

```
void apply (session ref session_id, pool_update ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |The update to apply                     |
|`host ref                    `|host                          |The host to apply the update to.        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: destroy

_Overview:_

Removes the database entry. Only works on unapplied update.

_Signature:_

```
void destroy (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |The update to destroy                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;after&#95;apply&#95;guidance

_Overview:_

Get the after&#95;apply&#95;guidance field of the given pool&#95;update.

_Signature:_

```
update_after_apply_guidance set get_after_apply_guidance (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `update_after_apply_guidance set`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the pool&#95;updates known to the system.

_Signature:_

```
pool_update ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of pool&#95;update references to pool&#95;update records for all pool&#95;updates known to the system.

_Signature:_

```
(pool_update ref -> pool_update record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(pool_update ref -> pool_update record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the pool&#95;update instances with the given label.

_Signature:_

```
pool_update ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the pool&#95;update instance with the specified UUID.

_Signature:_

```
pool_update ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `pool_update ref`

reference to the object

#### RPC name: get&#95;enforce&#95;homogeneity

_Overview:_

Get the enforce&#95;homogeneity field of the given pool&#95;update.

_Signature:_

```
bool get_enforce_homogeneity (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;hosts

_Overview:_

Get the hosts field of the given pool&#95;update.

_Signature:_

```
host ref set get_hosts (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

value of the field

#### RPC name: get&#95;installation&#95;size

_Overview:_

Get the installation&#95;size field of the given pool&#95;update.

_Signature:_

```
int get_installation_size (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;key

_Overview:_

Get the key field of the given pool&#95;update.

_Signature:_

```
string get_key (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given pool&#95;update.

_Signature:_

```
string get_name_description (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given pool&#95;update.

_Signature:_

```
string get_name_label (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given pool&#95;update.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given pool&#95;update.

_Signature:_

```
pool_update record get_record (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool_update record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given pool&#95;update.

_Signature:_

```
string get_uuid (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vdi

_Overview:_

Get the vdi field of the given pool&#95;update.

_Signature:_

```
VDI ref get_vdi (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;version

_Overview:_

Get the version field of the given pool&#95;update.

_Signature:_

```
string get_version (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: introduce

_Overview:_

Introduce update VDI

_Signature:_

```
pool_update ref introduce (session ref session_id, VDI ref vdi)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI which contains a software update.|

_Minimum Role:_ pool-operator

_Return Type:_ `pool_update ref`

the introduced pool update

#### RPC name: pool&#95;apply

_Overview:_

Apply the selected update to all hosts in the pool

_Signature:_

```
void pool_apply (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |The update to apply                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: pool&#95;clean

_Overview:_

Removes the update's files from all hosts in the pool, but does not revert the update

_Signature:_

```
void pool_clean (session ref session_id, pool_update ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |The update to clean up                  |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: precheck

_Overview:_

Execute the precheck stage of the selected update on a host

_Signature:_

```
livepatch_status precheck (session ref session_id, pool_update ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |The update whose prechecks will be run  |
|`host ref                    `|host                          |The host to run the prechecks on.       |

_Minimum Role:_ pool-operator

_Return Type:_ `livepatch_status`

The precheck pool update

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given pool&#95;update.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, pool_update ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given pool&#95;update.

_Signature:_

```
void set_other_config (session ref session_id, pool_update ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`pool_update ref             `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: probe&#95;result

A set of properties that describe one result element of SR.probe. Result elements and properties can change dynamically based on changes to the the SR.probe input&#45;parameters or the target.

### Fields for class: probe&#95;result

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|complete            |`bool              `|_RO/runtime_   |True if this configuration is complete and can be used to call SR.create. False if it requires further iterative calls to SR.probe, to potentially narrow down on a configuration that can be used.|
|configuration       |`(string -> string) map`|_RO/runtime_   |Plugin&#45;specific configuration which describes where and how to locate the storage repository. This may include the physical block device name, a remote NFS server and path or an RBD storage pool.|
|extra&#95;info      |`(string -> string) map`|_RO/runtime_   |Additional plugin&#45;specific information about this configuration, that might be of use for an API user. This can for example include the LUN or the WWPN.|
|sr                  |`sr_stat record option`|_RO/runtime_   |Existing SR found for this configuration|

### RPCs associated with class: probe&#95;result

Class probe&#95;result has no additional RPCs associated with it.

## Class: PUSB

A physical USB device

### Fields for class: PUSB

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|description         |`string            `|_RO/constructor_|USB device description                  |
|host                |`host ref          `|_RO/constructor_|Physical machine that owns the USB device|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|passthrough&#95;enabled|`bool              `|_RO/runtime_   |enabled for passthrough                 |
|path                |`string            `|_RO/constructor_|port path of USB device                 |
|product&#95;desc    |`string            `|_RO/constructor_|product description of the USB device   |
|product&#95;id      |`string            `|_RO/constructor_|product id of the USB device            |
|serial              |`string            `|_RO/constructor_|serial of the USB device                |
|speed               |`float             `|_RO/constructor_|USB device speed                        |
|USB&#95;group       |`USB_group ref     `|_RO/constructor_|USB group the PUSB is contained in      |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vendor&#95;desc     |`string            `|_RO/constructor_|vendor description of the USB device    |
|vendor&#95;id       |`string            `|_RO/constructor_|vendor id of the USB device             |
|version             |`string            `|_RO/constructor_|USB device version                      |

### RPCs associated with class: PUSB

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given PUSB.

_Signature:_

```
void add_to_other_config (session ref session_id, PUSB ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PUSBs known to the system.

_Signature:_

```
PUSB ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PUSB references to PUSB records for all PUSBs known to the system.

_Signature:_

```
(PUSB ref -> PUSB record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PUSB ref -> PUSB record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PUSB instance with the specified UUID.

_Signature:_

```
PUSB ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref`

reference to the object

#### RPC name: get&#95;description

_Overview:_

Get the description field of the given PUSB.

_Signature:_

```
string get_description (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PUSB.

_Signature:_

```
host ref get_host (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given PUSB.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;passthrough&#95;enabled

_Overview:_

Get the passthrough&#95;enabled field of the given PUSB.

_Signature:_

```
bool get_passthrough_enabled (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;path

_Overview:_

Get the path field of the given PUSB.

_Signature:_

```
string get_path (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;product&#95;desc

_Overview:_

Get the product&#95;desc field of the given PUSB.

_Signature:_

```
string get_product_desc (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;product&#95;id

_Overview:_

Get the product&#95;id field of the given PUSB.

_Signature:_

```
string get_product_id (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PUSB.

_Signature:_

```
PUSB record get_record (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB record`

all fields from the object

#### RPC name: get&#95;serial

_Overview:_

Get the serial field of the given PUSB.

_Signature:_

```
string get_serial (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;speed

_Overview:_

Get the speed field of the given PUSB.

_Signature:_

```
float get_speed (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;USB&#95;group

_Overview:_

Get the USB&#95;group field of the given PUSB.

_Signature:_

```
USB_group ref get_USB_group (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PUSB.

_Signature:_

```
string get_uuid (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;desc

_Overview:_

Get the vendor&#95;desc field of the given PUSB.

_Signature:_

```
string get_vendor_desc (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;id

_Overview:_

Get the vendor&#95;id field of the given PUSB.

_Signature:_

```
string get_vendor_id (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;version

_Overview:_

Get the version field of the given PUSB.

_Signature:_

```
string get_version (session ref session_id, PUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given PUSB.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, PUSB ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: scan

_Overview:_



_Signature:_

```
void scan (session ref session_id, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given PUSB.

_Signature:_

```
void set_other_config (session ref session_id, PUSB ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;passthrough&#95;enabled

_Overview:_



_Signature:_

```
void set_passthrough_enabled (session ref session_id, PUSB ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PUSB ref                    `|self                          |this PUSB                               |
|`bool                        `|value                         |passthrough is enabled when true and disabled with false|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

## Class: PVS&#95;cache&#95;storage

Describes the storage that is available to a PVS site for caching purposes

### Fields for class: PVS&#95;cache&#95;storage

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|host                |`host ref          `|_RO/constructor_|The host on which this object defines PVS cache storage|
|site                |`PVS_site ref      `|_RO/constructor_|The PVS&#95;site for which this object defines the storage|
|size                |`int               `|_RO/constructor_|The size of the cache VDI &#40;in bytes&#41;|
|SR                  |`SR ref            `|_RO/constructor_|SR providing storage for the PVS cache  |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VDI                 |`VDI ref           `|_RO/runtime_   |The VDI used for caching                |

### RPCs associated with class: PVS&#95;cache&#95;storage

#### RPC name: create

_Overview:_

Create a new PVS&#95;cache&#95;storage instance, and return its handle.

_Signature:_

```
PVS_cache_storage ref create (session ref session_id, PVS_cache_storage record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage record    `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_cache_storage ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified PVS&#95;cache&#95;storage instance.

_Signature:_

```
void destroy (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;cache&#95;storages known to the system.

_Signature:_

```
PVS_cache_storage ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;cache&#95;storage references to PVS&#95;cache&#95;storage records for all PVS&#95;cache&#95;storages known to the system.

_Signature:_

```
(PVS_cache_storage ref -> PVS_cache_storage record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PVS_cache_storage ref -> PVS_cache_storage record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;cache&#95;storage instance with the specified UUID.

_Signature:_

```
PVS_cache_storage ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref`

reference to the object

#### RPC name: get&#95;host

_Overview:_

Get the host field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
host ref get_host (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;cache&#95;storage.

_Signature:_

```
PVS_cache_storage record get_record (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage record`

all fields from the object

#### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
PVS_site ref get_site (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

#### RPC name: get&#95;size

_Overview:_

Get the size field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
int get_size (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
SR ref get_SR (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
string get_uuid (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VDI

_Overview:_

Get the VDI field of the given PVS&#95;cache&#95;storage.

_Signature:_

```
VDI ref get_VDI (session ref session_id, PVS_cache_storage ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_cache_storage ref       `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

## Class: PVS&#95;proxy

a proxy connects a VM/VIF with a PVS site

### Fields for class: PVS&#95;proxy

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|currently&#95;attached|`bool              `|_RO/runtime_   |true = VM is currently proxied          |
|site                |`PVS_site ref      `|_RO/constructor_|PVS site this proxy is part of          |
|status              |`pvs_proxy_status  `|_RO/runtime_   |The run&#45;time status of the proxy    |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VIF                 |`VIF ref           `|_RO/constructor_|VIF of the VM using the proxy           |

### RPCs associated with class: PVS&#95;proxy

#### RPC name: create

_Overview:_

Configure a VM/VIF to use a PVS proxy

_Signature:_

```
PVS_proxy ref create (session ref session_id, PVS_site ref site, VIF ref VIF)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|site                          |PVS site that we proxy for              |
|`VIF ref                     `|VIF                           |VIF for the VM that needs to be proxied |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_proxy ref`

the new PVS proxy

#### RPC name: destroy

_Overview:_

remove &#40;or switch off&#41; a PVS proxy for this VM

_Signature:_

```
void destroy (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |this PVS proxy                          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;proxys known to the system.

_Signature:_

```
PVS_proxy ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;proxy references to PVS&#95;proxy records for all PVS&#95;proxys known to the system.

_Signature:_

```
(PVS_proxy ref -> PVS_proxy record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PVS_proxy ref -> PVS_proxy record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;proxy instance with the specified UUID.

_Signature:_

```
PVS_proxy ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref`

reference to the object

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given PVS&#95;proxy.

_Signature:_

```
bool get_currently_attached (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;proxy.

_Signature:_

```
PVS_proxy record get_record (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy record`

all fields from the object

#### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;proxy.

_Signature:_

```
PVS_site ref get_site (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

#### RPC name: get&#95;status

_Overview:_

Get the status field of the given PVS&#95;proxy.

_Signature:_

```
pvs_proxy_status get_status (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pvs_proxy_status`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;proxy.

_Signature:_

```
string get_uuid (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VIF

_Overview:_

Get the VIF field of the given PVS&#95;proxy.

_Signature:_

```
VIF ref get_VIF (session ref session_id, PVS_proxy ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_proxy ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref`

value of the field

## Class: PVS&#95;server

individual machine serving provisioning &#40;block&#41; data

### Fields for class: PVS&#95;server

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|addresses           |`string set        `|_RO/constructor_|IPv4 addresses of this server           |
|first&#95;port      |`int               `|_RO/constructor_|First UDP port accepted by this server  |
|last&#95;port       |`int               `|_RO/constructor_|Last UDP port accepted by this server   |
|site                |`PVS_site ref      `|_RO/constructor_|PVS site this server is part of         |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: PVS&#95;server

#### RPC name: forget

_Overview:_

forget a PVS server

_Signature:_

```
void forget (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |this PVS server                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;addresses

_Overview:_

Get the addresses field of the given PVS&#95;server.

_Signature:_

```
string set get_addresses (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;servers known to the system.

_Signature:_

```
PVS_server ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;server references to PVS&#95;server records for all PVS&#95;servers known to the system.

_Signature:_

```
(PVS_server ref -> PVS_server record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PVS_server ref -> PVS_server record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;server instance with the specified UUID.

_Signature:_

```
PVS_server ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref`

reference to the object

#### RPC name: get&#95;first&#95;port

_Overview:_

Get the first&#95;port field of the given PVS&#95;server.

_Signature:_

```
int get_first_port (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;last&#95;port

_Overview:_

Get the last&#95;port field of the given PVS&#95;server.

_Signature:_

```
int get_last_port (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;server.

_Signature:_

```
PVS_server record get_record (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server record`

all fields from the object

#### RPC name: get&#95;site

_Overview:_

Get the site field of the given PVS&#95;server.

_Signature:_

```
PVS_site ref get_site (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;server.

_Signature:_

```
string get_uuid (session ref session_id, PVS_server ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_server ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: introduce

_Overview:_

introduce new PVS server

_Signature:_

```
PVS_server ref introduce (session ref session_id, string set addresses, int first_port, int last_port, PVS_site ref site)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string set                  `|addresses                     |IPv4 addresses of the server            |
|`int                         `|first&#95;port                |first UDP port accepted by this server  |
|`int                         `|last&#95;port                 |last UDP port accepted by this server   |
|`PVS_site ref                `|site                          |PVS site this server is a part of       |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_server ref`

the new PVS server

## Class: PVS&#95;site

machines serving blocks of data for provisioning VMs

### Fields for class: PVS&#95;site

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|cache&#95;storage   |`PVS_cache_storage ref set`|_RO/runtime_   |The SR used by PVS proxy for the cache  |
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|proxies             |`PVS_proxy ref set `|_RO/runtime_   |The set of proxies associated with the site|
|PVS&#95;uuid        |`string            `|_RO/constructor_|Unique identifier of the PVS site, as configured in PVS|
|servers             |`PVS_server ref set`|_RO/runtime_   |The set of PVS servers in the site      |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: PVS&#95;site

#### RPC name: forget

_Overview:_

Remove a site's meta data

_Signature:_

```
void forget (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |this PVS site                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `PVS_SITE_CONTAINS_RUNNING_PROXIES`, `PVS_SITE_CONTAINS_SERVERS`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the PVS&#95;sites known to the system.

_Signature:_

```
PVS_site ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of PVS&#95;site references to PVS&#95;site records for all PVS&#95;sites known to the system.

_Signature:_

```
(PVS_site ref -> PVS_site record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(PVS_site ref -> PVS_site record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the PVS&#95;site instances with the given label.

_Signature:_

```
PVS_site ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the PVS&#95;site instance with the specified UUID.

_Signature:_

```
PVS_site ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site ref`

reference to the object

#### RPC name: get&#95;cache&#95;storage

_Overview:_

Get the cache&#95;storage field of the given PVS&#95;site.

_Signature:_

```
PVS_cache_storage ref set get_cache_storage (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_cache_storage ref set`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given PVS&#95;site.

_Signature:_

```
string get_name_description (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given PVS&#95;site.

_Signature:_

```
string get_name_label (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;proxies

_Overview:_

Get the proxies field of the given PVS&#95;site.

_Signature:_

```
PVS_proxy ref set get_proxies (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_proxy ref set`

value of the field

#### RPC name: get&#95;PVS&#95;uuid

_Overview:_

Get the PVS&#95;uuid field of the given PVS&#95;site.

_Signature:_

```
string get_PVS_uuid (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given PVS&#95;site.

_Signature:_

```
PVS_site record get_record (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_site record`

all fields from the object

#### RPC name: get&#95;servers

_Overview:_

Get the servers field of the given PVS&#95;site.

_Signature:_

```
PVS_server ref set get_servers (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PVS_server ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given PVS&#95;site.

_Signature:_

```
string get_uuid (session ref session_id, PVS_site ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: introduce

_Overview:_

Introduce new PVS site

_Signature:_

```
PVS_site ref introduce (session ref session_id, string name_label, string name_description, string PVS_uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name&#95;label                |name of the PVS site                    |
|`string                      `|name&#95;description          |description of the PVS site             |
|`string                      `|PVS&#95;uuid                  |unique identifier of the PVS site       |

_Minimum Role:_ pool-operator

_Return Type:_ `PVS_site ref`

the new PVS site

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given PVS&#95;site.

_Signature:_

```
void set_name_description (session ref session_id, PVS_site ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given PVS&#95;site.

_Signature:_

```
void set_name_label (session ref session_id, PVS_site ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;PVS&#95;uuid

_Overview:_

Update the PVS UUID of the PVS site

_Signature:_

```
void set_PVS_uuid (session ref session_id, PVS_site ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PVS_site ref                `|self                          |this PVS site                           |
|`string                      `|value                         |PVS UUID to be used                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: role

A set of permissions associated with a subject

### Fields for class: role

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|name&#95;description|`string            `|_RO/constructor_|what this role is for                   |
|name&#95;label      |`string            `|_RO/constructor_|a short user&#45;friendly name for the role|
|subroles            |`role ref set      `|_RO/constructor_|a list of pointers to other roles or permissions|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: role

#### RPC name: get&#95;all

_Overview:_

Return a list of all the roles known to the system.

_Signature:_

```
role ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of role references to role records for all roles known to the system.

_Signature:_

```
(role ref -> role record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(role ref -> role record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the role instances with the given label.

_Signature:_

```
role ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;permission

_Overview:_

This call returns a list of roles given a permission

_Signature:_

```
role ref set get_by_permission (session ref session_id, role ref permission)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|permission                    |a reference to a permission             |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of references to roles

#### RPC name: get&#95;by&#95;permission&#95;name&#95;label

_Overview:_

This call returns a list of roles given a permission name

_Signature:_

```
role ref set get_by_permission_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |The short friendly name of the role     |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of references to roles

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the role instance with the specified UUID.

_Signature:_

```
role ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `role ref`

reference to the object

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given role.

_Signature:_

```
string get_name_description (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given role.

_Signature:_

```
string get_name_label (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;permissions

_Overview:_

This call returns a list of permissions given a role

_Signature:_

```
role ref set get_permissions (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |a reference to a role                   |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

a list of permissions

#### RPC name: get&#95;permissions&#95;name&#95;label

_Overview:_

This call returns a list of permission names given a role

_Signature:_

```
string set get_permissions_name_label (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |a reference to a role                   |

_Minimum Role:_ read-only

_Return Type:_ `string set`

a list of permission names

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given role.

_Signature:_

```
role record get_record (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role record`

all fields from the object

#### RPC name: get&#95;subroles

_Overview:_

Get the subroles field of the given role.

_Signature:_

```
role ref set get_subroles (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given role.

_Signature:_

```
string get_uuid (session ref session_id, role ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`role ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

## Class: SDN&#95;controller

Describes the SDN controller that is to connect with the pool

### Fields for class: SDN&#95;controller

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|address             |`string            `|_RO/constructor_|IP address of the controller            |
|port                |`int               `|_RO/constructor_|TCP port of the controller              |
|protocol            |`sdn_controller_protocol`|_RO/constructor_|Protocol to connect with SDN controller |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: SDN&#95;controller

#### RPC name: forget

_Overview:_

Remove the OVS manager of the pool and destroy the db record.

_Signature:_

```
void forget (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |this SDN controller                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;address

_Overview:_

Get the address field of the given SDN&#95;controller.

_Signature:_

```
string get_address (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the SDN&#95;controllers known to the system.

_Signature:_

```
SDN_controller ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SDN&#95;controller references to SDN&#95;controller records for all SDN&#95;controllers known to the system.

_Signature:_

```
(SDN_controller ref -> SDN_controller record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(SDN_controller ref -> SDN_controller record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SDN&#95;controller instance with the specified UUID.

_Signature:_

```
SDN_controller ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller ref`

reference to the object

#### RPC name: get&#95;port

_Overview:_

Get the port field of the given SDN&#95;controller.

_Signature:_

```
int get_port (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given SDN&#95;controller.

_Signature:_

```
sdn_controller_protocol get_protocol (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `sdn_controller_protocol`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SDN&#95;controller.

_Signature:_

```
SDN_controller record get_record (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SDN_controller record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SDN&#95;controller.

_Signature:_

```
string get_uuid (session ref session_id, SDN_controller ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SDN_controller ref          `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: introduce

_Overview:_

Introduce an SDN controller to the pool.

_Signature:_

```
SDN_controller ref introduce (session ref session_id, sdn_controller_protocol protocol, string address, int port)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`sdn_controller_protocol     `|protocol                      |Protocol to connect with the controller.|
|`string                      `|address                       |IP address of the controller.           |
|`int                         `|port                          |TCP port of the controller.             |

_Minimum Role:_ pool-operator

_Return Type:_ `SDN_controller ref`

the introduced SDN controller

## Class: secret

A secret

### Fields for class: secret

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|other&#95;config    |`(string -> string) map`|_RW_           |other&#95;config                        |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|value               |`string            `|_RW_           |the secret                              |

### RPCs associated with class: secret

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given secret.

_Signature:_

```
void add_to_other_config (session ref session_id, secret ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new secret instance, and return its handle.

_Signature:_

```
secret ref create (session ref session_id, secret record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret record               `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified secret instance.

_Signature:_

```
void destroy (session ref session_id, secret ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the secrets known to the system.

_Signature:_

```
secret ref set get_all (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of secret references to secret records for all secrets known to the system.

_Signature:_

```
(secret ref -> secret record) map get_all_records (session ref session_id)
```

_Minimum Role:_ pool-operator

_Return Type:_ `(secret ref -> secret record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the secret instance with the specified UUID.

_Signature:_

```
secret ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ pool-operator

_Return Type:_ `secret ref`

reference to the object

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given secret.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, secret ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given secret.

_Signature:_

```
secret record get_record (session ref session_id, secret ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `secret record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given secret.

_Signature:_

```
string get_uuid (session ref session_id, secret ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;value

_Overview:_

Get the value field of the given secret.

_Signature:_

```
string get_value (session ref session_id, secret ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given secret.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, secret ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given secret.

_Signature:_

```
void set_other_config (session ref session_id, secret ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;value

_Overview:_

Set the value field of the given secret.

_Signature:_

```
void set_value (session ref session_id, secret ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`secret ref                  `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: session

A session

### Fields for class: session

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|auth&#95;user&#95;name|`string            `|_RO/runtime_   |the subject name of the user that was externally authenticated. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|auth&#95;user&#95;sid|`string            `|_RO/runtime_   |the subject identifier of the user that was externally authenticated. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|is&#95;local&#95;superuser|`bool              `|_RO/runtime_   |true iff this session was created using local superuser credentials|
|last&#95;active     |`datetime          `|_RO/runtime_   |Timestamp for last time session was active|
|originator          |`string            `|_RO/runtime_   |a key string provided by a API user to distinguish itself from other users sharing the same login name|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|parent              |`session ref       `|_RO/constructor_|references the parent session that created this session|
|pool                |`bool              `|_RO/runtime_   |True if this session relates to a intra&#45;pool login, false otherwise|
|rbac&#95;permissions|`string set        `|_RO/constructor_|list with all RBAC permissions for this session|
|subject             |`subject ref       `|_RO/runtime_   |references the subject instance that created the session. If a session instance has is&#95;local&#95;superuser set, then the value of this field is undefined.|
|tasks               |`task ref set      `|_RO/runtime_   |list of tasks created using the current session|
|this&#95;host       |`host ref          `|_RO/runtime_   |Currently connected host                |
|this&#95;user       |`user ref          `|_RO/runtime_   |Currently connected user                |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|validation&#95;time |`datetime          `|_RO/runtime_   |time when session was last validated    |

### RPCs associated with class: session

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given session.

_Signature:_

```
void add_to_other_config (session ref session_id, session ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: change&#95;password

_Overview:_

Change the account password; if your session is authenticated with root priviledges then the old&#95;pwd is validated and the new&#95;pwd is set regardless

_Signature:_

```
void change_password (session ref session_id, string old_pwd, string new_pwd)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|old&#95;pwd                   |Old password for account                |
|`string                      `|new&#95;pwd                   |New password for account                |

_Return Type:_ `void`

#### RPC name: create&#95;from&#95;db&#95;file

_Overview:_



_Signature:_

```
session ref create_from_db_file (session ref session_id, string filename)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|filename                      |Database dump filename.                 |

_Return Type:_ `session ref`

ID of newly created session

#### RPC name: get&#95;all&#95;subject&#95;identifiers

_Overview:_

Return a list of all the user subject&#45;identifiers of all existing sessions

_Signature:_

```
string set get_all_subject_identifiers (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `string set`

The list of user subject&#45;identifiers of all existing sessions

#### RPC name: get&#95;auth&#95;user&#95;name

_Overview:_

Get the auth&#95;user&#95;name field of the given session.

_Signature:_

```
string get_auth_user_name (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;auth&#95;user&#95;sid

_Overview:_

Get the auth&#95;user&#95;sid field of the given session.

_Signature:_

```
string get_auth_user_sid (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the session instance with the specified UUID.

_Signature:_

```
session ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `session ref`

reference to the object

#### RPC name: get&#95;is&#95;local&#95;superuser

_Overview:_

Get the is&#95;local&#95;superuser field of the given session.

_Signature:_

```
bool get_is_local_superuser (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;last&#95;active

_Overview:_

Get the last&#95;active field of the given session.

_Signature:_

```
datetime get_last_active (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;originator

_Overview:_

Get the originator field of the given session.

_Signature:_

```
string get_originator (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given session.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;parent

_Overview:_

Get the parent field of the given session.

_Signature:_

```
session ref get_parent (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `session ref`

value of the field

#### RPC name: get&#95;pool

_Overview:_

Get the pool field of the given session.

_Signature:_

```
bool get_pool (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;rbac&#95;permissions

_Overview:_

Get the rbac&#95;permissions field of the given session.

_Signature:_

```
string set get_rbac_permissions (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given session.

_Signature:_

```
session record get_record (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `session record`

all fields from the object

#### RPC name: get&#95;subject

_Overview:_

Get the subject field of the given session.

_Signature:_

```
subject ref get_subject (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `subject ref`

value of the field

#### RPC name: get&#95;tasks

_Overview:_

Get the tasks field of the given session.

_Signature:_

```
task ref set get_tasks (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

value of the field

#### RPC name: get&#95;this&#95;host

_Overview:_

Get the this&#95;host field of the given session.

_Signature:_

```
host ref get_this_host (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;this&#95;user

_Overview:_

Get the this&#95;user field of the given session.

_Signature:_

```
user ref get_this_user (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `user ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given session.

_Signature:_

```
string get_uuid (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;validation&#95;time

_Overview:_

Get the validation&#95;time field of the given session.

_Signature:_

```
datetime get_validation_time (session ref session_id, session ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: local&#95;logout

_Overview:_

Log out of local session.

_Signature:_

```
void local_logout (session ref session_id)
```

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: login&#95;with&#95;password

_Overview:_

Attempt to authenticate the user, returning a session reference if successful

_Signature:_

```
session ref login_with_password (string uname, string pwd, string version, string originator)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`string                      `|uname                         |Username for login.                     |
|`string                      `|pwd                           |Password for login.                     |
|`string                      `|version                       |Client API version.                     |
|`string                      `|originator                    |Key string for distinguishing different API users sharing the same login name.|

_Minimum Role:_ read-only

_Return Type:_ `session ref`

reference of newly created session

_Possible Error Codes:_ `SESSION_AUTHENTICATION_FAILED`, `HOST_IS_SLAVE`

#### RPC name: logout

_Overview:_

Log out of a session

_Signature:_

```
void logout (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: logout&#95;subject&#95;identifier

_Overview:_

Log out all sessions associated to a user subject&#45;identifier, except the session associated with the context calling this function

_Signature:_

```
void logout_subject_identifier (session ref session_id, string subject_identifier)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|subject&#95;identifier        |User subject&#45;identifier of the sessions to be destroyed|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given session.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, session ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given session.

_Signature:_

```
void set_other_config (session ref session_id, session ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`session ref                 `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: slave&#95;local&#95;login&#95;with&#95;password

_Overview:_

Authenticate locally against a slave in emergency mode. Note the resulting sessions are only good for use on this host.

_Signature:_

```
session ref slave_local_login_with_password (string uname, string pwd)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`string                      `|uname                         |Username for login.                     |
|`string                      `|pwd                           |Password for login.                     |

_Minimum Role:_ pool-admin

_Return Type:_ `session ref`

ID of newly created session

## Class: SM

A storage manager plugin

### Fields for class: SM

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|capabilities        |`string set        `|_RO/runtime_   |**Deprecated**. capabilities of the SM plugin|
|configuration       |`(string -> string) map`|_RO/runtime_   |names and descriptions of device config keys|
|copyright           |`string            `|_RO/runtime_   |Entity which owns the copyright of this plugin|
|driver&#95;filename |`string            `|_RO/runtime_   |filename of the storage driver          |
|features            |`(string -> int) map`|_RO/runtime_   |capabilities of the SM plugin, with capability version numbers|
|name&#95;description|`string            `|_RO/runtime_   |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/runtime_   |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|required&#95;api&#95;version|`string            `|_RO/runtime_   |Minimum SM API version required on the server|
|required&#95;cluster&#95;stack|`string set        `|_RO/runtime_   |The storage plugin requires that one of these cluster stacks is configured and running.|
|type                |`string            `|_RO/runtime_   |SR.type                                 |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vendor              |`string            `|_RO/runtime_   |Vendor who created this plugin          |
|version             |`string            `|_RO/runtime_   |Version of the plugin                   |

### RPCs associated with class: SM

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given SM.

_Signature:_

```
void add_to_other_config (session ref session_id, SM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the SMs known to the system.

_Signature:_

```
SM ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `SM ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SM references to SM records for all SMs known to the system.

_Signature:_

```
(SM ref -> SM record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(SM ref -> SM record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the SM instances with the given label.

_Signature:_

```
SM ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `SM ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SM instance with the specified UUID.

_Signature:_

```
SM ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SM ref`

reference to the object

#### RPC name: get&#95;capabilities

**This message is deprecated.**

_Overview:_

Get the capabilities field of the given SM.

_Signature:_

```
string set get_capabilities (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;configuration

_Overview:_

Get the configuration field of the given SM.

_Signature:_

```
(string -> string) map get_configuration (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;copyright

_Overview:_

Get the copyright field of the given SM.

_Signature:_

```
string get_copyright (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;driver&#95;filename

_Overview:_

Get the driver&#95;filename field of the given SM.

_Signature:_

```
string get_driver_filename (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;features

_Overview:_

Get the features field of the given SM.

_Signature:_

```
(string -> int) map get_features (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> int) map`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given SM.

_Signature:_

```
string get_name_description (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given SM.

_Signature:_

```
string get_name_label (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given SM.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SM.

_Signature:_

```
SM record get_record (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SM record`

all fields from the object

#### RPC name: get&#95;required&#95;api&#95;version

_Overview:_

Get the required&#95;api&#95;version field of the given SM.

_Signature:_

```
string get_required_api_version (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;required&#95;cluster&#95;stack

_Overview:_

Get the required&#95;cluster&#95;stack field of the given SM.

_Signature:_

```
string set get_required_cluster_stack (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given SM.

_Signature:_

```
string get_type (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SM.

_Signature:_

```
string get_uuid (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor

_Overview:_

Get the vendor field of the given SM.

_Signature:_

```
string get_vendor (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;version

_Overview:_

Get the version field of the given SM.

_Signature:_

```
string get_version (session ref session_id, SM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given SM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, SM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given SM.

_Signature:_

```
void set_other_config (session ref session_id, SM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: SR

A storage repository

### Fields for class: SR

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`storage_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|blobs               |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this SR    |
|clustered           |`bool              `|_RO/runtime_   |True if the SR is using aggregated local storage|
|content&#95;type    |`string            `|_RO/constructor_|the type of the SR's content, if required &#40;e.g. ISOs&#41;|
|current&#95;operations|`(string -> storage_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|introduced&#95;by   |`DR_task ref       `|_RO/runtime_   |The disaster recovery task which introduced this SR|
|is&#95;tools&#95;sr |`bool              `|_RO/runtime_   |True if this is the SR that contains the Tools ISO VDIs|
|local&#95;cache&#95;enabled|`bool              `|_RO/runtime_   |True if this SR is assigned to be the local cache for its host|
|name&#95;description|`string            `|_RO/constructor_|a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|PBDs                |`PBD ref set       `|_RO/runtime_   |describes how particular hosts can see this storage repository|
|physical&#95;size   |`int               `|_RO/constructor_|total physical size of the repository &#40;in bytes&#41;|
|physical&#95;utilisation|`int               `|_RO/runtime_   |physical space currently utilised on this storage repository &#40;in bytes&#41;. Note that for sparse disk formats, physical&#95;utilisation may be less than virtual&#95;allocation|
|shared              |`bool              `|_RO/runtime_   |true if this SR is &#40;capable of being&#41; shared between multiple hosts|
|sm&#95;config       |`(string -> string) map`|_RW_           |SM dependent data                       |
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|type                |`string            `|_RO/constructor_|type of the storage repository          |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VDIs                |`VDI ref set       `|_RO/runtime_   |all virtual disks known to this storage repository|
|virtual&#95;allocation|`int               `|_RO/runtime_   |sum of virtual&#95;sizes of all VDIs in this storage repository &#40;in bytes&#41;|

### RPCs associated with class: SR

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given SR.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, SR ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given SR.

_Signature:_

```
void add_to_other_config (session ref session_id, SR ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;sm&#95;config

_Overview:_

Add the given key&#45;value pair to the sm&#95;config field of the given SR.

_Signature:_

```
void add_to_sm_config (session ref session_id, SR ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: assert&#95;can&#95;host&#95;ha&#95;statefile

_Overview:_

Returns successfully if the given SR can host an HA statefile. Otherwise returns an error to explain why not

_Signature:_

```
void assert_can_host_ha_statefile (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to query                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: assert&#95;supports&#95;database&#95;replication

_Overview:_

Returns successfully if the given SR supports database replication. Otherwise returns an error to explain why not.

_Signature:_

```
void assert_supports_database_replication (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to query                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new Storage Repository and introduce it into the managed system, creating both SR record and PBD record to attach it to current host &#40;with specified device&#95;config parameters&#41;

_Signature:_

```
SR ref create (session ref session_id, host ref host, (string -> string) map device_config, int physical_size, string name_label, string name_description, string type, string content_type, bool shared, (string -> string) map sm_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to create/make the SR on       |
|`(string -> string) map      `|device&#95;config             |The device config string that will be passed to backend SR driver|
|`int                         `|physical&#95;size             |The physical size of the new storage repository|
|`string                      `|name&#95;label                |The name of the new storage repository  |
|`string                      `|name&#95;description          |The description of the new storage repository|
|`string                      `|type                          |The type of the SR; used to specify the SR backend driver to use|
|`string                      `|content&#95;type              |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`bool                        `|shared                        |True if the SR &#40;is capable of&#41; being shared by multiple hosts|
|`(string -> string) map      `|sm&#95;config                 |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `SR ref`

The reference of the newly created Storage Repository.

_Possible Error Codes:_ `SR_UNKNOWN_DRIVER`

#### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this SR

_Signature:_

```
blob ref create_new_blob (session ref session_id, SR ref sr, string name, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|name                          |The name associated with the blob       |
|`string                      `|mime&#95;type                 |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ pool-operator

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

#### RPC name: destroy

_Overview:_

Destroy specified SR, removing SR&#45;record from database and remove SR from disk. &#40;In order to affect this operation the appropriate device&#95;config is read from the specified SR's PBD on current host&#41;

_Signature:_

```
void destroy (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_HAS_PBD`

#### RPC name: disable&#95;database&#95;replication

_Overview:_



_Signature:_

```
void disable_database_replication (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to which metadata should be no longer replicated|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: enable&#95;database&#95;replication

_Overview:_



_Signature:_

```
void enable_database_replication (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to which metadata should be replicated|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: forget

_Overview:_

Removing specified SR&#45;record from database, without attempting to remove SR from disk

_Signature:_

```
void forget (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `SR_HAS_PBD`

#### RPC name: forget&#95;data&#95;source&#95;archives

_Overview:_

Forget the recorded statistics related to the specified data source

_Signature:_

```
void forget_data_source_archives (session ref session_id, SR ref sr, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|data&#95;source               |The data source whose archives are to be forgotten|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the SRs known to the system.

_Signature:_

```
SR ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of SR references to SR records for all SRs known to the system.

_Signature:_

```
(SR ref -> SR record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(SR ref -> SR record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given SR.

_Signature:_

```
storage_operations set get_allowed_operations (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `storage_operations set`

value of the field

#### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given SR.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the SR instances with the given label.

_Signature:_

```
SR ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the SR instance with the specified UUID.

_Signature:_

```
SR ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

reference to the object

#### RPC name: get&#95;clustered

_Overview:_

Get the clustered field of the given SR.

_Signature:_

```
bool get_clustered (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;content&#95;type

_Overview:_

Get the content&#95;type field of the given SR.

_Signature:_

```
string get_content_type (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given SR.

_Signature:_

```
(string -> storage_operations) map get_current_operations (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> storage_operations) map`

value of the field

#### RPC name: get&#95;data&#95;sources

_Overview:_



_Signature:_

```
data_source record set get_data_sources (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to interrogate                   |

_Minimum Role:_ read-only

_Return Type:_ `data_source record set`

A set of data sources

#### RPC name: get&#95;introduced&#95;by

_Overview:_

Get the introduced&#95;by field of the given SR.

_Signature:_

```
DR_task ref get_introduced_by (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `DR_task ref`

value of the field

#### RPC name: get&#95;is&#95;tools&#95;sr

_Overview:_

Get the is&#95;tools&#95;sr field of the given SR.

_Signature:_

```
bool get_is_tools_sr (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;local&#95;cache&#95;enabled

_Overview:_

Get the local&#95;cache&#95;enabled field of the given SR.

_Signature:_

```
bool get_local_cache_enabled (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given SR.

_Signature:_

```
string get_name_description (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given SR.

_Signature:_

```
string get_name_label (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given SR.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PBDs

_Overview:_

Get the PBDs field of the given SR.

_Signature:_

```
PBD ref set get_PBDs (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PBD ref set`

value of the field

#### RPC name: get&#95;physical&#95;size

_Overview:_

Get the physical&#95;size field of the given SR.

_Signature:_

```
int get_physical_size (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;physical&#95;utilisation

_Overview:_

Get the physical&#95;utilisation field of the given SR.

_Signature:_

```
int get_physical_utilisation (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given SR.

_Signature:_

```
SR record get_record (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR record`

all fields from the object

#### RPC name: get&#95;shared

_Overview:_

Get the shared field of the given SR.

_Signature:_

```
bool get_shared (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;sm&#95;config

_Overview:_

Get the sm&#95;config field of the given SR.

_Signature:_

```
(string -> string) map get_sm_config (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;supported&#95;types

_Overview:_

Return a set of all the SR types supported by the system

_Signature:_

```
string set get_supported_types (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `string set`

the supported SR types

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given SR.

_Signature:_

```
string set get_tags (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given SR.

_Signature:_

```
string get_type (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given SR.

_Signature:_

```
string get_uuid (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VDIs

_Overview:_

Get the VDIs field of the given SR.

_Signature:_

```
VDI ref set get_VDIs (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

#### RPC name: get&#95;virtual&#95;allocation

_Overview:_

Get the virtual&#95;allocation field of the given SR.

_Signature:_

```
int get_virtual_allocation (session ref session_id, SR ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: introduce

_Overview:_

Introduce a new Storage Repository into the managed system

_Signature:_

```
SR ref introduce (session ref session_id, string uuid, string name_label, string name_description, string type, string content_type, bool shared, (string -> string) map sm_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |The uuid assigned to the introduced SR  |
|`string                      `|name&#95;label                |The name of the new storage repository  |
|`string                      `|name&#95;description          |The description of the new storage repository|
|`string                      `|type                          |The type of the SR; used to specify the SR backend driver to use|
|`string                      `|content&#95;type              |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`bool                        `|shared                        |True if the SR &#40;is capable of&#41; being shared by multiple hosts|
|`(string -> string) map      `|sm&#95;config                 |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `SR ref`

The reference of the newly introduced Storage Repository.

#### RPC name: make

**This message is deprecated.**

_Overview:_

Create a new Storage Repository on disk. This call is deprecated: use SR.create instead.

_Signature:_

```
string make (session ref session_id, host ref host, (string -> string) map device_config, int physical_size, string name_label, string name_description, string type, string content_type, (string -> string) map sm_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to create/make the SR on       |
|`(string -> string) map      `|device&#95;config             |The device config string that will be passed to backend SR driver|
|`int                         `|physical&#95;size             |The physical size of the new storage repository|
|`string                      `|name&#95;label                |The name of the new storage repository  |
|`string                      `|name&#95;description          |The description of the new storage repository|
|`string                      `|type                          |The type of the SR; used to specify the SR backend driver to use|
|`string                      `|content&#95;type              |The type of the new SRs content, if required &#40;e.g. ISOs&#41;|
|`(string -> string) map      `|sm&#95;config                 |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `string`

The uuid of the newly created Storage Repository.

#### RPC name: probe

_Overview:_

Perform a backend&#45;specific scan, using the given device&#95;config.  If the device&#95;config is complete, then this will return a list of the SRs present of this type on the device, if any.  If the device&#95;config is partial, then a backend&#45;specific scan will be performed, returning results that will guide the user in improving the device&#95;config.

_Signature:_

```
string probe (session ref session_id, host ref host, (string -> string) map device_config, string type, (string -> string) map sm_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to create/make the SR on       |
|`(string -> string) map      `|device&#95;config             |The device config string that will be passed to backend SR driver|
|`string                      `|type                          |The type of the SR; used to specify the SR backend driver to use|
|`(string -> string) map      `|sm&#95;config                 |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XML fragment containing the scan results.  These are specific to the scan being performed, and the backend.

#### RPC name: probe&#95;ext

_Overview:_

Perform a backend&#45;specific scan, using the given device&#95;config.  If the device&#95;config is complete, then this will return a list of the SRs present of this type on the device, if any.  If the device&#95;config is partial, then a backend&#45;specific scan will be performed, returning results that will guide the user in improving the device&#95;config.

_Signature:_

```
probe_result record set probe_ext (session ref session_id, host ref host, (string -> string) map device_config, string type, (string -> string) map sm_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`host ref                    `|host                          |The host to create/make the SR on       |
|`(string -> string) map      `|device&#95;config             |The device config string that will be passed to backend SR driver|
|`string                      `|type                          |The type of the SR; used to specify the SR backend driver to use|
|`(string -> string) map      `|sm&#95;config                 |Storage backend specific configuration options|

_Minimum Role:_ pool-operator

_Return Type:_ `probe_result record set`

A set of records containing the scan results.

#### RPC name: query&#95;data&#95;source

_Overview:_

Query the latest value of the specified data source

_Signature:_

```
float query_data_source (session ref session_id, SR ref sr, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|data&#95;source               |The data source to query                |

_Minimum Role:_ read-only

_Return Type:_ `float`

The latest value, averaged over the last 5 seconds

#### RPC name: record&#95;data&#95;source

_Overview:_

Start recording the specified data source

_Signature:_

```
void record_data_source (session ref session_id, SR ref sr, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|data&#95;source               |The data source to record               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given SR.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, SR ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;sm&#95;config

_Overview:_

Remove the given key and its corresponding value from the sm&#95;config field of the given SR.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_sm_config (session ref session_id, SR ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given SR.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, SR ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: scan

_Overview:_

Refreshes the list of VDIs associated with an SR

_Signature:_

```
void scan (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR to scan                          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name description of the SR

_Signature:_

```
void set_name_description (session ref session_id, SR ref sr, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|value                         |The name description for the SR         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name label of the SR

_Signature:_

```
void set_name_label (session ref session_id, SR ref sr, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`string                      `|value                         |The name label for the SR               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given SR.

_Signature:_

```
void set_other_config (session ref session_id, SR ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;physical&#95;size

_Overview:_

Sets the SR's physical&#95;size field

_Signature:_

```
void set_physical_size (session ref session_id, SR ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |The SR to modify                        |
|`int                         `|value                         |The new value of the SR's physical&#95;size|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;shared

_Overview:_

Sets the shared flag on the SR

_Signature:_

```
void set_shared (session ref session_id, SR ref sr, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR                                  |
|`bool                        `|value                         |True if the SR is shared                |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;sm&#95;config

_Overview:_

Set the sm&#95;config field of the given SR.

_Signature:_

```
void set_sm_config (session ref session_id, SR ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given SR.

_Signature:_

```
void set_tags (session ref session_id, SR ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: update

_Overview:_

Refresh the fields on the SR object

_Signature:_

```
void update (session ref session_id, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`SR ref                      `|sr                            |The SR whose fields should be refreshed |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: sr&#95;stat

A set of high&#45;level properties associated with an SR.

### Fields for class: sr&#95;stat

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|clustered           |`bool              `|_RO/runtime_   |Indicates whether the SR uses clustered local storage.|
|free&#95;space      |`int               `|_RO/runtime_   |Number of bytes free on the backing storage &#40;in bytes&#41;|
|health              |`sr_health         `|_RO/runtime_   |The health status of the SR.            |
|name&#95;description|`string            `|_RO/runtime_   |Longer, human&#45;readable description of the SR. Descriptions are generally only displayed by clients when the user is examining SRs in detail.|
|name&#95;label      |`string            `|_RO/runtime_   |Short, human&#45;readable label for the SR.|
|total&#95;space     |`int               `|_RO/runtime_   |Total physical size of the backing storage &#40;in bytes&#41;|
|uuid                |`string option     `|_RO/runtime_   |Uuid that uniquely identifies this SR, if one is available.|

### RPCs associated with class: sr&#95;stat

Class sr&#95;stat has no additional RPCs associated with it.

## Class: subject

A user or group that can log in xapi

### Fields for class: subject

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|other&#95;config    |`(string -> string) map`|_RO/constructor_|additional configuration                |
|roles               |`role ref set      `|_RO/runtime_   |the roles associated with this subject  |
|subject&#95;identifier|`string            `|_RO/constructor_|the subject identifier, unique in the external directory service|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: subject

#### RPC name: add&#95;to&#95;roles

_Overview:_

This call adds a new role to a subject

_Signature:_

```
void add_to_roles (session ref session_id, subject ref self, role ref role)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |The subject who we want to add the role to|
|`role ref                    `|role                          |The unique role reference               |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new subject instance, and return its handle.

_Signature:_

```
subject ref create (session ref session_id, subject record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject record              `|args                          |All constructor arguments               |

_Minimum Role:_ pool-admin

_Return Type:_ `subject ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified subject instance.

_Signature:_

```
void destroy (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the subjects known to the system.

_Signature:_

```
subject ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `subject ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of subject references to subject records for all subjects known to the system.

_Signature:_

```
(subject ref -> subject record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(subject ref -> subject record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the subject instance with the specified UUID.

_Signature:_

```
subject ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `subject ref`

reference to the object

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given subject.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;permissions&#95;name&#95;label

_Overview:_

This call returns a list of permission names given a subject

_Signature:_

```
string set get_permissions_name_label (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |The subject whose permissions will be retrieved|

_Minimum Role:_ read-only

_Return Type:_ `string set`

a list of permission names

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given subject.

_Signature:_

```
subject record get_record (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `subject record`

all fields from the object

#### RPC name: get&#95;roles

_Overview:_

Get the roles field of the given subject.

_Signature:_

```
role ref set get_roles (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `role ref set`

value of the field

#### RPC name: get&#95;subject&#95;identifier

_Overview:_

Get the subject&#95;identifier field of the given subject.

_Signature:_

```
string get_subject_identifier (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given subject.

_Signature:_

```
string get_uuid (session ref session_id, subject ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;roles

_Overview:_

This call removes a role from a subject

_Signature:_

```
void remove_from_roles (session ref session_id, subject ref self, role ref role)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`subject ref                 `|self                          |The subject from whom we want to remove the role|
|`role ref                    `|role                          |The unique role reference in the subject's roles field|

_Minimum Role:_ pool-admin

_Return Type:_ `void`

## Class: task

A long&#45;running asynchronous task

### Fields for class: task

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`task_allowed_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|backtrace           |`string            `|_RO/runtime_   |Function call trace for debugging.      |
|created             |`datetime          `|_RO/runtime_   |Time task was created                   |
|current&#95;operations|`(string -> task_allowed_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|error&#95;info      |`string set        `|_RO/runtime_   |if the task has failed, this field contains the set of associated error strings. Undefined otherwise.|
|finished            |`datetime          `|_RO/runtime_   |Time task finished &#40;i.e. succeeded or failed&#41;. If task&#45;status is pending, then the value of this field has no meaning|
|name&#95;description|`string            `|_RO/runtime_   |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/runtime_   |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|progress            |`float             `|_RO/runtime_   |This field contains the estimated fraction of the task which is complete. This field should not be used to determine whether the task is complete &#45; for this the status field of the task should be used.|
|resident&#95;on     |`host ref          `|_RO/runtime_   |the host on which the task is running   |
|result              |`string            `|_RO/runtime_   |if the task has completed successfully, this field contains the result value &#40;either Void or an object reference&#41;. Undefined otherwise.|
|status              |`task_status_type  `|_RO/runtime_   |current status of the task              |
|subtask&#95;of      |`task ref          `|_RO/runtime_   |Ref pointing to the task this is a substask of.|
|subtasks            |`task ref set      `|_RO/runtime_   |List pointing to all the substasks.     |
|type                |`string            `|_RO/runtime_   |if the task has completed successfully, this field contains the type of the encoded result &#40;i.e. name of the class whose reference is in the result field&#41;. Undefined otherwise.|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: task

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given task.

_Signature:_

```
void add_to_other_config (session ref session_id, task ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: cancel

_Overview:_

Request that a task be cancelled. Note that a task may fail to be cancelled and may complete or fail normally and note that, even when a task does cancel, it might take an arbitrary amount of time.

_Signature:_

```
void cancel (session ref session_id, task ref task)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|task                          |The task                                |

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_NOT_ALLOWED`

#### RPC name: create

_Overview:_

Create a new task object which must be manually destroyed.

_Signature:_

```
task ref create (session ref session_id, string label, string description)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |short label for the new task            |
|`string                      `|description                   |longer description for the new task     |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

The reference of the created task object

#### RPC name: destroy

_Overview:_

Destroy the task object

_Signature:_

```
void destroy (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |Reference to the task object            |

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the tasks known to the system.

_Signature:_

```
task ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of task references to task records for all tasks known to the system.

_Signature:_

```
(task ref -> task record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(task ref -> task record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given task.

_Signature:_

```
task_allowed_operations set get_allowed_operations (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task_allowed_operations set`

value of the field

#### RPC name: get&#95;backtrace

_Overview:_

Get the backtrace field of the given task.

_Signature:_

```
string get_backtrace (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the task instances with the given label.

_Signature:_

```
task ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the task instance with the specified UUID.

_Signature:_

```
task ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

reference to the object

#### RPC name: get&#95;created

_Overview:_

Get the created field of the given task.

_Signature:_

```
datetime get_created (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given task.

_Signature:_

```
(string -> task_allowed_operations) map get_current_operations (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> task_allowed_operations) map`

value of the field

#### RPC name: get&#95;error&#95;info

_Overview:_

Get the error&#95;info field of the given task.

_Signature:_

```
string set get_error_info (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;finished

_Overview:_

Get the finished field of the given task.

_Signature:_

```
datetime get_finished (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given task.

_Signature:_

```
string get_name_description (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given task.

_Signature:_

```
string get_name_label (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given task.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;progress

_Overview:_

Get the progress field of the given task.

_Signature:_

```
float get_progress (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given task.

_Signature:_

```
task record get_record (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task record`

all fields from the object

#### RPC name: get&#95;resident&#95;on

_Overview:_

Get the resident&#95;on field of the given task.

_Signature:_

```
host ref get_resident_on (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;result

_Overview:_

Get the result field of the given task.

_Signature:_

```
string get_result (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;status

_Overview:_

Get the status field of the given task.

_Signature:_

```
task_status_type get_status (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task_status_type`

value of the field

#### RPC name: get&#95;subtask&#95;of

_Overview:_

Get the subtask&#95;of field of the given task.

_Signature:_

```
task ref get_subtask_of (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref`

value of the field

#### RPC name: get&#95;subtasks

_Overview:_

Get the subtasks field of the given task.

_Signature:_

```
task ref set get_subtasks (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `task ref set`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given task.

_Signature:_

```
string get_type (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given task.

_Signature:_

```
string get_uuid (session ref session_id, task ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given task.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, task ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given task.

_Signature:_

```
void set_other_config (session ref session_id, task ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;progress

_Overview:_

Set the task progress

_Signature:_

```
void set_progress (session ref session_id, task ref self, float value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |Reference to the task object            |
|`float                       `|value                         |Task progress value to be set           |

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: set&#95;status

_Overview:_

Set the task status

_Signature:_

```
void set_status (session ref session_id, task ref self, task_status_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`task ref                    `|self                          |Reference to the task object            |
|`task_status_type            `|value                         |task status value to be set             |

_Minimum Role:_ read-only

_Return Type:_ `void`

## Class: tunnel

A tunnel for network traffic

### Fields for class: tunnel

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|access&#95;PIF      |`PIF ref           `|_RO/constructor_|The interface through which the tunnel is accessed|
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|protocol            |`tunnel_protocol   `|_RW_           |The protocol used for tunneling &#40;either GRE or VxLAN&#41;|
|status              |`(string -> string) map`|_RW_           |Status information about the tunnel     |
|transport&#95;PIF   |`PIF ref           `|_RO/constructor_|The interface used by the tunnel        |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: tunnel

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given tunnel.

_Signature:_

```
void add_to_other_config (session ref session_id, tunnel ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;status

_Overview:_

Add the given key&#45;value pair to the status field of the given tunnel.

_Signature:_

```
void add_to_status (session ref session_id, tunnel ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a tunnel

_Signature:_

```
tunnel ref create (session ref session_id, PIF ref transport_PIF, network ref network, tunnel_protocol protocol)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|transport&#95;PIF             |PIF which receives the tagged traffic   |
|`network ref                 `|network                       |Network to receive the tunnelled traffic|
|`tunnel_protocol             `|protocol                      |Protocol used for the tunnel &#40;GRE or VxLAN&#41;|

_Minimum Role:_ pool-operator

_Return Type:_ `tunnel ref`

The reference of the created tunnel object

_Possible Error Codes:_ `OPENVSWITCH_NOT_ACTIVE`, `TRANSPORT_PIF_NOT_CONFIGURED`, `IS_TUNNEL_ACCESS_PIF`

#### RPC name: destroy

_Overview:_

Destroy a tunnel

_Signature:_

```
void destroy (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |tunnel to destroy                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;access&#95;PIF

_Overview:_

Get the access&#95;PIF field of the given tunnel.

_Signature:_

```
PIF ref get_access_PIF (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the tunnels known to the system.

_Signature:_

```
tunnel ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of tunnel references to tunnel records for all tunnels known to the system.

_Signature:_

```
(tunnel ref -> tunnel record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(tunnel ref -> tunnel record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the tunnel instance with the specified UUID.

_Signature:_

```
tunnel ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `tunnel ref`

reference to the object

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given tunnel.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;protocol

_Overview:_

Get the protocol field of the given tunnel.

_Signature:_

```
tunnel_protocol get_protocol (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel_protocol`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given tunnel.

_Signature:_

```
tunnel record get_record (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tunnel record`

all fields from the object

#### RPC name: get&#95;status

_Overview:_

Get the status field of the given tunnel.

_Signature:_

```
(string -> string) map get_status (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;transport&#95;PIF

_Overview:_

Get the transport&#95;PIF field of the given tunnel.

_Signature:_

```
PIF ref get_transport_PIF (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given tunnel.

_Signature:_

```
string get_uuid (session ref session_id, tunnel ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given tunnel.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, tunnel ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;status

_Overview:_

Remove the given key and its corresponding value from the status field of the given tunnel.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_status (session ref session_id, tunnel ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given tunnel.

_Signature:_

```
void set_other_config (session ref session_id, tunnel ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;protocol

_Overview:_

Set the protocol field of the given tunnel.

_Signature:_

```
void set_protocol (session ref session_id, tunnel ref self, tunnel_protocol value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`tunnel_protocol             `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;status

_Overview:_

Set the status field of the given tunnel.

_Signature:_

```
void set_status (session ref session_id, tunnel ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`tunnel ref                  `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: USB&#95;group

A group of compatible USBs across the resource pool

### Fields for class: USB&#95;group

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|PUSBs               |`PUSB ref set      `|_RO/runtime_   |List of PUSBs in the group              |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VUSBs               |`VUSB ref set      `|_RO/runtime_   |List of VUSBs using the group           |

### RPCs associated with class: USB&#95;group

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given USB&#95;group.

_Signature:_

```
void add_to_other_config (session ref session_id, USB_group ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_



_Signature:_

```
USB_group ref create (session ref session_id, string name_label, string name_description, (string -> string) map other_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|name&#95;label                |                                        |
|`string                      `|name&#95;description          |                                        |
|`(string -> string) map      `|other&#95;config              |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `USB_group ref`

#### RPC name: destroy

_Overview:_



_Signature:_

```
void destroy (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |The USB group to destroy                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the USB&#95;groups known to the system.

_Signature:_

```
USB_group ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of USB&#95;group references to USB&#95;group records for all USB&#95;groups known to the system.

_Signature:_

```
(USB_group ref -> USB_group record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(USB_group ref -> USB_group record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the USB&#95;group instances with the given label.

_Signature:_

```
USB_group ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the USB&#95;group instance with the specified UUID.

_Signature:_

```
USB_group ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

reference to the object

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given USB&#95;group.

_Signature:_

```
string get_name_description (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given USB&#95;group.

_Signature:_

```
string get_name_label (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given USB&#95;group.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PUSBs

_Overview:_

Get the PUSBs field of the given USB&#95;group.

_Signature:_

```
PUSB ref set get_PUSBs (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given USB&#95;group.

_Signature:_

```
USB_group record get_record (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given USB&#95;group.

_Signature:_

```
string get_uuid (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VUSBs

_Overview:_

Get the VUSBs field of the given USB&#95;group.

_Signature:_

```
VUSB ref set get_VUSBs (session ref session_id, USB_group ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref set`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given USB&#95;group.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, USB_group ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given USB&#95;group.

_Signature:_

```
void set_name_description (session ref session_id, USB_group ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given USB&#95;group.

_Signature:_

```
void set_name_label (session ref session_id, USB_group ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given USB&#95;group.

_Signature:_

```
void set_other_config (session ref session_id, USB_group ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`USB_group ref               `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

## Class: user

**This class is deprecated.**

A user of the system

### Fields for class: user

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|fullname            |`string            `|_RW_           |**Deprecated**. full name               |
|other&#95;config    |`(string -> string) map`|_RW_           |**Deprecated**. additional configuration|
|short&#95;name      |`string            `|_RO/constructor_|**Deprecated**. short name &#40;e.g. userid&#41;|
|uuid                |`string            `|_RO/runtime_   |**Deprecated**. Unique identifier/object reference|

### RPCs associated with class: user

#### RPC name: add&#95;to&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given user.

_Signature:_

```
void add_to_other_config (session ref session_id, user ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: create

**This message is deprecated.**

_Overview:_

Create a new user instance, and return its handle.

_Signature:_

```
user ref create (session ref session_id, user record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user record                 `|args                          |All constructor arguments               |

_Minimum Role:_ pool-admin

_Return Type:_ `user ref`

reference to the newly created object

#### RPC name: destroy

**This message is deprecated.**

_Overview:_

Destroy the specified user instance.

_Signature:_

```
void destroy (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: get&#95;by&#95;uuid

**This message is deprecated.**

_Overview:_

Get a reference to the user instance with the specified UUID.

_Signature:_

```
user ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `user ref`

reference to the object

#### RPC name: get&#95;fullname

**This message is deprecated.**

_Overview:_

Get the fullname field of the given user.

_Signature:_

```
string get_fullname (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Get the other&#95;config field of the given user.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

**This message is deprecated.**

_Overview:_

Get a record containing the current state of the given user.

_Signature:_

```
user record get_record (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `user record`

all fields from the object

#### RPC name: get&#95;short&#95;name

**This message is deprecated.**

_Overview:_

Get the short&#95;name field of the given user.

_Signature:_

```
string get_short_name (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

**This message is deprecated.**

_Overview:_

Get the uuid field of the given user.

_Signature:_

```
string get_uuid (session ref session_id, user ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given user.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, user ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;fullname

**This message is deprecated.**

_Overview:_

Set the fullname field of the given user.

_Signature:_

```
void set_fullname (session ref session_id, user ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is deprecated.**

_Overview:_

Set the other&#95;config field of the given user.

_Signature:_

```
void set_other_config (session ref session_id, user ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`user ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

## Class: VBD

A virtual block device

### Fields for class: VBD

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`vbd_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|bootable            |`bool              `|_RW_           |true if this VBD is bootable            |
|current&#95;operations|`(string -> vbd_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|currently&#95;attached|`bool              `|_RO/constructor_|is the device currently attached &#40;erased on reboot&#41;|
|device              |`string            `|_RO/constructor_|device seen by the guest e.g. hda1      |
|empty               |`bool              `|_RO/constructor_|if true this represents an empty drive  |
|metrics             |`VBD_metrics ref   `|_RO/runtime_   |**Removed**. metrics associated with this VBD|
|mode                |`vbd_mode          `|_RO/constructor_|the mode the VBD should be mounted with |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|qos&#95;algorithm&#95;params|`(string -> string) map`|_RW_           |parameters for chosen QoS algorithm     |
|qos&#95;algorithm&#95;type|`string            `|_RW_           |QoS algorithm to use                    |
|qos&#95;supported&#95;algorithms|`string set        `|_RO/runtime_   |supported QoS algorithms for this VBD   |
|runtime&#95;properties|`(string -> string) map`|_RO/runtime_   |Device runtime properties               |
|status&#95;code     |`int               `|_RO/runtime_   |error/success code associated with last attach&#45;operation &#40;erased on reboot&#41;|
|status&#95;detail   |`string            `|_RO/runtime_   |error/success information associated with last attach&#45;operation status &#40;erased on reboot&#41;|
|storage&#95;lock    |`bool              `|_RO/runtime_   |true if a storage level lock was acquired|
|type                |`vbd_type          `|_RW_           |how the VBD will appear to the guest &#40;e.g. disk or CD&#41;|
|unpluggable         |`bool              `|_RW_           |true if this VBD will support hot&#45;unplug|
|userdevice          |`string            `|_RW_           |user&#45;friendly device name e.g. 0,1,2,etc.|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VDI                 |`VDI ref           `|_RO/constructor_|the virtual disk                        |
|VM                  |`VM ref            `|_RO/constructor_|the virtual machine                     |

### RPCs associated with class: VBD

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VBD.

_Signature:_

```
void add_to_other_config (session ref session_id, VBD ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;qos&#95;algorithm&#95;params

_Overview:_

Add the given key&#45;value pair to the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
void add_to_qos_algorithm_params (session ref session_id, VBD ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: assert&#95;attachable

_Overview:_

Throws an error if this VBD could not be attached to this VM if the VM were running. Intended for debugging.

_Signature:_

```
void assert_attachable (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |The VBD to query                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new VBD instance, and return its handle.

_Signature:_

```
VBD ref create (session ref session_id, VBD record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD record                  `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VBD ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified VBD instance.

_Signature:_

```
void destroy (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: eject

_Overview:_

Remove the media from the device and leave it empty

_Signature:_

```
void eject (session ref session_id, VBD ref vbd)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|vbd                           |The vbd representing the CDROM&#45;like device|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VBD_NOT_REMOVABLE_MEDIA`, `VBD_IS_EMPTY`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VBDs known to the system.

_Signature:_

```
VBD ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VBD ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VBD references to VBD records for all VBDs known to the system.

_Signature:_

```
(VBD ref -> VBD record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VBD ref -> VBD record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VBD.

_Signature:_

```
vbd_operations set get_allowed_operations (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_operations set`

value of the field

#### RPC name: get&#95;bootable

_Overview:_

Get the bootable field of the given VBD.

_Signature:_

```
bool get_bootable (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VBD instance with the specified UUID.

_Signature:_

```
VBD ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref`

reference to the object

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VBD.

_Signature:_

```
(string -> vbd_operations) map get_current_operations (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vbd_operations) map`

value of the field

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VBD.

_Signature:_

```
bool get_currently_attached (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device

_Overview:_

Get the device field of the given VBD.

_Signature:_

```
string get_device (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;empty

_Overview:_

Get the empty field of the given VBD.

_Signature:_

```
bool get_empty (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;metrics

**This message is removed.**

_Overview:_

Get the metrics field of the given VBD.

_Signature:_

```
VBD_metrics ref get_metrics (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD_metrics ref`

value of the field

#### RPC name: get&#95;mode

_Overview:_

Get the mode field of the given VBD.

_Signature:_

```
vbd_mode get_mode (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_mode`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VBD.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;qos&#95;algorithm&#95;params

_Overview:_

Get the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
(string -> string) map get_qos_algorithm_params (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;qos&#95;algorithm&#95;type

_Overview:_

Get the qos/algorithm&#95;type field of the given VBD.

_Signature:_

```
string get_qos_algorithm_type (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;qos&#95;supported&#95;algorithms

_Overview:_

Get the qos/supported&#95;algorithms field of the given VBD.

_Signature:_

```
string set get_qos_supported_algorithms (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VBD.

_Signature:_

```
VBD record get_record (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD record`

all fields from the object

#### RPC name: get&#95;runtime&#95;properties

_Overview:_

Get the runtime&#95;properties field of the given VBD.

_Signature:_

```
(string -> string) map get_runtime_properties (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;status&#95;code

_Overview:_

Get the status&#95;code field of the given VBD.

_Signature:_

```
int get_status_code (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;status&#95;detail

_Overview:_

Get the status&#95;detail field of the given VBD.

_Signature:_

```
string get_status_detail (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;storage&#95;lock

_Overview:_

Get the storage&#95;lock field of the given VBD.

_Signature:_

```
bool get_storage_lock (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given VBD.

_Signature:_

```
vbd_type get_type (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vbd_type`

value of the field

#### RPC name: get&#95;unpluggable

_Overview:_

Get the unpluggable field of the given VBD.

_Signature:_

```
bool get_unpluggable (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;userdevice

_Overview:_

Get the userdevice field of the given VBD.

_Signature:_

```
string get_userdevice (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VBD.

_Signature:_

```
string get_uuid (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VDI

_Overview:_

Get the VDI field of the given VBD.

_Signature:_

```
VDI ref get_VDI (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VBD.

_Signature:_

```
VM ref get_VM (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: insert

_Overview:_

Insert new media into the device

_Signature:_

```
void insert (session ref session_id, VBD ref vbd, VDI ref vdi)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|vbd                           |The vbd representing the CDROM&#45;like device|
|`VDI ref                     `|vdi                           |The new VDI to 'insert'                 |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VBD_NOT_REMOVABLE_MEDIA`, `VBD_NOT_EMPTY`

#### RPC name: plug

_Overview:_

Hotplug the specified VBD, dynamically attaching it to the running VM

_Signature:_

```
void plug (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |The VBD to hotplug                      |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VBD ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;qos&#95;algorithm&#95;params

_Overview:_

Remove the given key and its corresponding value from the qos/algorithm&#95;params field of the given VBD.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_qos_algorithm_params (session ref session_id, VBD ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;bootable

_Overview:_

Set the bootable field of the given VBD.

_Signature:_

```
void set_bootable (session ref session_id, VBD ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;mode

_Overview:_

Sets the mode of the VBD. The power&#95;state of the VM must be halted.

_Signature:_

```
void set_mode (session ref session_id, VBD ref self, vbd_mode value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |Reference to the object                 |
|`vbd_mode                    `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VBD.

_Signature:_

```
void set_other_config (session ref session_id, VBD ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;qos&#95;algorithm&#95;params

_Overview:_

Set the qos/algorithm&#95;params field of the given VBD.

_Signature:_

```
void set_qos_algorithm_params (session ref session_id, VBD ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;qos&#95;algorithm&#95;type

_Overview:_

Set the qos/algorithm&#95;type field of the given VBD.

_Signature:_

```
void set_qos_algorithm_type (session ref session_id, VBD ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;type

_Overview:_

Set the type field of the given VBD.

_Signature:_

```
void set_type (session ref session_id, VBD ref self, vbd_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`vbd_type                    `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;unpluggable

_Overview:_

Set the unpluggable field of the given VBD.

_Signature:_

```
void set_unpluggable (session ref session_id, VBD ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;userdevice

_Overview:_

Set the userdevice field of the given VBD.

_Signature:_

```
void set_userdevice (session ref session_id, VBD ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: unplug

_Overview:_

Hot&#45;unplug the specified VBD, dynamically unattaching it from the running VM

_Signature:_

```
void unplug (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |The VBD to hot&#45;unplug               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `DEVICE_DETACH_REJECTED`, `DEVICE_ALREADY_DETACHED`

#### RPC name: unplug&#95;force

_Overview:_

Forcibly unplug the specified VBD

_Signature:_

```
void unplug_force (session ref session_id, VBD ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD ref                     `|self                          |The VBD to forcibly unplug              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VBD&#95;metrics

**This class is removed.**

The metrics associated with a virtual block device

### Fields for class: VBD&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|io&#95;read&#95;kbs |`float             `|_RO/runtime_   |**Removed**. Read bandwidth &#40;KiB/s&#41;|
|io&#95;write&#95;kbs|`float             `|_RO/runtime_   |**Removed**. Write bandwidth &#40;KiB/s&#41;|
|last&#95;updated    |`datetime          `|_RO/runtime_   |**Removed**. Time at which this information was last updated|
|other&#95;config    |`(string -> string) map`|_RW_           |**Removed**. additional configuration   |
|uuid                |`string            `|_RO/runtime_   |**Removed**. Unique identifier/object reference|

### RPCs associated with class: VBD&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

**This message is removed.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VBD&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, VBD_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

**This message is removed.**

_Overview:_

Return a list of all the VBD&#95;metrics instances known to the system.

_Signature:_

```
VBD_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VBD_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is removed.**

_Overview:_

Return a map of VBD&#95;metrics references to VBD&#95;metrics records for all VBD&#95;metrics instances known to the system.

_Signature:_

```
(VBD_metrics ref -> VBD_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VBD_metrics ref -> VBD_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

**This message is removed.**

_Overview:_

Get a reference to the VBD&#95;metrics instance with the specified UUID.

_Signature:_

```
VBD_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VBD_metrics ref`

reference to the object

#### RPC name: get&#95;io&#95;read&#95;kbs

**This message is removed.**

_Overview:_

Get the io/read&#95;kbs field of the given VBD&#95;metrics.

_Signature:_

```
float get_io_read_kbs (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;io&#95;write&#95;kbs

**This message is removed.**

_Overview:_

Get the io/write&#95;kbs field of the given VBD&#95;metrics.

_Signature:_

```
float get_io_write_kbs (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;last&#95;updated

**This message is removed.**

_Overview:_

Get the last&#95;updated field of the given VBD&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is removed.**

_Overview:_

Get the other&#95;config field of the given VBD&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

**This message is removed.**

_Overview:_

Get a record containing the current state of the given VBD&#95;metrics.

_Signature:_

```
VBD_metrics record get_record (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD_metrics record`

all fields from the object

#### RPC name: get&#95;uuid

**This message is removed.**

_Overview:_

Get the uuid field of the given VBD&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, VBD_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is removed.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VBD&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VBD_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is removed.**

_Overview:_

Set the other&#95;config field of the given VBD&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, VBD_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VBD_metrics ref             `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VDI

A virtual disk image

### Fields for class: VDI

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allow&#95;caching   |`bool              `|_RO/runtime_   |true if this VDI is to be cached in the local cache SR|
|allowed&#95;operations|`vdi_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|cbt&#95;enabled     |`bool              `|_RO/runtime_   |True if changed blocks are tracked for this VDI|
|crash&#95;dumps     |`crashdump ref set `|_RO/runtime_   |list of crash dumps that refer to this disk|
|current&#95;operations|`(string -> vdi_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|is&#95;a&#95;snapshot|`bool              `|_RO/runtime_   |true if this is a snapshot.             |
|is&#95;tools&#95;iso|`bool              `|_RO/runtime_   |Whether this VDI is a Tools ISO         |
|location            |`string            `|_RO/runtime_   |location information                    |
|managed             |`bool              `|_RO/runtime_   |                                        |
|metadata&#95;latest |`bool              `|_RO/runtime_   |Whether this VDI contains the latest known accessible metadata for the pool|
|metadata&#95;of&#95;pool|`pool ref          `|_RO/runtime_   |The pool whose metadata is contained in this VDI|
|missing             |`bool              `|_RO/runtime_   |true if SR scan operation reported this VDI as not present on disk|
|name&#95;description|`string            `|_RO/constructor_|a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RO/constructor_|a human&#45;readable name               |
|on&#95;boot         |`on_boot           `|_RO/runtime_   |The behaviour of this VDI on a VM boot  |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|parent              |`VDI ref           `|_RO/runtime_   |**Deprecated**. This field is always null. Deprecated|
|physical&#95;utilisation|`int               `|_RO/runtime_   |amount of physical space that the disk image is currently taking up on the storage repository &#40;in bytes&#41;|
|read&#95;only       |`bool              `|_RO/constructor_|true if this disk may ONLY be mounted read&#45;only|
|sharable            |`bool              `|_RO/constructor_|true if this disk may be shared         |
|sm&#95;config       |`(string -> string) map`|_RW_           |SM dependent data                       |
|snapshot&#95;of     |`VDI ref           `|_RO/runtime_   |Ref pointing to the VDI this snapshot is of.|
|snapshot&#95;time   |`datetime          `|_RO/runtime_   |Date/time when this snapshot was created.|
|snapshots           |`VDI ref set       `|_RO/runtime_   |List pointing to all the VDIs snapshots.|
|SR                  |`SR ref            `|_RO/constructor_|storage repository in which the VDI resides|
|storage&#95;lock    |`bool              `|_RO/runtime_   |true if this disk is locked at the storage level|
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|type                |`vdi_type          `|_RO/constructor_|type of the VDI                         |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VBDs                |`VBD ref set       `|_RO/runtime_   |list of vbds that refer to this disk    |
|virtual&#95;size    |`int               `|_RO/constructor_|size of disk as presented to the guest &#40;in bytes&#41;. Note that, depending on storage backend type, requested size may not be respected exactly|
|xenstore&#95;data   |`(string -> string) map`|_RW_           |data to be inserted into the xenstore tree &#40;/local/domain/0/backend/vbd/&lt;domid&gt;/&lt;device&#45;id&gt;/sm&#45;data&#41; after the VDI is attached. This is generally set by the SM backends on vdi&#95;attach.|

### RPCs associated with class: VDI

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given VDI.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, VDI ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VDI.

_Signature:_

```
void add_to_other_config (session ref session_id, VDI ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;sm&#95;config

_Overview:_

Add the given key&#45;value pair to the sm&#95;config field of the given VDI.

_Signature:_

```
void add_to_sm_config (session ref session_id, VDI ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;xenstore&#95;data

_Overview:_

Add the given key&#45;value pair to the xenstore&#95;data field of the given VDI.

_Signature:_

```
void add_to_xenstore_data (session ref session_id, VDI ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: clone

_Overview:_

Take an exact copy of the VDI and return a reference to the new disk. If any driver&#95;params are specified then these are passed through to the storage&#45;specific substrate driver that implements the clone operation. NB the clone lives in the same Storage Repository as its parent.

_Signature:_

```
VDI ref clone (session ref session_id, VDI ref vdi, (string -> string) map driver_params)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to clone                        |
|`(string -> string) map      `|driver&#95;params             |Optional parameters that are passed through to the backend driver in order to specify storage&#45;type&#45;specific clone options|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ID of the newly created VDI.

#### RPC name: copy

_Overview:_

Copy either a full VDI or the block differences between two VDIs into either a fresh VDI or an existing VDI.

_Signature:_

```
VDI ref copy (session ref session_id, VDI ref vdi, SR ref sr, VDI ref base_vdi, VDI ref into_vdi)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to copy                         |
|`SR ref                      `|sr                            |The destination SR &#40;only required if the destination VDI is not specified|
|`VDI ref                     `|base&#95;vdi                  |The base VDI &#40;only required if copying only changed blocks, by default all blocks will be copied&#41;|
|`VDI ref                     `|into&#95;vdi                  |The destination VDI to copy blocks into &#40;if omitted then a destination SR must be provided and a fresh VDI will be created&#41;|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The reference of the VDI where the blocks were written.

_Possible Error Codes:_ `VDI_READONLY`, `VDI_TOO_SMALL`, `VDI_NOT_SPARSE`

#### RPC name: create

_Overview:_

Create a new VDI instance, and return its handle.

_Signature:_

```
VDI ref create (session ref session_id, VDI record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI record                  `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

reference to the newly created object

#### RPC name: data&#95;destroy

_Overview:_

Delete the data of the snapshot VDI, but keep its changed block tracking metadata. When successful, this call changes the type of the VDI to cbt&#95;metadata. This operation is idempotent: calling it on a VDI of type cbt&#95;metadata results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void data_destroy (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI whose data should be deleted.   |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_NO_CBT_METADATA`, `VDI_IN_USE`, `VDI_IS_A_PHYSICAL_DEVICE`

#### RPC name: destroy

_Overview:_

Destroy the specified VDI instance.

_Signature:_

```
void destroy (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: disable&#95;cbt

_Overview:_

Disable changed block tracking for the VDI. This call is only allowed on VDIs that support enabling CBT. It is an idempotent operation &#45; disabling CBT for a VDI for which CBT is not enabled results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void disable_cbt (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI for which CBT should be disabled|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_ON_BOOT_MODE_INCOMPATIBLE_WITH_OPERATION`

#### RPC name: enable&#95;cbt

_Overview:_

Enable changed block tracking for the VDI. This call is idempotent &#45; enabling CBT for a VDI for which CBT is already enabled results in a no&#45;op, and no error will be thrown.

_Signature:_

```
void enable_cbt (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI for which CBT should be enabled |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `OPERATION_NOT_ALLOWED`, `VDI_INCOMPATIBLE_TYPE`, `VDI_ON_BOOT_MODE_INCOMPATIBLE_WITH_OPERATION`

#### RPC name: forget

_Overview:_

Removes a VDI record from the database

_Signature:_

```
void forget (session ref session_id, VDI ref vdi)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to forget about                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VDIs known to the system.

_Signature:_

```
VDI ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VDI references to VDI records for all VDIs known to the system.

_Signature:_

```
(VDI ref -> VDI record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VDI ref -> VDI record) map`

records of all objects

#### RPC name: get&#95;allow&#95;caching

_Overview:_

Get the allow&#95;caching field of the given VDI.

_Signature:_

```
bool get_allow_caching (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VDI.

_Signature:_

```
vdi_operations set get_allowed_operations (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vdi_operations set`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VDI instances with the given label.

_Signature:_

```
VDI ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VDI instance with the specified UUID.

_Signature:_

```
VDI ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

reference to the object

#### RPC name: get&#95;cbt&#95;enabled

_Overview:_

Get the cbt&#95;enabled field of the given VDI.

_Signature:_

```
bool get_cbt_enabled (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;crash&#95;dumps

_Overview:_

Get the crash&#95;dumps field of the given VDI.

_Signature:_

```
crashdump ref set get_crash_dumps (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `crashdump ref set`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VDI.

_Signature:_

```
(string -> vdi_operations) map get_current_operations (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vdi_operations) map`

value of the field

#### RPC name: get&#95;is&#95;a&#95;snapshot

_Overview:_

Get the is&#95;a&#95;snapshot field of the given VDI.

_Signature:_

```
bool get_is_a_snapshot (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;tools&#95;iso

_Overview:_

Get the is&#95;tools&#95;iso field of the given VDI.

_Signature:_

```
bool get_is_tools_iso (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;location

_Overview:_

Get the location field of the given VDI.

_Signature:_

```
string get_location (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;managed

_Overview:_

Get the managed field of the given VDI.

_Signature:_

```
bool get_managed (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;metadata&#95;latest

_Overview:_

Get the metadata&#95;latest field of the given VDI.

_Signature:_

```
bool get_metadata_latest (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;metadata&#95;of&#95;pool

_Overview:_

Get the metadata&#95;of&#95;pool field of the given VDI.

_Signature:_

```
pool ref get_metadata_of_pool (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `pool ref`

value of the field

#### RPC name: get&#95;missing

_Overview:_

Get the missing field of the given VDI.

_Signature:_

```
bool get_missing (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VDI.

_Signature:_

```
string get_name_description (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VDI.

_Signature:_

```
string get_name_label (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;nbd&#95;info

_Overview:_

Get details specifying how to access this VDI via a Network Block Device server. For each of a set of NBD server addresses on which the VDI is available, the return value set contains a vdi&#95;nbd&#95;server&#95;info object that contains an exportname to request once the NBD connection is established, and connection details for the address. An empty list is returned if there is no network that has a PIF on a host with access to the relevant SR, or if no such network has been assigned an NBD&#45;related purpose in its purpose field. To access the given VDI, any of the vdi&#95;nbd&#95;server&#95;info objects can be used to make a connection to a server, and then the VDI will be available by requesting the exportname.

_Signature:_

```
vdi_nbd_server_info record set get_nbd_info (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to access via Network Block Device protocol|

_Minimum Role:_ vm-admin

_Return Type:_ `vdi_nbd_server_info record set`

The details necessary for connecting to the VDI over NBD. This includes an authentication token, so must be treated as sensitive material and must not be sent over insecure networks.

_Possible Error Codes:_ `VDI_INCOMPATIBLE_TYPE`

#### RPC name: get&#95;on&#95;boot

_Overview:_

Get the on&#95;boot field of the given VDI.

_Signature:_

```
on_boot get_on_boot (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `on_boot`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VDI.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;parent

**This message is deprecated.**

_Overview:_

Get the parent field of the given VDI.

_Signature:_

```
VDI ref get_parent (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;physical&#95;utilisation

_Overview:_

Get the physical&#95;utilisation field of the given VDI.

_Signature:_

```
int get_physical_utilisation (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;read&#95;only

_Overview:_

Get the read&#95;only field of the given VDI.

_Signature:_

```
bool get_read_only (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VDI.

_Signature:_

```
VDI record get_record (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI record`

all fields from the object

#### RPC name: get&#95;sharable

_Overview:_

Get the sharable field of the given VDI.

_Signature:_

```
bool get_sharable (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;sm&#95;config

_Overview:_

Get the sm&#95;config field of the given VDI.

_Signature:_

```
(string -> string) map get_sm_config (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;snapshot&#95;of

_Overview:_

Get the snapshot&#95;of field of the given VDI.

_Signature:_

```
VDI ref get_snapshot_of (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;snapshot&#95;time

_Overview:_

Get the snapshot&#95;time field of the given VDI.

_Signature:_

```
datetime get_snapshot_time (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;snapshots

_Overview:_

Get the snapshots field of the given VDI.

_Signature:_

```
VDI ref set get_snapshots (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref set`

value of the field

#### RPC name: get&#95;SR

_Overview:_

Get the SR field of the given VDI.

_Signature:_

```
SR ref get_SR (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;storage&#95;lock

_Overview:_

Get the storage&#95;lock field of the given VDI.

_Signature:_

```
bool get_storage_lock (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given VDI.

_Signature:_

```
string set get_tags (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given VDI.

_Signature:_

```
vdi_type get_type (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vdi_type`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VDI.

_Signature:_

```
string get_uuid (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VBDs

_Overview:_

Get the VBDs field of the given VDI.

_Signature:_

```
VBD ref set get_VBDs (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref set`

value of the field

#### RPC name: get&#95;virtual&#95;size

_Overview:_

Get the virtual&#95;size field of the given VDI.

_Signature:_

```
int get_virtual_size (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;xenstore&#95;data

_Overview:_

Get the xenstore&#95;data field of the given VDI.

_Signature:_

```
(string -> string) map get_xenstore_data (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: introduce

_Overview:_

Create a new VDI record in the database only

_Signature:_

```
VDI ref introduce (session ref session_id, string uuid, string name_label, string name_description, SR ref SR, vdi_type type, bool sharable, bool read_only, (string -> string) map other_config, string location, (string -> string) map xenstore_data, (string -> string) map sm_config, bool managed, int virtual_size, int physical_utilisation, pool ref metadata_of_pool, bool is_a_snapshot, datetime snapshot_time, VDI ref snapshot_of)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |The uuid of the disk to introduce       |
|`string                      `|name&#95;label                |The name of the disk record             |
|`string                      `|name&#95;description          |The description of the disk record      |
|`SR ref                      `|SR                            |The SR that the VDI is in               |
|`vdi_type                    `|type                          |The type of the VDI                     |
|`bool                        `|sharable                      |true if this disk may be shared         |
|`bool                        `|read&#95;only                 |true if this disk may ONLY be mounted read&#45;only|
|`(string -> string) map      `|other&#95;config              |additional configuration                |
|`string                      `|location                      |location information                    |
|`(string -> string) map      `|xenstore&#95;data             |Data to insert into xenstore            |
|`(string -> string) map      `|sm&#95;config                 |Storage&#45;specific config             |
|`bool                        `|managed                       |Storage&#45;specific config             |
|`int                         `|virtual&#95;size              |Storage&#45;specific config             |
|`int                         `|physical&#95;utilisation      |Storage&#45;specific config             |
|`pool ref                    `|metadata&#95;of&#95;pool      |Storage&#45;specific config             |
|`bool                        `|is&#95;a&#95;snapshot         |Storage&#45;specific config             |
|`datetime                    `|snapshot&#95;time             |Storage&#45;specific config             |
|`VDI ref                     `|snapshot&#95;of               |Storage&#45;specific config             |

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ref of the newly created VDI record.

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`

#### RPC name: list&#95;changed&#95;blocks

_Overview:_

Compare two VDIs in 64k block increments and report which blocks differ. This operation is not allowed when vdi&#95;to is attached to a VM.

_Signature:_

```
string list_changed_blocks (session ref session_id, VDI ref vdi_from, VDI ref vdi_to)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi&#95;from                  |The first VDI.                          |
|`VDI ref                     `|vdi&#95;to                    |The second VDI.                         |

_Minimum Role:_ vm-operator

_Return Type:_ `string`

A base64 string&#45;encoding of the bitmap showing which blocks differ in the two VDIs.

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`, `VDI_MISSING`, `SR_NOT_ATTACHED`, `SR_HAS_NO_PBDS`, `VDI_IN_USE`

#### RPC name: open&#95;database

_Overview:_

Load the metadata found on the supplied VDI and return a session reference which can be used in API calls to query its contents.

_Signature:_

```
session ref open_database (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI which contains the database to open|

_Minimum Role:_ pool-operator

_Return Type:_ `session ref`

A session which can be used to query the database

#### RPC name: pool&#95;migrate

_Overview:_

Migrate a VDI, which may be attached to a running guest, to a different SR. The destination SR must be visible to the guest.

_Signature:_

```
VDI ref pool_migrate (session ref session_id, VDI ref vdi, SR ref sr, (string -> string) map options)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to migrate                      |
|`SR ref                      `|sr                            |The destination SR                      |
|`(string -> string) map      `|options                       |Other parameters                        |

_Minimum Role:_ vm-power-admin

_Return Type:_ `VDI ref`

The new reference of the migrated VDI.

#### RPC name: read&#95;database&#95;pool&#95;uuid

_Overview:_

Check the VDI cache for the pool UUID of the database on this VDI.

_Signature:_

```
string read_database_pool_uuid (session ref session_id, VDI ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The metadata VDI to look up in the cache.|

_Minimum Role:_ read-only

_Return Type:_ `string`

The cached pool UUID of the database on the VDI.

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VDI ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;sm&#95;config

_Overview:_

Remove the given key and its corresponding value from the sm&#95;config field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_sm_config (session ref session_id, VDI ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;xenstore&#95;data

_Overview:_

Remove the given key and its corresponding value from the xenstore&#95;data field of the given VDI.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_xenstore_data (session ref session_id, VDI ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given VDI.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, VDI ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: resize

_Overview:_

Resize the VDI.

_Signature:_

```
void resize (session ref session_id, VDI ref vdi, int size)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to resize                       |
|`int                         `|size                          |The new size of the VDI                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: resize&#95;online

**This message is removed.**

_Overview:_

Resize the VDI which may or may not be attached to running guests.

_Signature:_

```
void resize_online (session ref session_id, VDI ref vdi, int size)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to resize                       |
|`int                         `|size                          |The new size of the VDI                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;allow&#95;caching

_Overview:_

Set the value of the allow&#95;caching parameter. This value can only be changed when the VDI is not attached to a running VM. The caching behaviour is only affected by this flag for VHD&#45;based VDIs that have one parent and no child VHDs. Moreover, caching only takes place when the host running the VM containing this VDI has a nominated SR for local caching.

_Signature:_

```
void set_allow_caching (session ref session_id, VDI ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`bool                        `|value                         |The value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name description of the VDI. This can only happen when its SR is currently attached.

_Signature:_

```
void set_name_description (session ref session_id, VDI ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`string                      `|value                         |The name description for the VDI        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name label of the VDI. This can only happen when then its SR is currently attached.

_Signature:_

```
void set_name_label (session ref session_id, VDI ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`string                      `|value                         |The name lable for the VDI              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;on&#95;boot

_Overview:_

Set the value of the on&#95;boot parameter. This value can only be changed when the VDI is not attached to a running VM.

_Signature:_

```
void set_on_boot (session ref session_id, VDI ref self, on_boot value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`on_boot                     `|value                         |The value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VDI.

_Signature:_

```
void set_other_config (session ref session_id, VDI ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;read&#95;only

_Overview:_

Sets the VDI's read&#95;only field

_Signature:_

```
void set_read_only (session ref session_id, VDI ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`bool                        `|value                         |The new value of the VDI's read&#95;only field|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;sharable

_Overview:_

Sets the VDI's sharable field

_Signature:_

```
void set_sharable (session ref session_id, VDI ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |The VDI to modify                       |
|`bool                        `|value                         |The new value of the VDI's sharable field|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;sm&#95;config

_Overview:_

Set the sm&#95;config field of the given VDI.

_Signature:_

```
void set_sm_config (session ref session_id, VDI ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given VDI.

_Signature:_

```
void set_tags (session ref session_id, VDI ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;xenstore&#95;data

_Overview:_

Set the xenstore&#95;data field of the given VDI.

_Signature:_

```
void set_xenstore_data (session ref session_id, VDI ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: snapshot

_Overview:_

Take a read&#45;only snapshot of the VDI, returning a reference to the snapshot. If any driver&#95;params are specified then these are passed through to the storage&#45;specific substrate driver that takes the snapshot. NB the snapshot lives in the same Storage Repository as its parent.

_Signature:_

```
VDI ref snapshot (session ref session_id, VDI ref vdi, (string -> string) map driver_params)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI to snapshot                     |
|`(string -> string) map      `|driver&#95;params             |Optional parameters that can be passed through to backend driver in order to specify storage&#45;type&#45;specific snapshot options|

_Minimum Role:_ vm-admin

_Return Type:_ `VDI ref`

The ID of the newly created VDI.

#### RPC name: update

_Overview:_

Ask the storage backend to refresh the fields in the VDI object

_Signature:_

```
void update (session ref session_id, VDI ref vdi)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VDI ref                     `|vdi                           |The VDI whose stats &#40;eg size&#41; should be updated|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `SR_OPERATION_NOT_SUPPORTED`

## Class: vdi&#95;nbd&#95;server&#95;info

Details for connecting to a VDI using the Network Block Device protocol

### Fields for class: vdi&#95;nbd&#95;server&#95;info

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|address             |`string            `|_RO/runtime_   |An address on which the server can be reached; this can be IPv4, IPv6, or a DNS name.|
|cert                |`string            `|_RO/runtime_   |The TLS certificate of the server       |
|exportname          |`string            `|_RO/runtime_   |The exportname to request over NBD. This holds details including an authentication token, so it must be protected appropriately. Clients should regard the exportname as an opaque string or token.|
|port                |`int               `|_RO/runtime_   |The TCP port                            |
|subject             |`string            `|_RO/runtime_   |For convenience, this redundant field holds a DNS &#40;hostname&#41; subject of the certificate. This can be a wildcard, but only for a certificate that has a wildcard subject and no concrete hostname subjects.|

### RPCs associated with class: vdi&#95;nbd&#95;server&#95;info

Class vdi&#95;nbd&#95;server&#95;info has no additional RPCs associated with it.

## Class: VGPU

A virtual GPU &#40;vGPU&#41;

### Fields for class: VGPU

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|compatibility&#95;metadata|`(string -> string) map`|_RO/runtime_   |VGPU metadata to determine whether a VGPU can migrate between two PGPUs|
|currently&#95;attached|`bool              `|_RO/runtime_   |Reflects whether the virtual device is currently connected to a physical device|
|device              |`string            `|_RO/runtime_   |Order in which the devices are plugged into the VM|
|extra&#95;args      |`string            `|_RW_           |Extra arguments for vGPU and passed to demu|
|GPU&#95;group       |`GPU_group ref     `|_RO/runtime_   |GPU group used by the vGPU              |
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|PCI                 |`PCI ref           `|_RO/runtime_   |Device passed trough to VM, either as full device or SR&#45;IOV virtual function|
|resident&#95;on     |`PGPU ref          `|_RO/runtime_   |The PGPU on which this VGPU is running  |
|scheduled&#95;to&#95;be&#95;resident&#95;on|`PGPU ref          `|_RO/runtime_   |The PGPU on which this VGPU is scheduled to run|
|type                |`VGPU_type ref     `|_RO/runtime_   |Preset type for this VGPU               |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VM                  |`VM ref            `|_RO/runtime_   |VM that owns the vGPU                   |

### RPCs associated with class: VGPU

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VGPU.

_Signature:_

```
void add_to_other_config (session ref session_id, VGPU ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_



_Signature:_

```
VGPU ref create (session ref session_id, VM ref VM, GPU_group ref GPU_group, string device, (string -> string) map other_config, VGPU_type ref type)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|VM                            |                                        |
|`GPU_group ref               `|GPU&#95;group                 |                                        |
|`string                      `|device                        |                                        |
|`(string -> string) map      `|other&#95;config              |                                        |
|`VGPU_type ref               `|type                          |                                        |

_Minimum Role:_ pool-operator

_Return Type:_ `VGPU ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_



_Signature:_

```
void destroy (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |The vGPU to destroy                     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VGPUs known to the system.

_Signature:_

```
VGPU ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VGPU references to VGPU records for all VGPUs known to the system.

_Signature:_

```
(VGPU ref -> VGPU record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VGPU ref -> VGPU record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VGPU instance with the specified UUID.

_Signature:_

```
VGPU ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref`

reference to the object

#### RPC name: get&#95;compatibility&#95;metadata

_Overview:_

Get the compatibility&#95;metadata field of the given VGPU.

_Signature:_

```
(string -> string) map get_compatibility_metadata (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VGPU.

_Signature:_

```
bool get_currently_attached (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device

_Overview:_

Get the device field of the given VGPU.

_Signature:_

```
string get_device (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;extra&#95;args

_Overview:_

Get the extra&#95;args field of the given VGPU.

_Signature:_

```
string get_extra_args (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;GPU&#95;group

_Overview:_

Get the GPU&#95;group field of the given VGPU.

_Signature:_

```
GPU_group ref get_GPU_group (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VGPU.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PCI

_Overview:_

Get the PCI field of the given VGPU.

_Signature:_

```
PCI ref get_PCI (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VGPU.

_Signature:_

```
VGPU record get_record (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU record`

all fields from the object

#### RPC name: get&#95;resident&#95;on

_Overview:_

Get the resident&#95;on field of the given VGPU.

_Signature:_

```
PGPU ref get_resident_on (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

value of the field

#### RPC name: get&#95;scheduled&#95;to&#95;be&#95;resident&#95;on

_Overview:_

Get the scheduled&#95;to&#95;be&#95;resident&#95;on field of the given VGPU.

_Signature:_

```
PGPU ref get_scheduled_to_be_resident_on (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given VGPU.

_Signature:_

```
VGPU_type ref get_type (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VGPU.

_Signature:_

```
string get_uuid (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VGPU.

_Signature:_

```
VM ref get_VM (session ref session_id, VGPU ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VGPU.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VGPU ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;extra&#95;args

_Overview:_

Set the extra&#95;args field of the given VGPU.

_Signature:_

```
void set_extra_args (session ref session_id, VGPU ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VGPU.

_Signature:_

```
void set_other_config (session ref session_id, VGPU ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: VGPU&#95;type

A type of virtual GPU

### Fields for class: VGPU&#95;type

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|compatible&#95;types&#95;in&#95;vm|`VGPU_type ref set `|_RO/runtime_   |List of VGPU types which are compatible in one VM|
|enabled&#95;on&#95;GPU&#95;groups|`GPU_group ref set `|_RO/runtime_   |List of GPU groups in which at least one have this VGPU type enabled|
|enabled&#95;on&#95;PGPUs|`PGPU ref set      `|_RO/runtime_   |List of PGPUs that have this VGPU type enabled|
|experimental        |`bool              `|_RO/constructor_|Indicates whether VGPUs of this type should be considered experimental|
|framebuffer&#95;size|`int               `|_RO/constructor_|Framebuffer size of the VGPU type, in bytes|
|identifier          |`string            `|_RO/constructor_|Key used to identify VGPU types and avoid creating duplicates &#45; this field is used internally and not intended for interpretation by API clients|
|implementation      |`vgpu_type_implementation`|_RO/constructor_|The internal implementation of this VGPU type|
|max&#95;heads       |`int               `|_RO/constructor_|Maximum number of displays supported by the VGPU type|
|max&#95;resolution&#95;x|`int               `|_RO/constructor_|Maximum resolution &#40;width&#41; supported by the VGPU type|
|max&#95;resolution&#95;y|`int               `|_RO/constructor_|Maximum resolution &#40;height&#41; supported by the VGPU type|
|model&#95;name      |`string            `|_RO/constructor_|Model name associated with the VGPU type|
|supported&#95;on&#95;GPU&#95;groups|`GPU_group ref set `|_RO/runtime_   |List of GPU groups in which at least one PGPU supports this VGPU type|
|supported&#95;on&#95;PGPUs|`PGPU ref set      `|_RO/runtime_   |List of PGPUs that support this VGPU type|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|vendor&#95;name     |`string            `|_RO/constructor_|Name of VGPU vendor                     |
|VGPUs               |`VGPU ref set      `|_RO/runtime_   |List of VGPUs of this type              |

### RPCs associated with class: VGPU&#95;type

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VGPU&#95;types known to the system.

_Signature:_

```
VGPU_type ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VGPU&#95;type references to VGPU&#95;type records for all VGPU&#95;types known to the system.

_Signature:_

```
(VGPU_type ref -> VGPU_type record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VGPU_type ref -> VGPU_type record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VGPU&#95;type instance with the specified UUID.

_Signature:_

```
VGPU_type ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref`

reference to the object

#### RPC name: get&#95;compatible&#95;types&#95;in&#95;vm

_Overview:_

Get the compatible&#95;types&#95;in&#95;vm field of the given VGPU&#95;type.

_Signature:_

```
VGPU_type ref set get_compatible_types_in_vm (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type ref set`

value of the field

#### RPC name: get&#95;enabled&#95;on&#95;GPU&#95;groups

_Overview:_

Get the enabled&#95;on&#95;GPU&#95;groups field of the given VGPU&#95;type.

_Signature:_

```
GPU_group ref set get_enabled_on_GPU_groups (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

value of the field

#### RPC name: get&#95;enabled&#95;on&#95;PGPUs

_Overview:_

Get the enabled&#95;on&#95;PGPUs field of the given VGPU&#95;type.

_Signature:_

```
PGPU ref set get_enabled_on_PGPUs (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

#### RPC name: get&#95;experimental

_Overview:_

Get the experimental field of the given VGPU&#95;type.

_Signature:_

```
bool get_experimental (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;framebuffer&#95;size

_Overview:_

Get the framebuffer&#95;size field of the given VGPU&#95;type.

_Signature:_

```
int get_framebuffer_size (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;identifier

_Overview:_

Get the identifier field of the given VGPU&#95;type.

_Signature:_

```
string get_identifier (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;implementation

_Overview:_

Get the implementation field of the given VGPU&#95;type.

_Signature:_

```
vgpu_type_implementation get_implementation (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vgpu_type_implementation`

value of the field

#### RPC name: get&#95;max&#95;heads

_Overview:_

Get the max&#95;heads field of the given VGPU&#95;type.

_Signature:_

```
int get_max_heads (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;max&#95;resolution&#95;x

_Overview:_

Get the max&#95;resolution&#95;x field of the given VGPU&#95;type.

_Signature:_

```
int get_max_resolution_x (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;max&#95;resolution&#95;y

_Overview:_

Get the max&#95;resolution&#95;y field of the given VGPU&#95;type.

_Signature:_

```
int get_max_resolution_y (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;model&#95;name

_Overview:_

Get the model&#95;name field of the given VGPU&#95;type.

_Signature:_

```
string get_model_name (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VGPU&#95;type.

_Signature:_

```
VGPU_type record get_record (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU_type record`

all fields from the object

#### RPC name: get&#95;supported&#95;on&#95;GPU&#95;groups

_Overview:_

Get the supported&#95;on&#95;GPU&#95;groups field of the given VGPU&#95;type.

_Signature:_

```
GPU_group ref set get_supported_on_GPU_groups (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `GPU_group ref set`

value of the field

#### RPC name: get&#95;supported&#95;on&#95;PGPUs

_Overview:_

Get the supported&#95;on&#95;PGPUs field of the given VGPU&#95;type.

_Signature:_

```
PGPU ref set get_supported_on_PGPUs (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PGPU ref set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VGPU&#95;type.

_Signature:_

```
string get_uuid (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;vendor&#95;name

_Overview:_

Get the vendor&#95;name field of the given VGPU&#95;type.

_Signature:_

```
string get_vendor_name (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VGPUs

_Overview:_

Get the VGPUs field of the given VGPU&#95;type.

_Signature:_

```
VGPU ref set get_VGPUs (session ref session_id, VGPU_type ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VGPU_type ref               `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

## Class: VIF

A virtual network interface

### Fields for class: VIF

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`vif_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|current&#95;operations|`(string -> vif_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|currently&#95;attached|`bool              `|_RO/constructor_|is the device currently attached &#40;erased on reboot&#41;|
|device              |`string            `|_RO/constructor_|order in which VIF backends are created by xapi|
|ipv4&#95;addresses  |`string set        `|_RO/runtime_   |IPv4 addresses in CIDR format           |
|ipv4&#95;allowed    |`string set        `|_RO/constructor_|A list of IPv4 addresses which can be used to filter traffic passing through this VIF|
|ipv4&#95;configuration&#95;mode|`vif_ipv4_configuration_mode`|_RO/runtime_   |Determines whether IPv4 addresses are configured on the VIF|
|ipv4&#95;gateway    |`string            `|_RO/runtime_   |IPv4 gateway &#40;the empty string means that no gateway is set&#41;|
|ipv6&#95;addresses  |`string set        `|_RO/runtime_   |IPv6 addresses in CIDR format           |
|ipv6&#95;allowed    |`string set        `|_RO/constructor_|A list of IPv6 addresses which can be used to filter traffic passing through this VIF|
|ipv6&#95;configuration&#95;mode|`vif_ipv6_configuration_mode`|_RO/runtime_   |Determines whether IPv6 addresses are configured on the VIF|
|ipv6&#95;gateway    |`string            `|_RO/runtime_   |IPv6 gateway &#40;the empty string means that no gateway is set&#41;|
|locking&#95;mode    |`vif_locking_mode  `|_RO/constructor_|current locking mode of the VIF         |
|MAC                 |`string            `|_RO/constructor_|ethernet MAC address of virtual interface, as exposed to guest|
|MAC&#95;autogenerated|`bool              `|_RO/runtime_   |true if the MAC was autogenerated; false indicates it was set manually|
|metrics             |`VIF_metrics ref   `|_RO/runtime_   |**Removed**. metrics associated with this VIF|
|MTU                 |`int               `|_RO/constructor_|MTU in octets                           |
|network             |`network ref       `|_RO/constructor_|virtual network to which this vif is connected|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|qos&#95;algorithm&#95;params|`(string -> string) map`|_RW_           |parameters for chosen QoS algorithm     |
|qos&#95;algorithm&#95;type|`string            `|_RW_           |QoS algorithm to use                    |
|qos&#95;supported&#95;algorithms|`string set        `|_RO/runtime_   |supported QoS algorithms for this VIF   |
|runtime&#95;properties|`(string -> string) map`|_RO/runtime_   |Device runtime properties               |
|status&#95;code     |`int               `|_RO/runtime_   |error/success code associated with last attach&#45;operation &#40;erased on reboot&#41;|
|status&#95;detail   |`string            `|_RO/runtime_   |error/success information associated with last attach&#45;operation status &#40;erased on reboot&#41;|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VM                  |`VM ref            `|_RO/constructor_|virtual machine to which this vif is connected|

### RPCs associated with class: VIF

#### RPC name: add&#95;ipv4&#95;allowed

_Overview:_

Associates an IPv4 address with this VIF

_Signature:_

```
void add_ipv4_allowed (session ref session_id, VIF ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF which the IP address will be associated with|
|`string                      `|value                         |The IP address which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;ipv6&#95;allowed

_Overview:_

Associates an IPv6 address with this VIF

_Signature:_

```
void add_ipv6_allowed (session ref session_id, VIF ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF which the IP address will be associated with|
|`string                      `|value                         |The IP address which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VIF.

_Signature:_

```
void add_to_other_config (session ref session_id, VIF ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;qos&#95;algorithm&#95;params

_Overview:_

Add the given key&#45;value pair to the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
void add_to_qos_algorithm_params (session ref session_id, VIF ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: configure&#95;ipv4

_Overview:_

Configure IPv4 settings for this virtual interface

_Signature:_

```
void configure_ipv4 (session ref session_id, VIF ref self, vif_ipv4_configuration_mode mode, string address, string gateway)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to configure                    |
|`vif_ipv4_configuration_mode `|mode                          |Whether to use static or no IPv4 assignment|
|`string                      `|address                       |The IPv4 address in &lt;addr&gt;/&lt;prefix length&gt; format &#40;for static mode only&#41;|
|`string                      `|gateway                       |The IPv4 gateway &#40;for static mode only; leave empty to not set a gateway&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: configure&#95;ipv6

_Overview:_

Configure IPv6 settings for this virtual interface

_Signature:_

```
void configure_ipv6 (session ref session_id, VIF ref self, vif_ipv6_configuration_mode mode, string address, string gateway)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to configure                    |
|`vif_ipv6_configuration_mode `|mode                          |Whether to use static or no IPv6 assignment|
|`string                      `|address                       |The IPv6 address in &lt;addr&gt;/&lt;prefix length&gt; format &#40;for static mode only&#41;|
|`string                      `|gateway                       |The IPv6 gateway &#40;for static mode only; leave empty to not set a gateway&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new VIF instance, and return its handle.

_Signature:_

```
VIF ref create (session ref session_id, VIF record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF record                  `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VIF ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified VIF instance.

_Signature:_

```
void destroy (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VIFs known to the system.

_Signature:_

```
VIF ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VIF ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VIF references to VIF records for all VIFs known to the system.

_Signature:_

```
(VIF ref -> VIF record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VIF ref -> VIF record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VIF.

_Signature:_

```
vif_operations set get_allowed_operations (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_operations set`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VIF instance with the specified UUID.

_Signature:_

```
VIF ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref`

reference to the object

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VIF.

_Signature:_

```
(string -> vif_operations) map get_current_operations (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vif_operations) map`

value of the field

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VIF.

_Signature:_

```
bool get_currently_attached (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;device

_Overview:_

Get the device field of the given VIF.

_Signature:_

```
string get_device (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;ipv4&#95;addresses

_Overview:_

Get the ipv4&#95;addresses field of the given VIF.

_Signature:_

```
string set get_ipv4_addresses (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ipv4&#95;allowed

_Overview:_

Get the ipv4&#95;allowed field of the given VIF.

_Signature:_

```
string set get_ipv4_allowed (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ipv4&#95;configuration&#95;mode

_Overview:_

Get the ipv4&#95;configuration&#95;mode field of the given VIF.

_Signature:_

```
vif_ipv4_configuration_mode get_ipv4_configuration_mode (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_ipv4_configuration_mode`

value of the field

#### RPC name: get&#95;ipv4&#95;gateway

_Overview:_

Get the ipv4&#95;gateway field of the given VIF.

_Signature:_

```
string get_ipv4_gateway (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;ipv6&#95;addresses

_Overview:_

Get the ipv6&#95;addresses field of the given VIF.

_Signature:_

```
string set get_ipv6_addresses (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ipv6&#95;allowed

_Overview:_

Get the ipv6&#95;allowed field of the given VIF.

_Signature:_

```
string set get_ipv6_allowed (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;ipv6&#95;configuration&#95;mode

_Overview:_

Get the ipv6&#95;configuration&#95;mode field of the given VIF.

_Signature:_

```
vif_ipv6_configuration_mode get_ipv6_configuration_mode (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_ipv6_configuration_mode`

value of the field

#### RPC name: get&#95;ipv6&#95;gateway

_Overview:_

Get the ipv6&#95;gateway field of the given VIF.

_Signature:_

```
string get_ipv6_gateway (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;locking&#95;mode

_Overview:_

Get the locking&#95;mode field of the given VIF.

_Signature:_

```
vif_locking_mode get_locking_mode (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vif_locking_mode`

value of the field

#### RPC name: get&#95;MAC

_Overview:_

Get the MAC field of the given VIF.

_Signature:_

```
string get_MAC (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;MAC&#95;autogenerated

_Overview:_

Get the MAC&#95;autogenerated field of the given VIF.

_Signature:_

```
bool get_MAC_autogenerated (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;metrics

**This message is removed.**

_Overview:_

Get the metrics field of the given VIF.

_Signature:_

```
VIF_metrics ref get_metrics (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF_metrics ref`

value of the field

#### RPC name: get&#95;MTU

_Overview:_

Get the MTU field of the given VIF.

_Signature:_

```
int get_MTU (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;network

_Overview:_

Get the network field of the given VIF.

_Signature:_

```
network ref get_network (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `network ref`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VIF.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;qos&#95;algorithm&#95;params

_Overview:_

Get the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
(string -> string) map get_qos_algorithm_params (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;qos&#95;algorithm&#95;type

_Overview:_

Get the qos/algorithm&#95;type field of the given VIF.

_Signature:_

```
string get_qos_algorithm_type (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;qos&#95;supported&#95;algorithms

_Overview:_

Get the qos/supported&#95;algorithms field of the given VIF.

_Signature:_

```
string set get_qos_supported_algorithms (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VIF.

_Signature:_

```
VIF record get_record (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF record`

all fields from the object

#### RPC name: get&#95;runtime&#95;properties

_Overview:_

Get the runtime&#95;properties field of the given VIF.

_Signature:_

```
(string -> string) map get_runtime_properties (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;status&#95;code

_Overview:_

Get the status&#95;code field of the given VIF.

_Signature:_

```
int get_status_code (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;status&#95;detail

_Overview:_

Get the status&#95;detail field of the given VIF.

_Signature:_

```
string get_status_detail (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VIF.

_Signature:_

```
string get_uuid (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VIF.

_Signature:_

```
VM ref get_VM (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: move

_Overview:_

Move the specified VIF to the specified network, even while the VM is running

_Signature:_

```
void move (session ref session_id, VIF ref self, network ref network)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to move                         |
|`network ref                 `|network                       |The network to move it to               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: plug

_Overview:_

Hotplug the specified VIF, dynamically attaching it to the running VM

_Signature:_

```
void plug (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to hotplug                      |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VIF ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;qos&#95;algorithm&#95;params

_Overview:_

Remove the given key and its corresponding value from the qos/algorithm&#95;params field of the given VIF.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_qos_algorithm_params (session ref session_id, VIF ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;ipv4&#95;allowed

_Overview:_

Removes an IPv4 address from this VIF

_Signature:_

```
void remove_ipv4_allowed (session ref session_id, VIF ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF from which the IP address will be removed|
|`string                      `|value                         |The IP address which will be removed from the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;ipv6&#95;allowed

_Overview:_

Removes an IPv6 address from this VIF

_Signature:_

```
void remove_ipv6_allowed (session ref session_id, VIF ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF from which the IP address will be removed|
|`string                      `|value                         |The IP address which will be removed from the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;ipv4&#95;allowed

_Overview:_

Set the IPv4 addresses to which traffic on this VIF can be restricted

_Signature:_

```
void set_ipv4_allowed (session ref session_id, VIF ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF which the IP addresses will be associated with|
|`string set                  `|value                         |The IP addresses which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;ipv6&#95;allowed

_Overview:_

Set the IPv6 addresses to which traffic on this VIF can be restricted

_Signature:_

```
void set_ipv6_allowed (session ref session_id, VIF ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF which the IP addresses will be associated with|
|`string set                  `|value                         |The IP addresses which will be associated with the VIF|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;locking&#95;mode

_Overview:_

Set the locking mode for this VIF

_Signature:_

```
void set_locking_mode (session ref session_id, VIF ref self, vif_locking_mode value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF whose locking mode will be set  |
|`vif_locking_mode            `|value                         |The new locking mode for the VIF        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VIF.

_Signature:_

```
void set_other_config (session ref session_id, VIF ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;qos&#95;algorithm&#95;params

_Overview:_

Set the qos/algorithm&#95;params field of the given VIF.

_Signature:_

```
void set_qos_algorithm_params (session ref session_id, VIF ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;qos&#95;algorithm&#95;type

_Overview:_

Set the qos/algorithm&#95;type field of the given VIF.

_Signature:_

```
void set_qos_algorithm_type (session ref session_id, VIF ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: unplug

_Overview:_

Hot&#45;unplug the specified VIF, dynamically unattaching it from the running VM

_Signature:_

```
void unplug (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to hot&#45;unplug               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: unplug&#95;force

_Overview:_

Forcibly unplug the specified VIF

_Signature:_

```
void unplug_force (session ref session_id, VIF ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF ref                     `|self                          |The VIF to forcibly unplug              |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VIF&#95;metrics

**This class is removed.**

The metrics associated with a virtual network device

### Fields for class: VIF&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|io&#95;read&#95;kbs |`float             `|_RO/runtime_   |**Removed**. Read bandwidth &#40;KiB/s&#41;|
|io&#95;write&#95;kbs|`float             `|_RO/runtime_   |**Removed**. Write bandwidth &#40;KiB/s&#41;|
|last&#95;updated    |`datetime          `|_RO/runtime_   |**Removed**. Time at which this information was last updated|
|other&#95;config    |`(string -> string) map`|_RW_           |**Removed**. additional configuration   |
|uuid                |`string            `|_RO/runtime_   |**Removed**. Unique identifier/object reference|

### RPCs associated with class: VIF&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

**This message is removed.**

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VIF&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, VIF_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

**This message is removed.**

_Overview:_

Return a list of all the VIF&#95;metrics instances known to the system.

_Signature:_

```
VIF_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VIF_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is removed.**

_Overview:_

Return a map of VIF&#95;metrics references to VIF&#95;metrics records for all VIF&#95;metrics instances known to the system.

_Signature:_

```
(VIF_metrics ref -> VIF_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VIF_metrics ref -> VIF_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

**This message is removed.**

_Overview:_

Get a reference to the VIF&#95;metrics instance with the specified UUID.

_Signature:_

```
VIF_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VIF_metrics ref`

reference to the object

#### RPC name: get&#95;io&#95;read&#95;kbs

**This message is removed.**

_Overview:_

Get the io/read&#95;kbs field of the given VIF&#95;metrics.

_Signature:_

```
float get_io_read_kbs (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;io&#95;write&#95;kbs

**This message is removed.**

_Overview:_

Get the io/write&#95;kbs field of the given VIF&#95;metrics.

_Signature:_

```
float get_io_write_kbs (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;last&#95;updated

**This message is removed.**

_Overview:_

Get the last&#95;updated field of the given VIF&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;other&#95;config

**This message is removed.**

_Overview:_

Get the other&#95;config field of the given VIF&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

**This message is removed.**

_Overview:_

Get a record containing the current state of the given VIF&#95;metrics.

_Signature:_

```
VIF_metrics record get_record (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF_metrics record`

all fields from the object

#### RPC name: get&#95;uuid

**This message is removed.**

_Overview:_

Get the uuid field of the given VIF&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, VIF_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

**This message is removed.**

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VIF&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VIF_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

**This message is removed.**

_Overview:_

Set the other&#95;config field of the given VIF&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, VIF_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VIF_metrics ref             `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VLAN

A VLAN mux/demux

### Fields for class: VLAN

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|tag                 |`int               `|_RO/constructor_|VLAN tag in use                         |
|tagged&#95;PIF      |`PIF ref           `|_RO/constructor_|interface on which traffic is tagged    |
|untagged&#95;PIF    |`PIF ref           `|_RO/runtime_   |interface on which traffic is untagged  |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: VLAN

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VLAN.

_Signature:_

```
void add_to_other_config (session ref session_id, VLAN ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a VLAN mux/demuxer

_Signature:_

```
VLAN ref create (session ref session_id, PIF ref tagged_PIF, int tag, network ref network)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`PIF ref                     `|tagged&#95;PIF                |PIF which receives the tagged traffic   |
|`int                         `|tag                           |VLAN tag to use                         |
|`network ref                 `|network                       |Network to receive the untagged traffic |

_Minimum Role:_ pool-operator

_Return Type:_ `VLAN ref`

The reference of the created VLAN object

#### RPC name: destroy

_Overview:_

Destroy a VLAN mux/demuxer

_Signature:_

```
void destroy (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |VLAN mux/demuxer to destroy             |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VLANs known to the system.

_Signature:_

```
VLAN ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VLAN references to VLAN records for all VLANs known to the system.

_Signature:_

```
(VLAN ref -> VLAN record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VLAN ref -> VLAN record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VLAN instance with the specified UUID.

_Signature:_

```
VLAN ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VLAN ref`

reference to the object

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VLAN.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VLAN.

_Signature:_

```
VLAN record get_record (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VLAN record`

all fields from the object

#### RPC name: get&#95;tag

_Overview:_

Get the tag field of the given VLAN.

_Signature:_

```
int get_tag (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;tagged&#95;PIF

_Overview:_

Get the tagged&#95;PIF field of the given VLAN.

_Signature:_

```
PIF ref get_tagged_PIF (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;untagged&#95;PIF

_Overview:_

Get the untagged&#95;PIF field of the given VLAN.

_Signature:_

```
PIF ref get_untagged_PIF (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PIF ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VLAN.

_Signature:_

```
string get_uuid (session ref session_id, VLAN ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VLAN.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VLAN ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VLAN.

_Signature:_

```
void set_other_config (session ref session_id, VLAN ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VLAN ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: VM

A virtual machine &#40;or 'guest'&#41;.

### Fields for class: VM

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|actions&#95;after&#95;crash|`on_crash_behaviour`|_RO/constructor_|action to take if the guest crashes     |
|actions&#95;after&#95;reboot|`on_normal_exit    `|_RW_           |action to take after the guest has rebooted itself|
|actions&#95;after&#95;shutdown|`on_normal_exit    `|_RW_           |action to take after the guest has shutdown itself|
|affinity            |`host ref          `|_RW_           |A host which the VM has some affinity for &#40;or NULL&#41;. This is used as a hint to the start call when it decides where to run the VM. Resource constraints may cause the VM to be started elsewhere.|
|allowed&#95;operations|`vm_operations set `|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|appliance           |`VM_appliance ref  `|_RO/constructor_|the appliance to which this VM belongs  |
|attached&#95;PCIs   |`PCI ref set       `|_RO/runtime_   |Currently passed&#45;through PCI devices|
|bios&#95;strings    |`(string -> string) map`|_RO/runtime_   |BIOS strings                            |
|blobs               |`(string -> blob ref) map`|_RO/runtime_   |Binary blobs associated with this VM    |
|blocked&#95;operations|`(vm_operations -> string) map`|_RW_           |List of operations which have been explicitly blocked and an error code|
|children            |`VM ref set        `|_RO/runtime_   |List pointing to all the children of this VM|
|consoles            |`console ref set   `|_RO/runtime_   |virtual console devices                 |
|crash&#95;dumps     |`crashdump ref set `|_RO/runtime_   |crash dumps associated with this VM     |
|current&#95;operations|`(string -> vm_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|domain&#95;type     |`domain_type       `|_RO/constructor_|The type of domain that will be created when the VM is started|
|domarch             |`string            `|_RO/runtime_   |Domain architecture &#40;if available, null string otherwise&#41;|
|domid               |`int               `|_RO/runtime_   |domain ID &#40;if available, &#45;1 otherwise&#41;|
|generation&#95;id   |`string            `|_RO/constructor_|Generation ID of the VM                 |
|guest&#95;metrics   |`VM_guest_metrics ref`|_RO/runtime_   |metrics associated with the running guest|
|ha&#95;always&#95;run|`bool              `|_RO/constructor_|**Deprecated**. if true then the system will attempt to keep the VM running as much as possible.|
|ha&#95;restart&#95;priority|`string            `|_RO/constructor_|has possible values: "best&#45;effort" meaning "try to restart this VM if possible but don't consider the Pool to be overcommitted if this is not possible"; "restart" meaning "this VM should be restarted"; "" meaning "do not try to restart this VM"|
|hardware&#95;platform&#95;version|`int               `|_RW_           |The host virtual hardware platform version the VM can run on|
|has&#95;vendor&#95;device|`bool              `|_RO/constructor_|When an HVM guest starts, this controls the presence of the emulated C000 PCI device which triggers Windows Update to fetch or update PV drivers.|
|HVM&#95;boot&#95;params|`(string -> string) map`|_RW_           |HVM boot params                         |
|HVM&#95;boot&#95;policy|`string            `|_RO/constructor_|**Deprecated**. HVM boot policy         |
|HVM&#95;shadow&#95;multiplier|`float             `|_RO/constructor_|multiplier applied to the amount of shadow that will be made available to the guest|
|is&#95;a&#95;snapshot|`bool              `|_RO/runtime_   |true if this is a snapshot. Snapshotted VMs can never be started, they are used only for cloning other VMs|
|is&#95;a&#95;template|`bool              `|_RW_           |true if this is a template. Template VMs can never be started, they are used only for cloning other VMs|
|is&#95;control&#95;domain|`bool              `|_RO/runtime_   |true if this is a control domain &#40;domain 0 or a driver domain&#41;|
|is&#95;default&#95;template|`bool              `|_RO/runtime_   |true if this is a default template. Default template VMs can never be started or migrated, they are used only for cloning other VMs|
|is&#95;snapshot&#95;from&#95;vmpp|`bool              `|_RO/constructor_|**Deprecated**. true if this snapshot was created by the protection policy|
|is&#95;vmss&#95;snapshot|`bool              `|_RO/constructor_|true if this snapshot was created by the snapshot schedule|
|last&#95;boot&#95;CPU&#95;flags|`(string -> string) map`|_RO/constructor_|describes the CPU flags on which the VM was last booted|
|last&#95;booted&#95;record|`string            `|_RO/constructor_|marshalled value containing VM record at time of last boot, updated dynamically to reflect the runtime state of the domain|
|memory&#95;dynamic&#95;max|`int               `|_RO/constructor_|Dynamic maximum &#40;bytes&#41;         |
|memory&#95;dynamic&#95;min|`int               `|_RO/constructor_|Dynamic minimum &#40;bytes&#41;         |
|memory&#95;overhead |`int               `|_RO/runtime_   |Virtualization memory overhead &#40;bytes&#41;.|
|memory&#95;static&#95;max|`int               `|_RO/constructor_|Statically&#45;set &#40;i.e. absolute&#41; maximum &#40;bytes&#41;. The value of this field at VM start time acts as a hard limit of the amount of memory a guest can use. New values only take effect on reboot.|
|memory&#95;static&#95;min|`int               `|_RO/constructor_|Statically&#45;set &#40;i.e. absolute&#41; mininum &#40;bytes&#41;. The value of this field indicates the least amount of memory this VM can boot with without crashing.|
|memory&#95;target   |`int               `|_RO/constructor_|**Deprecated**. Dynamically&#45;set memory target &#40;bytes&#41;. The value of this field indicates the current target for memory available to this VM.|
|metrics             |`VM_metrics ref    `|_RO/runtime_   |metrics associated with this VM         |
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|NVRAM               |`(string -> string) map`|_RO/constructor_|initial value for guest NVRAM &#40;containing UEFI variables, etc&#41;. Cannot be changed while the VM is running|
|order               |`int               `|_RO/constructor_|The point in the startup or shutdown sequence at which this VM will be started|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|parent              |`VM ref            `|_RO/runtime_   |Ref pointing to the parent of this VM   |
|PCI&#95;bus         |`string            `|_RW_           |**Deprecated**. PCI bus path for pass&#45;through devices|
|platform            |`(string -> string) map`|_RW_           |platform&#45;specific configuration     |
|power&#95;state     |`vm_power_state    `|_RO/constructor_|Current power state of the machine      |
|protection&#95;policy|`VMPP ref          `|_RO/constructor_|**Deprecated**. Ref pointing to a protection policy for this VM|
|PV&#95;args         |`string            `|_RW_           |kernel command&#45;line arguments       |
|PV&#95;bootloader   |`string            `|_RW_           |name of or path to bootloader           |
|PV&#95;bootloader&#95;args|`string            `|_RW_           |miscellaneous arguments for the bootloader|
|PV&#95;kernel       |`string            `|_RW_           |path to the kernel                      |
|PV&#95;legacy&#95;args|`string            `|_RW_           |to make Zurich guests boot              |
|PV&#95;ramdisk      |`string            `|_RW_           |path to the initrd                      |
|recommendations     |`string            `|_RW_           |An XML specification of recommended values and ranges for properties of this VM|
|reference&#95;label |`string            `|_RO/constructor_|Textual reference to the template used to create a VM. This can be used by clients in need of an immutable reference to the template since the latter's uuid and name&#95;label may change, for example, after a package installation or upgrade.|
|requires&#95;reboot |`bool              `|_RO/runtime_   |Indicates whether a VM requires a reboot in order to update its configuration, e.g. its memory allocation.|
|resident&#95;on     |`host ref          `|_RO/runtime_   |the host the VM is currently resident on|
|scheduled&#95;to&#95;be&#95;resident&#95;on|`host ref          `|_RO/runtime_   |the host on which the VM is due to be started/resumed/migrated. This acts as a memory reservation indicator|
|shutdown&#95;delay  |`int               `|_RO/constructor_|The delay to wait before proceeding to the next order in the shutdown sequence &#40;seconds&#41;|
|snapshot&#95;info   |`(string -> string) map`|_RO/runtime_   |Human&#45;readable information concerning this snapshot|
|snapshot&#95;metadata|`string            `|_RO/runtime_   |Encoded information about the VM's metadata this is a snapshot of|
|snapshot&#95;of     |`VM ref            `|_RO/runtime_   |Ref pointing to the VM this snapshot is of.|
|snapshot&#95;schedule|`VMSS ref          `|_RO/constructor_|Ref pointing to a snapshot schedule for this VM|
|snapshot&#95;time   |`datetime          `|_RO/runtime_   |Date/time when this snapshot was created.|
|snapshots           |`VM ref set        `|_RO/runtime_   |List pointing to all the VM snapshots.  |
|start&#95;delay     |`int               `|_RO/constructor_|The delay to wait before proceeding to the next order in the startup sequence &#40;seconds&#41;|
|suspend&#95;SR      |`SR ref            `|_RW_           |The SR on which a suspend image is stored|
|suspend&#95;VDI     |`VDI ref           `|_RO/constructor_|The VDI that a suspend image is stored on. &#40;Only has meaning if VM is currently suspended&#41;|
|tags                |`string set        `|_RW_           |user&#45;specified tags for categorization purposes|
|transportable&#95;snapshot&#95;id|`string            `|_RO/runtime_   |Transportable ID of the snapshot VM     |
|user&#95;version    |`int               `|_RW_           |Creators of VMs and templates may store version information here.|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VBDs                |`VBD ref set       `|_RO/runtime_   |virtual block devices                   |
|VCPUs&#95;at&#95;startup|`int               `|_RO/constructor_|Boot number of VCPUs                    |
|VCPUs&#95;max       |`int               `|_RO/constructor_|Max number of VCPUs                     |
|VCPUs&#95;params    |`(string -> string) map`|_RW_           |configuration parameters for the selected VCPU policy|
|version             |`int               `|_RO/constructor_|The number of times this VM has been recovered|
|VGPUs               |`VGPU ref set      `|_RO/runtime_   |Virtual GPUs                            |
|VIFs                |`VIF ref set       `|_RO/runtime_   |virtual network interfaces              |
|VTPMs               |`VTPM ref set      `|_RO/runtime_   |virtual TPMs                            |
|VUSBs               |`VUSB ref set      `|_RO/runtime_   |vitual usb devices                      |
|xenstore&#95;data   |`(string -> string) map`|_RW_           |data to be inserted into the xenstore tree &#40;/local/domain/&lt;domid&gt;/vm&#45;data&#41; after the VM is created.|

### RPCs associated with class: VM

#### RPC name: add&#95;tags

_Overview:_

Add the given value to the tags field of the given VM.  If the value is already in that Set, then do nothing.

_Signature:_

```
void add_tags (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to add                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;blocked&#95;operations

_Overview:_

Add the given key&#45;value pair to the blocked&#95;operations field of the given VM.

_Signature:_

```
void add_to_blocked_operations (session ref session_id, VM ref self, vm_operations key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`vm_operations               `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;HVM&#95;boot&#95;params

_Overview:_

Add the given key&#45;value pair to the HVM/boot&#95;params field of the given VM.

_Signature:_

```
void add_to_HVM_boot_params (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;NVRAM

_Overview:_



_Signature:_

```
void add_to_NVRAM (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|key                           |The key                                 |
|`string                      `|value                         |The value                               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VM.

_Signature:_

```
void add_to_other_config (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;platform

_Overview:_

Add the given key&#45;value pair to the platform field of the given VM.

_Signature:_

```
void add_to_platform (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;VCPUs&#95;params

_Overview:_

Add the given key&#45;value pair to the VCPUs/params field of the given VM.

_Signature:_

```
void add_to_VCPUs_params (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;VCPUs&#95;params&#95;live

_Overview:_

Add the given key&#45;value pair to VM.VCPUs&#95;params, and apply that value on the running VM

_Signature:_

```
void add_to_VCPUs_params_live (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|key                           |The key                                 |
|`string                      `|value                         |The value                               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;xenstore&#95;data

_Overview:_

Add the given key&#45;value pair to the xenstore&#95;data field of the given VM.

_Signature:_

```
void add_to_xenstore_data (session ref session_id, VM ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: assert&#95;agile

_Overview:_

Returns an error if the VM is not considered agile e.g. because it is tied to a resource local to a host

_Signature:_

```
void assert_agile (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: assert&#95;can&#95;be&#95;recovered

_Overview:_

Assert whether all SRs required to recover this VM are available.

_Signature:_

```
void assert_can_be_recovered (session ref session_id, VM ref self, session ref session_to)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to recover                       |
|`session ref                 `|session&#95;to                |The session to which the VM is to be recovered.|

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `VM_IS_PART_OF_AN_APPLIANCE`, `VM_REQUIRES_SR`

#### RPC name: assert&#95;can&#95;boot&#95;here

_Overview:_

Returns an error if the VM could not boot on this host for some reason

_Signature:_

```
void assert_can_boot_here (session ref session_id, VM ref self, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`host ref                    `|host                          |The host                                |

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `HOST_NOT_ENOUGH_FREE_MEMORY`, `HOST_NOT_ENOUGH_PCPUS`, `NETWORK_SRIOV_INSUFFICIENT_CAPACITY`, `HOST_NOT_LIVE`, `HOST_DISABLED`, `HOST_CANNOT_ATTACH_NETWORK`, `VM_HVM_REQUIRED`, `VM_REQUIRES_GPU`, `VM_REQUIRES_IOMMU`, `VM_REQUIRES_NETWORK`, `VM_REQUIRES_SR`, `VM_REQUIRES_VGPU`, `VM_HOST_INCOMPATIBLE_VERSION`, `VM_HOST_INCOMPATIBLE_VIRTUAL_HARDWARE_PLATFORM_VERSION`, `INVALID_VALUE`, `MEMORY_CONSTRAINT_VIOLATION`, `OPERATION_NOT_ALLOWED`, `VALUE_NOT_SUPPORTED`, `VM_INCOMPATIBLE_WITH_THIS_HOST`

#### RPC name: assert&#95;can&#95;migrate

_Overview:_

Assert whether a VM can be migrated to the specified destination.

_Signature:_

```
void assert_can_migrate (session ref session_id, VM ref vm, (string -> string) map dest, bool live, (VDI ref -> SR ref) map vdi_map, (VIF ref -> network ref) map vif_map, (string -> string) map options, (VGPU ref -> GPU_group ref) map vgpu_map)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |
|`(string -> string) map      `|dest                          |The result of a VM.migrate&#95;receive call.|
|`bool                        `|live                          |Live migration                          |
|`(VDI ref -> SR ref) map     `|vdi&#95;map                   |Map of source VDI to destination SR     |
|`(VIF ref -> network ref) map`|vif&#95;map                   |Map of source VIF to destination network|
|`(string -> string) map      `|options                       |Other parameters                        |
|`(VGPU ref -> GPU_group ref) map`|vgpu&#95;map                  |Map of source vGPU to destination GPU group|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `LICENCE_RESTRICTION`

#### RPC name: assert&#95;operation&#95;valid

_Overview:_

Check to see whether this operation is acceptable in the current state of the system, raising an error if the operation is invalid for some reason

_Signature:_

```
void assert_operation_valid (session ref session_id, VM ref self, vm_operations op)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`vm_operations               `|op                            |proposed operation                      |

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: call&#95;plugin

_Overview:_

Call an API plugin on this vm

_Signature:_

```
string call_plugin (session ref session_id, VM ref vm, string plugin, string fn, (string -> string) map args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The vm                                  |
|`string                      `|plugin                        |The name of the plugin                  |
|`string                      `|fn                            |The name of the function within the plugin|
|`(string -> string) map      `|args                          |Arguments for the function              |

_Minimum Role:_ vm-operator

_Return Type:_ `string`

Result from the plugin

#### RPC name: checkpoint

_Overview:_

Checkpoints the specified VM, making a new VM. Checkpoint automatically exploits the capabilities of the underlying storage repository in which the VM's disk images are stored &#40;e.g. Copy on Write&#41; and saves the memory image as well.

_Signature:_

```
VM ref checkpoint (session ref session_id, VM ref vm, string new_name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be checkpointed               |
|`string                      `|new&#95;name                  |The name of the checkpointed VM         |

_Minimum Role:_ vm-power-admin

_Return Type:_ `VM ref`

The reference of the newly created VM.

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`, `VM_CHECKPOINT_SUSPEND_FAILED`, `VM_CHECKPOINT_RESUME_FAILED`

#### RPC name: clean&#95;reboot

_Overview:_

Attempt to cleanly shutdown the specified VM &#40;Note: this may not be supported&#45;&#45;&#45;e.g. if a guest agent is not installed&#41;. This can only be called when the specified VM is in the Running state.

_Signature:_

```
void clean_reboot (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to shutdown                      |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: clean&#95;shutdown

_Overview:_

Attempt to cleanly shutdown the specified VM. &#40;Note: this may not be supported&#45;&#45;&#45;e.g. if a guest agent is not installed&#41;. This can only be called when the specified VM is in the Running state.

_Signature:_

```
void clean_shutdown (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to shutdown                      |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: clone

_Overview:_

Clones the specified VM, making a new VM. Clone automatically exploits the capabilities of the underlying storage repository in which the VM's disk images are stored &#40;e.g. Copy on Write&#41;.   This function can only be called when the VM is in the Halted State.

_Signature:_

```
VM ref clone (session ref session_id, VM ref vm, string new_name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be cloned                     |
|`string                      `|new&#95;name                  |The name of the cloned VM               |

_Minimum Role:_ vm-admin

_Return Type:_ `VM ref`

The reference of the newly created VM.

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`, `LICENCE_RESTRICTION`

#### RPC name: compute&#95;memory&#95;overhead

_Overview:_

Computes the virtualization memory overhead of a VM.

_Signature:_

```
int compute_memory_overhead (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM for which to compute the memory overhead|

_Minimum Role:_ read-only

_Return Type:_ `int`

the virtualization memory overhead of the VM.

#### RPC name: copy

_Overview:_

Copied the specified VM, making a new VM. Unlike clone, copy does not exploits the capabilities of the underlying storage repository in which the VM's disk images are stored. Instead, copy guarantees that the disk images of the newly created VM will be 'full disks' &#45; i.e. not part of a CoW chain.  This function can only be called when the VM is in the Halted State.

_Signature:_

```
VM ref copy (session ref session_id, VM ref vm, string new_name, SR ref sr)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be copied                     |
|`string                      `|new&#95;name                  |The name of the copied VM               |
|`SR ref                      `|sr                            |An SR to copy all the VM's disks into &#40;if an invalid reference then it uses the existing SRs&#41;|

_Minimum Role:_ vm-admin

_Return Type:_ `VM ref`

The reference of the newly created VM.

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`, `LICENCE_RESTRICTION`

#### RPC name: copy&#95;bios&#95;strings

_Overview:_

Copy the BIOS strings from the given host to this VM

_Signature:_

```
void copy_bios_strings (session ref session_id, VM ref vm, host ref host)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to modify                        |
|`host ref                    `|host                          |The host to copy the BIOS strings from  |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_

NOT RECOMMENDED&#33; VM.clone or VM.copy &#40;or VM.import&#41; is a better choice in almost all situations. The standard way to obtain a new VM is to call VM.clone on a template VM, then call VM.provision on the new clone. Caution: if VM.create is used and then the new VM is attached to a virtual disc that has an operating system already installed, then there is no guarantee that the operating system will boot and run. Any software that calls VM.create on a future version of this API may fail or give unexpected results. For example this could happen if an additional parameter were added to VM.create. VM.create is intended only for use in the automatic creation of the system VM templates. It creates a new VM instance, and returns its handle.

_Signature:_

```
VM ref create (session ref session_id, VM record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM record                   `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VM ref`

reference to the newly created object

#### RPC name: create&#95;new&#95;blob

_Overview:_

Create a placeholder for a named binary blob of data that is associated with this VM

_Signature:_

```
blob ref create_new_blob (session ref session_id, VM ref vm, string name, string mime_type, bool public)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |
|`string                      `|name                          |The name associated with the blob       |
|`string                      `|mime&#95;type                 |The mime type for the data. Empty string translates to application/octet&#45;stream|
|`bool                        `|public                        |True if the blob should be publicly available|

_Minimum Role:_ vm-power-admin

_Return Type:_ `blob ref`

The reference of the blob, needed for populating its data

#### RPC name: destroy

_Overview:_

Destroy the specified VM.  The VM is completely removed from the system.  This function can only be called when the VM is in the Halted State.

_Signature:_

```
void destroy (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: forget&#95;data&#95;source&#95;archives

_Overview:_

Forget the recorded statistics related to the specified data source

_Signature:_

```
void forget_data_source_archives (session ref session_id, VM ref self, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|data&#95;source               |The data source whose archives are to be forgotten|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;actions&#95;after&#95;crash

_Overview:_

Get the actions/after&#95;crash field of the given VM.

_Signature:_

```
on_crash_behaviour get_actions_after_crash (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `on_crash_behaviour`

value of the field

#### RPC name: get&#95;actions&#95;after&#95;reboot

_Overview:_

Get the actions/after&#95;reboot field of the given VM.

_Signature:_

```
on_normal_exit get_actions_after_reboot (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `on_normal_exit`

value of the field

#### RPC name: get&#95;actions&#95;after&#95;shutdown

_Overview:_

Get the actions/after&#95;shutdown field of the given VM.

_Signature:_

```
on_normal_exit get_actions_after_shutdown (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `on_normal_exit`

value of the field

#### RPC name: get&#95;affinity

_Overview:_

Get the affinity field of the given VM.

_Signature:_

```
host ref get_affinity (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VMs known to the system.

_Signature:_

```
VM ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM references to VM records for all VMs known to the system.

_Signature:_

```
(VM ref -> VM record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VM ref -> VM record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VM.

_Signature:_

```
vm_operations set get_allowed_operations (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vm_operations set`

value of the field

#### RPC name: get&#95;allowed&#95;VBD&#95;devices

_Overview:_

Returns a list of the allowed values that a VBD device field can take

_Signature:_

```
string set get_allowed_VBD_devices (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to query                         |

_Minimum Role:_ read-only

_Return Type:_ `string set`

The allowed values

#### RPC name: get&#95;allowed&#95;VIF&#95;devices

_Overview:_

Returns a list of the allowed values that a VIF device field can take

_Signature:_

```
string set get_allowed_VIF_devices (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to query                         |

_Minimum Role:_ read-only

_Return Type:_ `string set`

The allowed values

#### RPC name: get&#95;appliance

_Overview:_

Get the appliance field of the given VM.

_Signature:_

```
VM_appliance ref get_appliance (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref`

value of the field

#### RPC name: get&#95;attached&#95;PCIs

_Overview:_

Get the attached&#95;PCIs field of the given VM.

_Signature:_

```
PCI ref set get_attached_PCIs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PCI ref set`

value of the field

#### RPC name: get&#95;bios&#95;strings

_Overview:_

Get the bios&#95;strings field of the given VM.

_Signature:_

```
(string -> string) map get_bios_strings (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;blobs

_Overview:_

Get the blobs field of the given VM.

_Signature:_

```
(string -> blob ref) map get_blobs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> blob ref) map`

value of the field

#### RPC name: get&#95;blocked&#95;operations

_Overview:_

Get the blocked&#95;operations field of the given VM.

_Signature:_

```
(vm_operations -> string) map get_blocked_operations (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(vm_operations -> string) map`

value of the field

#### RPC name: get&#95;boot&#95;record

**This message is deprecated.**

_Overview:_

Returns a record describing the VM's dynamic state, initialised when the VM boots and updated to reflect runtime configuration changes e.g. CPU hotplug

_Signature:_

```
VM record get_boot_record (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM whose boot&#45;time state to return|

_Minimum Role:_ read-only

_Return Type:_ `VM record`

A record describing the VM

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VM instances with the given label.

_Signature:_

```
VM ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM instance with the specified UUID.

_Signature:_

```
VM ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

reference to the object

#### RPC name: get&#95;children

_Overview:_

Get the children field of the given VM.

_Signature:_

```
VM ref set get_children (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: get&#95;consoles

_Overview:_

Get the consoles field of the given VM.

_Signature:_

```
console ref set get_consoles (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `console ref set`

value of the field

#### RPC name: get&#95;cooperative

**This message is deprecated.**

_Overview:_

Return true if the VM is currently 'co&#45;operative' i.e. is expected to reach a balloon target and actually has done

_Signature:_

```
bool get_cooperative (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |

_Minimum Role:_ read-only

_Return Type:_ `bool`

true if the VM is currently 'co&#45;operative'; false otherwise

#### RPC name: get&#95;crash&#95;dumps

_Overview:_

Get the crash&#95;dumps field of the given VM.

_Signature:_

```
crashdump ref set get_crash_dumps (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `crashdump ref set`

value of the field

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VM.

_Signature:_

```
(string -> vm_operations) map get_current_operations (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vm_operations) map`

value of the field

#### RPC name: get&#95;data&#95;sources

_Overview:_



_Signature:_

```
data_source record set get_data_sources (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to interrogate                   |

_Minimum Role:_ read-only

_Return Type:_ `data_source record set`

A set of data sources

#### RPC name: get&#95;domain&#95;type

_Overview:_

Get the domain&#95;type field of the given VM.

_Signature:_

```
domain_type get_domain_type (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `domain_type`

value of the field

#### RPC name: get&#95;domarch

_Overview:_

Get the domarch field of the given VM.

_Signature:_

```
string get_domarch (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;domid

_Overview:_

Get the domid field of the given VM.

_Signature:_

```
int get_domid (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;generation&#95;id

_Overview:_

Get the generation&#95;id field of the given VM.

_Signature:_

```
string get_generation_id (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;guest&#95;metrics

_Overview:_

Get the guest&#95;metrics field of the given VM.

_Signature:_

```
VM_guest_metrics ref get_guest_metrics (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics ref`

value of the field

#### RPC name: get&#95;ha&#95;always&#95;run

**This message is deprecated.**

_Overview:_

Get the ha&#95;always&#95;run field of the given VM.

_Signature:_

```
bool get_ha_always_run (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;ha&#95;restart&#95;priority

_Overview:_

Get the ha&#95;restart&#95;priority field of the given VM.

_Signature:_

```
string get_ha_restart_priority (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;hardware&#95;platform&#95;version

_Overview:_

Get the hardware&#95;platform&#95;version field of the given VM.

_Signature:_

```
int get_hardware_platform_version (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;has&#95;vendor&#95;device

_Overview:_

Get the has&#95;vendor&#95;device field of the given VM.

_Signature:_

```
bool get_has_vendor_device (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;HVM&#95;boot&#95;params

_Overview:_

Get the HVM/boot&#95;params field of the given VM.

_Signature:_

```
(string -> string) map get_HVM_boot_params (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;HVM&#95;boot&#95;policy

**This message is deprecated.**

_Overview:_

Get the HVM/boot&#95;policy field of the given VM.

_Signature:_

```
string get_HVM_boot_policy (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;HVM&#95;shadow&#95;multiplier

_Overview:_

Get the HVM/shadow&#95;multiplier field of the given VM.

_Signature:_

```
float get_HVM_shadow_multiplier (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `float`

value of the field

#### RPC name: get&#95;is&#95;a&#95;snapshot

_Overview:_

Get the is&#95;a&#95;snapshot field of the given VM.

_Signature:_

```
bool get_is_a_snapshot (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;a&#95;template

_Overview:_

Get the is&#95;a&#95;template field of the given VM.

_Signature:_

```
bool get_is_a_template (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;control&#95;domain

_Overview:_

Get the is&#95;control&#95;domain field of the given VM.

_Signature:_

```
bool get_is_control_domain (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;default&#95;template

_Overview:_

Get the is&#95;default&#95;template field of the given VM.

_Signature:_

```
bool get_is_default_template (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;snapshot&#95;from&#95;vmpp

**This message is deprecated.**

_Overview:_

Get the is&#95;snapshot&#95;from&#95;vmpp field of the given VM.

_Signature:_

```
bool get_is_snapshot_from_vmpp (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;vmss&#95;snapshot

_Overview:_

Get the is&#95;vmss&#95;snapshot field of the given VM.

_Signature:_

```
bool get_is_vmss_snapshot (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;last&#95;boot&#95;CPU&#95;flags

_Overview:_

Get the last&#95;boot&#95;CPU&#95;flags field of the given VM.

_Signature:_

```
(string -> string) map get_last_boot_CPU_flags (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;last&#95;booted&#95;record

_Overview:_

Get the last&#95;booted&#95;record field of the given VM.

_Signature:_

```
string get_last_booted_record (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;memory&#95;dynamic&#95;max

_Overview:_

Get the memory/dynamic&#95;max field of the given VM.

_Signature:_

```
int get_memory_dynamic_max (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;dynamic&#95;min

_Overview:_

Get the memory/dynamic&#95;min field of the given VM.

_Signature:_

```
int get_memory_dynamic_min (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;overhead

_Overview:_

Get the memory/overhead field of the given VM.

_Signature:_

```
int get_memory_overhead (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;static&#95;max

_Overview:_

Get the memory/static&#95;max field of the given VM.

_Signature:_

```
int get_memory_static_max (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;static&#95;min

_Overview:_

Get the memory/static&#95;min field of the given VM.

_Signature:_

```
int get_memory_static_min (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;memory&#95;target

**This message is deprecated.**

_Overview:_

Get the memory/target field of the given VM.

_Signature:_

```
int get_memory_target (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;metrics

_Overview:_

Get the metrics field of the given VM.

_Signature:_

```
VM_metrics ref get_metrics (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics ref`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VM.

_Signature:_

```
string get_name_description (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VM.

_Signature:_

```
string get_name_label (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;NVRAM

_Overview:_

Get the NVRAM field of the given VM.

_Signature:_

```
(string -> string) map get_NVRAM (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;order

_Overview:_

Get the order field of the given VM.

_Signature:_

```
int get_order (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VM.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;parent

_Overview:_

Get the parent field of the given VM.

_Signature:_

```
VM ref get_parent (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: get&#95;PCI&#95;bus

**This message is deprecated.**

_Overview:_

Get the PCI&#95;bus field of the given VM.

_Signature:_

```
string get_PCI_bus (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;platform

_Overview:_

Get the platform field of the given VM.

_Signature:_

```
(string -> string) map get_platform (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;possible&#95;hosts

_Overview:_

Return the list of hosts on which this VM may run.

_Signature:_

```
host ref set get_possible_hosts (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |

_Minimum Role:_ read-only

_Return Type:_ `host ref set`

The possible hosts

#### RPC name: get&#95;power&#95;state

_Overview:_

Get the power&#95;state field of the given VM.

_Signature:_

```
vm_power_state get_power_state (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vm_power_state`

value of the field

#### RPC name: get&#95;protection&#95;policy

**This message is deprecated.**

_Overview:_

Get the protection&#95;policy field of the given VM.

_Signature:_

```
VMPP ref get_protection_policy (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VMPP ref`

value of the field

#### RPC name: get&#95;PV&#95;args

_Overview:_

Get the PV/args field of the given VM.

_Signature:_

```
string get_PV_args (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PV&#95;bootloader

_Overview:_

Get the PV/bootloader field of the given VM.

_Signature:_

```
string get_PV_bootloader (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PV&#95;bootloader&#95;args

_Overview:_

Get the PV/bootloader&#95;args field of the given VM.

_Signature:_

```
string get_PV_bootloader_args (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PV&#95;kernel

_Overview:_

Get the PV/kernel field of the given VM.

_Signature:_

```
string get_PV_kernel (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PV&#95;legacy&#95;args

_Overview:_

Get the PV/legacy&#95;args field of the given VM.

_Signature:_

```
string get_PV_legacy_args (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;PV&#95;ramdisk

_Overview:_

Get the PV/ramdisk field of the given VM.

_Signature:_

```
string get_PV_ramdisk (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;recommendations

_Overview:_

Get the recommendations field of the given VM.

_Signature:_

```
string get_recommendations (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM.

_Signature:_

```
VM record get_record (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM record`

all fields from the object

#### RPC name: get&#95;reference&#95;label

_Overview:_

Get the reference&#95;label field of the given VM.

_Signature:_

```
string get_reference_label (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;requires&#95;reboot

_Overview:_

Get the requires&#95;reboot field of the given VM.

_Signature:_

```
bool get_requires_reboot (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;resident&#95;on

_Overview:_

Get the resident&#95;on field of the given VM.

_Signature:_

```
host ref get_resident_on (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;scheduled&#95;to&#95;be&#95;resident&#95;on

_Overview:_

Get the scheduled&#95;to&#95;be&#95;resident&#95;on field of the given VM.

_Signature:_

```
host ref get_scheduled_to_be_resident_on (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `host ref`

value of the field

#### RPC name: get&#95;shutdown&#95;delay

_Overview:_

Get the shutdown&#95;delay field of the given VM.

_Signature:_

```
int get_shutdown_delay (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;snapshot&#95;info

_Overview:_

Get the snapshot&#95;info field of the given VM.

_Signature:_

```
(string -> string) map get_snapshot_info (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;snapshot&#95;metadata

_Overview:_

Get the snapshot&#95;metadata field of the given VM.

_Signature:_

```
string get_snapshot_metadata (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;snapshot&#95;of

_Overview:_

Get the snapshot&#95;of field of the given VM.

_Signature:_

```
VM ref get_snapshot_of (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: get&#95;snapshot&#95;schedule

_Overview:_

Get the snapshot&#95;schedule field of the given VM.

_Signature:_

```
VMSS ref get_snapshot_schedule (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref`

value of the field

#### RPC name: get&#95;snapshot&#95;time

_Overview:_

Get the snapshot&#95;time field of the given VM.

_Signature:_

```
datetime get_snapshot_time (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;snapshots

_Overview:_

Get the snapshots field of the given VM.

_Signature:_

```
VM ref set get_snapshots (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: get&#95;SRs&#95;required&#95;for&#95;recovery

_Overview:_

List all the SR's that are required for the VM to be recovered

_Signature:_

```
SR ref set get_SRs_required_for_recovery (session ref session_id, VM ref self, session ref session_to)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM for which the SRs have to be recovered|
|`session ref                 `|session&#95;to                |The session to which the SRs of the VM have to be recovered.|

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

refs for SRs required to recover the VM

#### RPC name: get&#95;start&#95;delay

_Overview:_

Get the start&#95;delay field of the given VM.

_Signature:_

```
int get_start_delay (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;suspend&#95;SR

_Overview:_

Get the suspend&#95;SR field of the given VM.

_Signature:_

```
SR ref get_suspend_SR (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `SR ref`

value of the field

#### RPC name: get&#95;suspend&#95;VDI

_Overview:_

Get the suspend&#95;VDI field of the given VM.

_Signature:_

```
VDI ref get_suspend_VDI (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VDI ref`

value of the field

#### RPC name: get&#95;tags

_Overview:_

Get the tags field of the given VM.

_Signature:_

```
string set get_tags (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;transportable&#95;snapshot&#95;id

_Overview:_

Get the transportable&#95;snapshot&#95;id field of the given VM.

_Signature:_

```
string get_transportable_snapshot_id (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;user&#95;version

_Overview:_

Get the user&#95;version field of the given VM.

_Signature:_

```
int get_user_version (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM.

_Signature:_

```
string get_uuid (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VBDs

_Overview:_

Get the VBDs field of the given VM.

_Signature:_

```
VBD ref set get_VBDs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VBD ref set`

value of the field

#### RPC name: get&#95;VCPUs&#95;at&#95;startup

_Overview:_

Get the VCPUs/at&#95;startup field of the given VM.

_Signature:_

```
int get_VCPUs_at_startup (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;VCPUs&#95;max

_Overview:_

Get the VCPUs/max field of the given VM.

_Signature:_

```
int get_VCPUs_max (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;VCPUs&#95;params

_Overview:_

Get the VCPUs/params field of the given VM.

_Signature:_

```
(string -> string) map get_VCPUs_params (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;version

_Overview:_

Get the version field of the given VM.

_Signature:_

```
int get_version (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;VGPUs

_Overview:_

Get the VGPUs field of the given VM.

_Signature:_

```
VGPU ref set get_VGPUs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VGPU ref set`

value of the field

#### RPC name: get&#95;VIFs

_Overview:_

Get the VIFs field of the given VM.

_Signature:_

```
VIF ref set get_VIFs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VIF ref set`

value of the field

#### RPC name: get&#95;VTPMs

_Overview:_

Get the VTPMs field of the given VM.

_Signature:_

```
VTPM ref set get_VTPMs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VTPM ref set`

value of the field

#### RPC name: get&#95;VUSBs

_Overview:_

Get the VUSBs field of the given VM.

_Signature:_

```
VUSB ref set get_VUSBs (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref set`

value of the field

#### RPC name: get&#95;xenstore&#95;data

_Overview:_

Get the xenstore&#95;data field of the given VM.

_Signature:_

```
(string -> string) map get_xenstore_data (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: hard&#95;reboot

_Overview:_

Stop executing the specified VM without attempting a clean shutdown and immediately restart the VM.

_Signature:_

```
void hard_reboot (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to reboot                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: hard&#95;shutdown

_Overview:_

Stop executing the specified VM without attempting a clean shutdown.

_Signature:_

```
void hard_shutdown (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to destroy                       |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: import

_Overview:_

Import an XVA from a URI

_Signature:_

```
VM ref set import (session ref session_id, string url, SR ref sr, bool full_restore, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|url                           |The URL of the XVA file                 |
|`SR ref                      `|sr                            |The destination SR for the disks        |
|`bool                        `|full&#95;restore              |Perform a full restore                  |
|`bool                        `|force                         |Force the import                        |

_Minimum Role:_ pool-operator

_Return Type:_ `VM ref set`

Imported VM reference

#### RPC name: import&#95;convert

_Overview:_

Import using a conversion service.

_Signature:_

```
void import_convert (session ref session_id, string type, string username, string password, SR ref sr, (string -> string) map remote_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|type                          |Type of the conversion                  |
|`string                      `|username                      |Admin username on the host              |
|`string                      `|password                      |Password on the host                    |
|`SR ref                      `|sr                            |The destination SR                      |
|`(string -> string) map      `|remote&#95;config             |Remote configuration options            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: maximise&#95;memory

_Overview:_

Returns the maximum amount of guest memory which will fit, together with overheads, in the supplied amount of physical memory. If 'exact' is true then an exact calculation is performed using the VM's current settings. If 'exact' is false then a more conservative approximation is used

_Signature:_

```
int maximise_memory (session ref session_id, VM ref self, int total, bool approximate)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|total                         |Total amount of physical RAM to fit within|
|`bool                        `|approximate                   |If false the limit is calculated with the guest's current exact configuration. Otherwise a more approximate calculation is performed|

_Minimum Role:_ read-only

_Return Type:_ `int`

The maximum possible static&#45;max

#### RPC name: migrate&#95;send

_Overview:_

Migrate the VM to another host.  This can only be called when the specified VM is in the Running state.

_Signature:_

```
VM ref migrate_send (session ref session_id, VM ref vm, (string -> string) map dest, bool live, (VDI ref -> SR ref) map vdi_map, (VIF ref -> network ref) map vif_map, (string -> string) map options, (VGPU ref -> GPU_group ref) map vgpu_map)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |
|`(string -> string) map      `|dest                          |The result of a Host.migrate&#95;receive call.|
|`bool                        `|live                          |Live migration                          |
|`(VDI ref -> SR ref) map     `|vdi&#95;map                   |Map of source VDI to destination SR     |
|`(VIF ref -> network ref) map`|vif&#95;map                   |Map of source VIF to destination network|
|`(string -> string) map      `|options                       |Other parameters                        |
|`(VGPU ref -> GPU_group ref) map`|vgpu&#95;map                  |Map of source vGPU to destination GPU group|

_Minimum Role:_ vm-power-admin

_Return Type:_ `VM ref`

The reference of the newly created VM in the destination pool

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `LICENCE_RESTRICTION`

#### RPC name: pause

_Overview:_

Pause the specified VM. This can only be called when the specified VM is in the Running state.

_Signature:_

```
void pause (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to pause                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: pool&#95;migrate

_Overview:_

Migrate a VM to another Host.

_Signature:_

```
void pool_migrate (session ref session_id, VM ref vm, host ref host, (string -> string) map options)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to migrate                       |
|`host ref                    `|host                          |The target host                         |
|`(string -> string) map      `|options                       |Extra configuration operations          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `VM_IS_TEMPLATE`, `OPERATION_NOT_ALLOWED`, `VM_MIGRATE_FAILED`

#### RPC name: power&#95;state&#95;reset

_Overview:_

Reset the power&#45;state of the VM to halted in the database only. &#40;Used to recover from slave failures in pooling scenarios by resetting the power&#45;states of VMs running on dead slaves to halted.&#41; This is a potentially dangerous operation; use with care.

_Signature:_

```
void power_state_reset (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to reset                         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: provision

_Overview:_

Inspects the disk configuration contained within the VM's other&#95;config, creates VDIs and VBDs and then executes any applicable post&#45;install script.

_Signature:_

```
void provision (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be provisioned                |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`, `LICENCE_RESTRICTION`

#### RPC name: query&#95;data&#95;source

_Overview:_

Query the latest value of the specified data source

_Signature:_

```
float query_data_source (session ref session_id, VM ref self, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|data&#95;source               |The data source to query                |

_Minimum Role:_ read-only

_Return Type:_ `float`

The latest value, averaged over the last 5 seconds

#### RPC name: query&#95;services

_Overview:_

Query the system services advertised by this VM and register them. This can only be applied to a system domain.

_Signature:_

```
(string -> string) map query_services (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |

_Minimum Role:_ pool-admin

_Return Type:_ `(string -> string) map`

map of service type to name

#### RPC name: record&#95;data&#95;source

_Overview:_

Start recording the specified data source

_Signature:_

```
void record_data_source (session ref session_id, VM ref self, string data_source)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|data&#95;source               |The data source to record               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: recover

_Overview:_

Recover the VM

_Signature:_

```
void recover (session ref session_id, VM ref self, session ref session_to, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to recover                       |
|`session ref                 `|session&#95;to                |The session to which the VM is to be recovered.|
|`bool                        `|force                         |Whether the VM should replace newer versions of itself.|

_Minimum Role:_ read-only

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;blocked&#95;operations

_Overview:_

Remove the given key and its corresponding value from the blocked&#95;operations field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_blocked_operations (session ref session_id, VM ref self, vm_operations key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`vm_operations               `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;HVM&#95;boot&#95;params

_Overview:_

Remove the given key and its corresponding value from the HVM/boot&#95;params field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_HVM_boot_params (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;NVRAM

_Overview:_



_Signature:_

```
void remove_from_NVRAM (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|key                           |The key                                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;platform

_Overview:_

Remove the given key and its corresponding value from the platform field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_platform (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;VCPUs&#95;params

_Overview:_

Remove the given key and its corresponding value from the VCPUs/params field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_VCPUs_params (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;xenstore&#95;data

_Overview:_

Remove the given key and its corresponding value from the xenstore&#95;data field of the given VM.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_xenstore_data (session ref session_id, VM ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: remove&#95;tags

_Overview:_

Remove the given value from the tags field of the given VM.  If the value is not in that Set, then do nothing.

_Signature:_

```
void remove_tags (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |Value to remove                         |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: resume

_Overview:_

Awaken the specified VM and resume it.  This can only be called when the specified VM is in the Suspended state.

_Signature:_

```
void resume (session ref session_id, VM ref vm, bool start_paused, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to resume                        |
|`bool                        `|start&#95;paused              |Resume VM in paused state if set to true.|
|`bool                        `|force                         |Attempt to force the VM to resume. If this flag is false then the VM may fail pre&#45;resume safety checks &#40;e.g. if the CPU the VM was running on looks substantially different to the current one&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: resume&#95;on

_Overview:_

Awaken the specified VM and resume it on a particular Host.  This can only be called when the specified VM is in the Suspended state.

_Signature:_

```
void resume_on (session ref session_id, VM ref vm, host ref host, bool start_paused, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to resume                        |
|`host ref                    `|host                          |The Host on which to resume the VM      |
|`bool                        `|start&#95;paused              |Resume VM in paused state if set to true.|
|`bool                        `|force                         |Attempt to force the VM to resume. If this flag is false then the VM may fail pre&#45;resume safety checks &#40;e.g. if the CPU the VM was running on looks substantially different to the current one&#41;|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: retrieve&#95;wlb&#95;recommendations

_Overview:_

Returns mapping of hosts to ratings, indicating the suitability of starting the VM at that location according to wlb. Rating is replaced with an error if the VM cannot boot there.

_Signature:_

```
(host ref -> string set) map retrieve_wlb_recommendations (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |

_Minimum Role:_ read-only

_Return Type:_ `(host ref -> string set) map`

The potential hosts and their corresponding recommendations or errors

#### RPC name: revert

_Overview:_

Reverts the specified VM to a previous state.

_Signature:_

```
void revert (session ref session_id, VM ref snapshot)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|snapshot                      |The snapshotted state that we revert to |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OPERATION_NOT_ALLOWED`, `SR_FULL`, `VM_REVERT_FAILED`

#### RPC name: send&#95;sysrq

_Overview:_

Send the given key as a sysrq to this VM.  The key is specified as a single character &#40;a String of length 1&#41;.  This can only be called when the specified VM is in the Running state.

_Signature:_

```
void send_sysrq (session ref session_id, VM ref vm, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |
|`string                      `|key                           |The key to send                         |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`

#### RPC name: send&#95;trigger

_Overview:_

Send the named trigger to this VM.  This can only be called when the specified VM is in the Running state.

_Signature:_

```
void send_trigger (session ref session_id, VM ref vm, string trigger)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM                                  |
|`string                      `|trigger                       |The trigger to send                     |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`

#### RPC name: set&#95;actions&#95;after&#95;crash

_Overview:_

Sets the actions&#95;after&#95;crash parameter

_Signature:_

```
void set_actions_after_crash (session ref session_id, VM ref self, on_crash_behaviour value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to set                           |
|`on_crash_behaviour          `|value                         |The new value to set                    |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;actions&#95;after&#95;reboot

_Overview:_

Set the actions/after&#95;reboot field of the given VM.

_Signature:_

```
void set_actions_after_reboot (session ref session_id, VM ref self, on_normal_exit value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`on_normal_exit              `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;actions&#95;after&#95;shutdown

_Overview:_

Set the actions/after&#95;shutdown field of the given VM.

_Signature:_

```
void set_actions_after_shutdown (session ref session_id, VM ref self, on_normal_exit value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`on_normal_exit              `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;affinity

_Overview:_

Set the affinity field of the given VM.

_Signature:_

```
void set_affinity (session ref session_id, VM ref self, host ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`host ref                    `|value                         |New value to set                        |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;appliance

_Overview:_

Assign this VM to an appliance.

_Signature:_

```
void set_appliance (session ref session_id, VM ref self, VM_appliance ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to assign to an appliance.       |
|`VM_appliance ref            `|value                         |The appliance to which this VM should be assigned.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;bios&#95;strings

_Overview:_

Set custom BIOS strings to this VM. VM will be given a default set of BIOS strings, only some of which can be overridden by the supplied values. Allowed keys are: 'bios&#45;vendor', 'bios&#45;version', 'system&#45;manufacturer', 'system&#45;product&#45;name', 'system&#45;version', 'system&#45;serial&#45;number', 'enclosure&#45;asset&#45;tag', 'baseboard&#45;manufacturer', 'baseboard&#45;product&#45;name', 'baseboard&#45;version', 'baseboard&#45;serial&#45;number', 'baseboard&#45;asset&#45;tag', 'baseboard&#45;location&#45;in&#45;chassis', 'enclosure&#45;asset&#45;tag'

_Signature:_

```
void set_bios_strings (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to modify                        |
|`(string -> string) map      `|value                         |The custom BIOS strings as a list of key&#45;value pairs|

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BIOS_STRINGS_ALREADY_SET`, `INVALID_VALUE`

#### RPC name: set&#95;blocked&#95;operations

_Overview:_

Set the blocked&#95;operations field of the given VM.

_Signature:_

```
void set_blocked_operations (session ref session_id, VM ref self, (vm_operations -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(vm_operations -> string) map`|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;domain&#95;type

_Overview:_

Set the VM.domain&#95;type field of the given VM, which will take effect when it is next started

_Signature:_

```
void set_domain_type (session ref session_id, VM ref self, domain_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`domain_type                 `|value                         |The new domain type                     |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;ha&#95;always&#95;run

**This message is deprecated.**

_Overview:_

Set the value of the ha&#95;always&#95;run

_Signature:_

```
void set_ha_always_run (session ref session_id, VM ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`bool                        `|value                         |The value                               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;ha&#95;restart&#95;priority

_Overview:_

Set the value of the ha&#95;restart&#95;priority field

_Signature:_

```
void set_ha_restart_priority (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|value                         |The value                               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;hardware&#95;platform&#95;version

_Overview:_

Set the hardware&#95;platform&#95;version field of the given VM.

_Signature:_

```
void set_hardware_platform_version (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`int                         `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;has&#95;vendor&#95;device

_Overview:_

Controls whether, when the VM starts in HVM mode, its virtual hardware will include the emulated PCI device for which drivers may be available through Windows Update. Usually this should never be changed on a VM on which Windows has been installed: changing it on such a VM is likely to lead to a crash on next start.

_Signature:_

```
void set_has_vendor_device (session ref session_id, VM ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM on which to set this flag        |
|`bool                        `|value                         |True to provide the vendor PCI device.  |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;HVM&#95;boot&#95;params

_Overview:_

Set the HVM/boot&#95;params field of the given VM.

_Signature:_

```
void set_HVM_boot_params (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;HVM&#95;boot&#95;policy

**This message is deprecated.**

_Overview:_

Set the VM.HVM&#95;boot&#95;policy field of the given VM, which will take effect when it is next started

_Signature:_

```
void set_HVM_boot_policy (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`string                      `|value                         |The new HVM boot policy                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;HVM&#95;shadow&#95;multiplier

_Overview:_

Set the shadow memory multiplier on a halted VM

_Signature:_

```
void set_HVM_shadow_multiplier (session ref session_id, VM ref self, float value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`float                       `|value                         |The new shadow memory multiplier to set |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;is&#95;a&#95;template

_Overview:_

Set the is&#95;a&#95;template field of the given VM.

_Signature:_

```
void set_is_a_template (session ref session_id, VM ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory

_Overview:_

Set the memory allocation of this VM. Sets all of memory&#95;static&#95;max, memory&#95;dynamic&#95;min, and memory&#95;dynamic&#95;max to the given value, and leaves memory&#95;static&#95;min untouched.

_Signature:_

```
void set_memory (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |The new memory allocation &#40;bytes&#41;.|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;dynamic&#95;max

_Overview:_

Set the value of the memory&#95;dynamic&#95;max field

_Signature:_

```
void set_memory_dynamic_max (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to modify                        |
|`int                         `|value                         |The new value of memory&#95;dynamic&#95;max|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;dynamic&#95;min

_Overview:_

Set the value of the memory&#95;dynamic&#95;min field

_Signature:_

```
void set_memory_dynamic_min (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to modify                        |
|`int                         `|value                         |The new value of memory&#95;dynamic&#95;min|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;dynamic&#95;range

_Overview:_

Set the minimum and maximum amounts of physical memory the VM is allowed to use.

_Signature:_

```
void set_memory_dynamic_range (session ref session_id, VM ref self, int min, int max)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|min                           |The new minimum value                   |
|`int                         `|max                           |The new maximum value                   |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;limits

_Overview:_

Set the memory limits of this VM.

_Signature:_

```
void set_memory_limits (session ref session_id, VM ref self, int static_min, int static_max, int dynamic_min, int dynamic_max)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|static&#95;min                |The new value of memory&#95;static&#95;min.|
|`int                         `|static&#95;max                |The new value of memory&#95;static&#95;max.|
|`int                         `|dynamic&#95;min               |The new value of memory&#95;dynamic&#95;min.|
|`int                         `|dynamic&#95;max               |The new value of memory&#95;dynamic&#95;max.|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;static&#95;max

_Overview:_

Set the value of the memory&#95;static&#95;max field

_Signature:_

```
void set_memory_static_max (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to modify                        |
|`int                         `|value                         |The new value of memory&#95;static&#95;max|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `HA_OPERATION_WOULD_BREAK_FAILOVER_PLAN`

#### RPC name: set&#95;memory&#95;static&#95;min

_Overview:_

Set the value of the memory&#95;static&#95;min field

_Signature:_

```
void set_memory_static_min (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM to modify                        |
|`int                         `|value                         |The new value of memory&#95;static&#95;min|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;static&#95;range

_Overview:_

Set the static &#40;ie boot&#45;time&#41; range of virtual memory that the VM is allowed to use.

_Signature:_

```
void set_memory_static_range (session ref session_id, VM ref self, int min, int max)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|min                           |The new minimum value                   |
|`int                         `|max                           |The new maximum value                   |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;memory&#95;target&#95;live

**This message is deprecated.**

_Overview:_

Set the memory target for a running VM

_Signature:_

```
void set_memory_target_live (session ref session_id, VM ref self, int target)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|target                        |The target in bytes                     |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VM.

_Signature:_

```
void set_name_description (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VM.

_Signature:_

```
void set_name_label (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;NVRAM

_Overview:_



_Signature:_

```
void set_NVRAM (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`(string -> string) map      `|value                         |The value                               |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;order

_Overview:_

Set this VM's boot order

_Signature:_

```
void set_order (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |This VM's boot order                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VM.

_Signature:_

```
void set_other_config (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PCI&#95;bus

**This message is deprecated.**

_Overview:_

Set the PCI&#95;bus field of the given VM.

_Signature:_

```
void set_PCI_bus (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;platform

_Overview:_

Set the platform field of the given VM.

_Signature:_

```
void set_platform (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;protection&#95;policy

_Overview:_

Set the value of the protection&#95;policy field

_Signature:_

```
void set_protection_policy (session ref session_id, VM ref self, VMPP ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`VMPP ref                    `|value                         |The value                               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;args

_Overview:_

Set the PV/args field of the given VM.

_Signature:_

```
void set_PV_args (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;bootloader

_Overview:_

Set the PV/bootloader field of the given VM.

_Signature:_

```
void set_PV_bootloader (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;bootloader&#95;args

_Overview:_

Set the PV/bootloader&#95;args field of the given VM.

_Signature:_

```
void set_PV_bootloader_args (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;kernel

_Overview:_

Set the PV/kernel field of the given VM.

_Signature:_

```
void set_PV_kernel (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;legacy&#95;args

_Overview:_

Set the PV/legacy&#95;args field of the given VM.

_Signature:_

```
void set_PV_legacy_args (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;PV&#95;ramdisk

_Overview:_

Set the PV/ramdisk field of the given VM.

_Signature:_

```
void set_PV_ramdisk (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;recommendations

_Overview:_

Set the recommendations field of the given VM.

_Signature:_

```
void set_recommendations (session ref session_id, VM ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;shadow&#95;multiplier&#95;live

_Overview:_

Set the shadow memory multiplier on a running VM

_Signature:_

```
void set_shadow_multiplier_live (session ref session_id, VM ref self, float multiplier)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`float                       `|multiplier                    |The new shadow memory multiplier to set |

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

#### RPC name: set&#95;shutdown&#95;delay

_Overview:_

Set this VM's shutdown delay in seconds

_Signature:_

```
void set_shutdown_delay (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |This VM's shutdown delay in seconds     |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;snapshot&#95;schedule

_Overview:_

Set the value of the snapshot schedule field

_Signature:_

```
void set_snapshot_schedule (session ref session_id, VM ref self, VMSS ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`VMSS ref                    `|value                         |The value                               |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;start&#95;delay

_Overview:_

Set this VM's start delay in seconds

_Signature:_

```
void set_start_delay (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |This VM's start delay in seconds        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;suspend&#95;SR

_Overview:_

Set the suspend&#95;SR field of the given VM.

_Signature:_

```
void set_suspend_SR (session ref session_id, VM ref self, SR ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`SR ref                      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;suspend&#95;VDI

_Overview:_

Set this VM's suspend VDI, which must be indentical to its current one

_Signature:_

```
void set_suspend_VDI (session ref session_id, VM ref self, VDI ref value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`VDI ref                     `|value                         |The suspend VDI uuid                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;tags

_Overview:_

Set the tags field of the given VM.

_Signature:_

```
void set_tags (session ref session_id, VM ref self, string set value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`string set                  `|value                         |New value to set                        |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

#### RPC name: set&#95;user&#95;version

_Overview:_

Set the user&#95;version field of the given VM.

_Signature:_

```
void set_user_version (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`int                         `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;VCPUs&#95;at&#95;startup

_Overview:_

Set the number of startup VCPUs for a halted VM

_Signature:_

```
void set_VCPUs_at_startup (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |The new maximum number of VCPUs         |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;VCPUs&#95;max

_Overview:_

Set the maximum number of VCPUs for a halted VM

_Signature:_

```
void set_VCPUs_max (session ref session_id, VM ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|value                         |The new maximum number of VCPUs         |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;VCPUs&#95;number&#95;live

_Overview:_

Set the number of VCPUs for a running VM

_Signature:_

```
void set_VCPUs_number_live (session ref session_id, VM ref self, int nvcpu)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |
|`int                         `|nvcpu                         |The number of VCPUs                     |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_NOT_ALLOWED`, `LICENCE_RESTRICTION`

#### RPC name: set&#95;VCPUs&#95;params

_Overview:_

Set the VCPUs/params field of the given VM.

_Signature:_

```
void set_VCPUs_params (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;xenstore&#95;data

_Overview:_

Set the xenstore&#95;data field of the given VM.

_Signature:_

```
void set_xenstore_data (session ref session_id, VM ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: shutdown

_Overview:_

Attempts to first clean shutdown a VM and if it should fail then perform a hard shutdown on it.

_Signature:_

```
void shutdown (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to shutdown                      |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: snapshot

_Overview:_

Snapshots the specified VM, making a new VM. Snapshot automatically exploits the capabilities of the underlying storage repository in which the VM's disk images are stored &#40;e.g. Copy on Write&#41;.

_Signature:_

```
VM ref snapshot (session ref session_id, VM ref vm, string new_name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be snapshotted                |
|`string                      `|new&#95;name                  |The name of the snapshotted VM          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `VM ref`

The reference of the newly created VM.

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`

#### RPC name: snapshot&#95;with&#95;quiesce

**This message is removed.**

_Overview:_

Snapshots the specified VM with quiesce, making a new VM. Snapshot automatically exploits the capabilities of the underlying storage repository in which the VM's disk images are stored &#40;e.g. Copy on Write&#41;.

_Signature:_

```
VM ref snapshot_with_quiesce (session ref session_id, VM ref vm, string new_name)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to be snapshotted                |
|`string                      `|new&#95;name                  |The name of the snapshotted VM          |

_Minimum Role:_ vm-power-admin

_Return Type:_ `VM ref`

The reference of the newly created VM.

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `SR_FULL`, `OPERATION_NOT_ALLOWED`, `VM_SNAPSHOT_WITH_QUIESCE_FAILED`, `VM_SNAPSHOT_WITH_QUIESCE_TIMEOUT`, `VM_SNAPSHOT_WITH_QUIESCE_PLUGIN_DEOS_NOT_RESPOND`, `VM_SNAPSHOT_WITH_QUIESCE_NOT_SUPPORTED`

#### RPC name: start

_Overview:_

Start the specified VM.  This function can only be called with the VM is in the Halted State.

_Signature:_

```
void start (session ref session_id, VM ref vm, bool start_paused, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to start                         |
|`bool                        `|start&#95;paused              |Instantiate VM in paused state if set to true.|
|`bool                        `|force                         |Attempt to force the VM to start. If this flag is false then the VM may fail pre&#45;boot safety checks &#40;e.g. if the CPU the VM last booted on looks substantially different to the current one&#41;|

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `VM_HVM_REQUIRED`, `VM_IS_TEMPLATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `BOOTLOADER_FAILED`, `UNKNOWN_BOOTLOADER`, `NO_HOSTS_AVAILABLE`, `LICENCE_RESTRICTION`

#### RPC name: start&#95;on

_Overview:_

Start the specified VM on a particular host.  This function can only be called with the VM is in the Halted State.

_Signature:_

```
void start_on (session ref session_id, VM ref vm, host ref host, bool start_paused, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to start                         |
|`host ref                    `|host                          |The Host on which to start the VM       |
|`bool                        `|start&#95;paused              |Instantiate VM in paused state if set to true.|
|`bool                        `|force                         |Attempt to force the VM to start. If this flag is false then the VM may fail pre&#45;boot safety checks &#40;e.g. if the CPU the VM last booted on looks substantially different to the current one&#41;|

_Minimum Role:_ vm-power-admin

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `VM_IS_TEMPLATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `BOOTLOADER_FAILED`, `UNKNOWN_BOOTLOADER`

#### RPC name: suspend

_Overview:_

Suspend the specified VM to disk.  This can only be called when the specified VM is in the Running state.

_Signature:_

```
void suspend (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to suspend                       |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OTHER_OPERATION_IN_PROGRESS`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: unpause

_Overview:_

Resume the specified VM. This can only be called when the specified VM is in the Paused state.

_Signature:_

```
void unpause (session ref session_id, VM ref vm)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|vm                            |The VM to unpause                       |

_Minimum Role:_ vm-operator

_Return Type:_ `void`

_Possible Error Codes:_ `VM_BAD_POWER_STATE`, `OPERATION_NOT_ALLOWED`, `VM_IS_TEMPLATE`

#### RPC name: update&#95;allowed&#95;operations

_Overview:_

Recomputes the list of acceptable operations

_Signature:_

```
void update_allowed_operations (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |reference to the object                 |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: wait&#95;memory&#95;target&#95;live

**This message is deprecated.**

_Overview:_

Wait for a running VM to reach its current memory target

_Signature:_

```
void wait_memory_target_live (session ref session_id, VM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|self                          |The VM                                  |

_Minimum Role:_ read-only

_Return Type:_ `void`

## Class: VM&#95;appliance

VM appliance

### Fields for class: VM&#95;appliance

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`vm_appliance_operation set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|current&#95;operations|`(string -> vm_appliance_operation) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VMs                 |`VM ref set        `|_RO/runtime_   |all VMs in this appliance               |

### RPCs associated with class: VM&#95;appliance

#### RPC name: assert&#95;can&#95;be&#95;recovered

_Overview:_

Assert whether all SRs required to recover this VM appliance are available.

_Signature:_

```
void assert_can_be_recovered (session ref session_id, VM_appliance ref self, session ref session_to)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance to recover             |
|`session ref                 `|session&#95;to                |The session to which the VM appliance is to be recovered.|

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `VM_REQUIRES_SR`

#### RPC name: clean&#95;shutdown

_Overview:_

Perform a clean shutdown of all the VMs in the appliance

_Signature:_

```
void clean_shutdown (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

#### RPC name: create

_Overview:_

Create a new VM&#95;appliance instance, and return its handle.

_Signature:_

```
VM_appliance ref create (session ref session_id, VM_appliance record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance record         `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `VM_appliance ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified VM&#95;appliance instance.

_Signature:_

```
void destroy (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;appliances known to the system.

_Signature:_

```
VM_appliance ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;appliance references to VM&#95;appliance records for all VM&#95;appliances known to the system.

_Signature:_

```
(VM_appliance ref -> VM_appliance record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VM_appliance ref -> VM_appliance record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VM&#95;appliance.

_Signature:_

```
vm_appliance_operation set get_allowed_operations (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vm_appliance_operation set`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VM&#95;appliance instances with the given label.

_Signature:_

```
VM_appliance ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;appliance instance with the specified UUID.

_Signature:_

```
VM_appliance ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance ref`

reference to the object

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VM&#95;appliance.

_Signature:_

```
(string -> vm_appliance_operation) map get_current_operations (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vm_appliance_operation) map`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VM&#95;appliance.

_Signature:_

```
string get_name_description (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VM&#95;appliance.

_Signature:_

```
string get_name_label (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;appliance.

_Signature:_

```
VM_appliance record get_record (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_appliance record`

all fields from the object

#### RPC name: get&#95;SRs&#95;required&#95;for&#95;recovery

_Overview:_

Get the list of SRs required by the VM appliance to recover.

_Signature:_

```
SR ref set get_SRs_required_for_recovery (session ref session_id, VM_appliance ref self, session ref session_to)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance for which the required list of SRs has to be recovered.|
|`session ref                 `|session&#95;to                |The session to which the list of SRs have to be recovered .|

_Minimum Role:_ read-only

_Return Type:_ `SR ref set`

refs for SRs required to recover the VM

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;appliance.

_Signature:_

```
string get_uuid (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VMs

_Overview:_

Get the VMs field of the given VM&#95;appliance.

_Signature:_

```
VM ref set get_VMs (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: hard&#95;shutdown

_Overview:_

Perform a hard shutdown of all the VMs in the appliance

_Signature:_

```
void hard_shutdown (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

#### RPC name: recover

_Overview:_

Recover the VM appliance

_Signature:_

```
void recover (session ref session_id, VM_appliance ref self, session ref session_to, bool force)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance to recover             |
|`session ref                 `|session&#95;to                |The session to which the VM appliance is to be recovered.|
|`bool                        `|force                         |Whether the VMs should replace newer versions of themselves.|

_Minimum Role:_ read-only

_Return Type:_ `void`

_Possible Error Codes:_ `VM_REQUIRES_SR`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VM&#95;appliance.

_Signature:_

```
void set_name_description (session ref session_id, VM_appliance ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VM&#95;appliance.

_Signature:_

```
void set_name_label (session ref session_id, VM_appliance ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: shutdown

_Overview:_

For each VM in the appliance, try to shut it down cleanly. If this fails, perform a hard shutdown of the VM.

_Signature:_

```
void shutdown (session ref session_id, VM_appliance ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

#### RPC name: start

_Overview:_

Start all VMs in the appliance

_Signature:_

```
void start (session ref session_id, VM_appliance ref self, bool paused)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_appliance ref            `|self                          |The VM appliance                        |
|`bool                        `|paused                        |Instantiate all VMs belonging to this appliance in paused state if set to true.|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

_Possible Error Codes:_ `OPERATION_PARTIALLY_FAILED`

## Class: VM&#95;guest&#95;metrics

The metrics reported by the guest &#40;as opposed to inferred from outside&#41;

### Fields for class: VM&#95;guest&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|can&#95;use&#95;hotplug&#95;vbd|`tristate_type     `|_RO/runtime_   |The guest's statement of whether it supports VBD hotplug, i.e. whether it is capable of responding immediately to instantiation of a new VBD by bringing online a new PV block device. If the guest states that it is not capable, then the VBD plug and unplug operations will not be allowed while the guest is running.|
|can&#95;use&#95;hotplug&#95;vif|`tristate_type     `|_RO/runtime_   |The guest's statement of whether it supports VIF hotplug, i.e. whether it is capable of responding immediately to instantiation of a new VIF by bringing online a new PV network device. If the guest states that it is not capable, then the VIF plug and unplug operations will not be allowed while the guest is running.|
|disks               |`(string -> string) map`|_RO/runtime_   |**Removed**. This field exists but has no data.|
|last&#95;updated    |`datetime          `|_RO/runtime_   |Time at which this information was last updated|
|live                |`bool              `|_RO/runtime_   |True if the guest is sending heartbeat messages via the guest agent|
|memory              |`(string -> string) map`|_RO/runtime_   |**Removed**. This field exists but has no data. Use the memory and memory&#95;internal&#95;free RRD data&#45;sources instead.|
|networks            |`(string -> string) map`|_RO/runtime_   |network configuration                   |
|os&#95;version      |`(string -> string) map`|_RO/runtime_   |version of the OS                       |
|other               |`(string -> string) map`|_RO/runtime_   |anything else                           |
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|PV&#95;drivers&#95;detected|`bool              `|_RO/runtime_   |At least one of the guest's devices has successfully connected to the backend.|
|PV&#95;drivers&#95;up&#95;to&#95;date|`bool              `|_RO/runtime_   |**Deprecated**. Logically equivalent to PV&#95;drivers&#95;detected|
|PV&#95;drivers&#95;version|`(string -> string) map`|_RO/runtime_   |version of the PV drivers               |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |

### RPCs associated with class: VM&#95;guest&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, VM_guest_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;guest&#95;metrics instances known to the system.

_Signature:_

```
VM_guest_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;guest&#95;metrics references to VM&#95;guest&#95;metrics records for all VM&#95;guest&#95;metrics instances known to the system.

_Signature:_

```
(VM_guest_metrics ref -> VM_guest_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VM_guest_metrics ref -> VM_guest_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;guest&#95;metrics instance with the specified UUID.

_Signature:_

```
VM_guest_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics ref`

reference to the object

#### RPC name: get&#95;can&#95;use&#95;hotplug&#95;vbd

_Overview:_

Get the can&#95;use&#95;hotplug&#95;vbd field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
tristate_type get_can_use_hotplug_vbd (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tristate_type`

value of the field

#### RPC name: get&#95;can&#95;use&#95;hotplug&#95;vif

_Overview:_

Get the can&#95;use&#95;hotplug&#95;vif field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
tristate_type get_can_use_hotplug_vif (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `tristate_type`

value of the field

#### RPC name: get&#95;disks

**This message is removed.**

_Overview:_

Get the disks field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_disks (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;live

_Overview:_

Get the live field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_live (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;memory

**This message is removed.**

_Overview:_

Get the memory field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_memory (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;networks

_Overview:_

Get the networks field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_networks (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;os&#95;version

_Overview:_

Get the os&#95;version field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_os_version (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;other

_Overview:_

Get the other field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_other (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;PV&#95;drivers&#95;detected

_Overview:_

Get the PV&#95;drivers&#95;detected field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_PV_drivers_detected (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;PV&#95;drivers&#95;up&#95;to&#95;date

**This message is deprecated.**

_Overview:_

Get the PV&#95;drivers&#95;up&#95;to&#95;date field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
bool get_PV_drivers_up_to_date (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;PV&#95;drivers&#95;version

_Overview:_

Get the PV&#95;drivers&#95;version field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
(string -> string) map get_PV_drivers_version (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;guest&#95;metrics.

_Signature:_

```
VM_guest_metrics record get_record (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_guest_metrics record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, VM_guest_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VM&#95;guest&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VM_guest_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VM&#95;guest&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, VM_guest_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_guest_metrics ref        `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VM&#95;metrics

The metrics associated with a VM

### Fields for class: VM&#95;metrics

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|current&#95;domain&#95;type|`domain_type       `|_RO/runtime_   |The current domain type of the VM &#40;for running,suspended, or paused VMs&#41;. The last&#45;known domain type for halted VMs.|
|hvm                 |`bool              `|_RO/runtime_   |hardware virtual machine                |
|install&#95;time    |`datetime          `|_RO/runtime_   |Time at which the VM was installed      |
|last&#95;updated    |`datetime          `|_RO/runtime_   |Time at which this information was last updated|
|memory&#95;actual   |`int               `|_RO/runtime_   |Guest's actual memory &#40;bytes&#41;   |
|nested&#95;virt     |`bool              `|_RO/runtime_   |VM supports nested virtualisation       |
|nomigrate           |`bool              `|_RO/runtime_   |VM is immobile and can't migrate between hosts|
|other&#95;config    |`(string -> string) map`|_RW_           |additional configuration                |
|start&#95;time      |`datetime          `|_RO/runtime_   |Time at which this VM was last booted   |
|state               |`string set        `|_RO/runtime_   |The state of the guest, eg blocked, dying etc|
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VCPUs&#95;CPU       |`(int -> int) map  `|_RO/runtime_   |VCPU to PCPU map                        |
|VCPUs&#95;flags     |`(int -> string set) map`|_RO/runtime_   |CPU flags &#40;blocked,online,running&#41;|
|VCPUs&#95;number    |`int               `|_RO/runtime_   |Current number of VCPUs                 |
|VCPUs&#95;params    |`(string -> string) map`|_RO/runtime_   |The live equivalent to VM.VCPUs&#95;params|
|VCPUs&#95;utilisation|`(int -> float) map`|_RO/runtime_   |**Removed**. Utilisation for all of guest's current VCPUs|

### RPCs associated with class: VM&#95;metrics

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
void add_to_other_config (session ref session_id, VM_metrics ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VM&#95;metrics instances known to the system.

_Signature:_

```
VM_metrics ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VM&#95;metrics references to VM&#95;metrics records for all VM&#95;metrics instances known to the system.

_Signature:_

```
(VM_metrics ref -> VM_metrics record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VM_metrics ref -> VM_metrics record) map`

records of all objects

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VM&#95;metrics instance with the specified UUID.

_Signature:_

```
VM_metrics ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics ref`

reference to the object

#### RPC name: get&#95;current&#95;domain&#95;type

_Overview:_

Get the current&#95;domain&#95;type field of the given VM&#95;metrics.

_Signature:_

```
domain_type get_current_domain_type (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `domain_type`

value of the field

#### RPC name: get&#95;hvm

_Overview:_

Get the hvm field of the given VM&#95;metrics.

_Signature:_

```
bool get_hvm (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;install&#95;time

_Overview:_

Get the install&#95;time field of the given VM&#95;metrics.

_Signature:_

```
datetime get_install_time (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;last&#95;updated

_Overview:_

Get the last&#95;updated field of the given VM&#95;metrics.

_Signature:_

```
datetime get_last_updated (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;memory&#95;actual

_Overview:_

Get the memory/actual field of the given VM&#95;metrics.

_Signature:_

```
int get_memory_actual (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;nested&#95;virt

_Overview:_

Get the nested&#95;virt field of the given VM&#95;metrics.

_Signature:_

```
bool get_nested_virt (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;nomigrate

_Overview:_

Get the nomigrate field of the given VM&#95;metrics.

_Signature:_

```
bool get_nomigrate (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VM&#95;metrics.

_Signature:_

```
VM_metrics record get_record (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM_metrics record`

all fields from the object

#### RPC name: get&#95;start&#95;time

_Overview:_

Get the start&#95;time field of the given VM&#95;metrics.

_Signature:_

```
datetime get_start_time (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;state

_Overview:_

Get the state field of the given VM&#95;metrics.

_Signature:_

```
string set get_state (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VM&#95;metrics.

_Signature:_

```
string get_uuid (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VCPUs&#95;CPU

_Overview:_

Get the VCPUs/CPU field of the given VM&#95;metrics.

_Signature:_

```
(int -> int) map get_VCPUs_CPU (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> int) map`

value of the field

#### RPC name: get&#95;VCPUs&#95;flags

_Overview:_

Get the VCPUs/flags field of the given VM&#95;metrics.

_Signature:_

```
(int -> string set) map get_VCPUs_flags (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> string set) map`

value of the field

#### RPC name: get&#95;VCPUs&#95;number

_Overview:_

Get the VCPUs/number field of the given VM&#95;metrics.

_Signature:_

```
int get_VCPUs_number (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;VCPUs&#95;params

_Overview:_

Get the VCPUs/params field of the given VM&#95;metrics.

_Signature:_

```
(string -> string) map get_VCPUs_params (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;VCPUs&#95;utilisation

**This message is removed.**

_Overview:_

Get the VCPUs/utilisation field of the given VM&#95;metrics.

_Signature:_

```
(int -> float) map get_VCPUs_utilisation (session ref session_id, VM_metrics ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(int -> float) map`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VM&#95;metrics.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VM_metrics ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VM&#95;metrics.

_Signature:_

```
void set_other_config (session ref session_id, VM_metrics ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM_metrics ref              `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

## Class: VMPP

**This class is removed.**

VM Protection Policy

### Fields for class: VMPP

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|alarm&#95;config    |`(string -> string) map`|_RO/constructor_|**Removed**. configuration for the alarm|
|archive&#95;frequency|`vmpp_archive_frequency`|_RO/constructor_|**Removed**. frequency of the archive schedule|
|archive&#95;last&#95;run&#95;time|`datetime          `|_RO/runtime_   |**Removed**. time of the last archive   |
|archive&#95;schedule|`(string -> string) map`|_RO/constructor_|**Removed**. schedule of the archive containing 'hour', 'min', 'days'. Date/time&#45;related information is in Local Timezone|
|archive&#95;target&#95;config|`(string -> string) map`|_RO/constructor_|**Removed**. configuration for the archive, including its 'location', 'username', 'password'|
|archive&#95;target&#95;type|`vmpp_archive_target_type`|_RO/constructor_|**Removed**. type of the archive target config|
|backup&#95;frequency|`vmpp_backup_frequency`|_RO/constructor_|**Removed**. frequency of the backup schedule|
|backup&#95;last&#95;run&#95;time|`datetime          `|_RO/runtime_   |**Removed**. time of the last backup    |
|backup&#95;retention&#95;value|`int               `|_RO/constructor_|**Removed**. maximum number of backups that should be stored at any time|
|backup&#95;schedule |`(string -> string) map`|_RO/constructor_|**Removed**. schedule of the backup containing 'hour', 'min', 'days'. Date/time&#45;related information is in Local Timezone|
|backup&#95;type     |`vmpp_backup_type  `|_RW_           |**Removed**. type of the backup sub&#45;policy|
|is&#95;alarm&#95;enabled|`bool              `|_RO/constructor_|**Removed**. true if alarm is enabled for this policy|
|is&#95;archive&#95;running|`bool              `|_RO/runtime_   |**Removed**. true if this protection policy's archive is running|
|is&#95;backup&#95;running|`bool              `|_RO/runtime_   |**Removed**. true if this protection policy's backup is running|
|is&#95;policy&#95;enabled|`bool              `|_RW_           |**Removed**. enable or disable this policy|
|name&#95;description|`string            `|_RW_           |**Removed**. a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |**Removed**. a human&#45;readable name  |
|recent&#95;alerts   |`string set        `|_RO/runtime_   |**Removed**. recent alerts              |
|uuid                |`string            `|_RO/runtime_   |**Removed**. Unique identifier/object reference|
|VMs                 |`VM ref set        `|_RO/runtime_   |**Removed**. all VMs attached to this protection policy|

### RPCs associated with class: VMPP

#### RPC name: add&#95;to&#95;alarm&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void add_to_alarm_config (session ref session_id, VMPP ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to add                          |
|`string                      `|value                         |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;archive&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void add_to_archive_schedule (session ref session_id, VMPP ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to add                          |
|`string                      `|value                         |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;archive&#95;target&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void add_to_archive_target_config (session ref session_id, VMPP ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to add                          |
|`string                      `|value                         |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: add&#95;to&#95;backup&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void add_to_backup_schedule (session ref session_id, VMPP ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to add                          |
|`string                      `|value                         |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: archive&#95;now

**This message is removed.**

_Overview:_

This call archives the snapshot provided as a parameter

_Signature:_

```
string archive_now (session ref session_id, VM ref snapshot)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|snapshot                      |The snapshot to archive                 |

_Minimum Role:_ vm-power-admin

_Return Type:_ `string`

An XMLRPC result

#### RPC name: create

**This message is removed.**

_Overview:_

Create a new VMPP instance, and return its handle.

_Signature:_

```
VMPP ref create (session ref session_id, VMPP record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP record                 `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `VMPP ref`

reference to the newly created object

#### RPC name: destroy

**This message is removed.**

_Overview:_

Destroy the specified VMPP instance.

_Signature:_

```
void destroy (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;alarm&#95;config

**This message is removed.**

_Overview:_

Get the alarm&#95;config field of the given VMPP.

_Signature:_

```
(string -> string) map get_alarm_config (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;alerts

**This message is removed.**

_Overview:_

This call fetches a history of alerts for a given protection policy

_Signature:_

```
string set get_alerts (session ref session_id, VMPP ref vmpp, int hours_from_now)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|vmpp                          |The protection policy                   |
|`int                         `|hours&#95;from&#95;now        |how many hours in the past the oldest record to fetch is|

_Minimum Role:_ pool-operator

_Return Type:_ `string set`

A list of alerts encoded in xml

#### RPC name: get&#95;all

**This message is removed.**

_Overview:_

Return a list of all the VMPPs known to the system.

_Signature:_

```
VMPP ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VMPP ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

**This message is removed.**

_Overview:_

Return a map of VMPP references to VMPP records for all VMPPs known to the system.

_Signature:_

```
(VMPP ref -> VMPP record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VMPP ref -> VMPP record) map`

records of all objects

#### RPC name: get&#95;archive&#95;frequency

**This message is removed.**

_Overview:_

Get the archive&#95;frequency field of the given VMPP.

_Signature:_

```
vmpp_archive_frequency get_archive_frequency (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmpp_archive_frequency`

value of the field

#### RPC name: get&#95;archive&#95;last&#95;run&#95;time

**This message is removed.**

_Overview:_

Get the archive&#95;last&#95;run&#95;time field of the given VMPP.

_Signature:_

```
datetime get_archive_last_run_time (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;archive&#95;schedule

**This message is removed.**

_Overview:_

Get the archive&#95;schedule field of the given VMPP.

_Signature:_

```
(string -> string) map get_archive_schedule (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;archive&#95;target&#95;config

**This message is removed.**

_Overview:_

Get the archive&#95;target&#95;config field of the given VMPP.

_Signature:_

```
(string -> string) map get_archive_target_config (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;archive&#95;target&#95;type

**This message is removed.**

_Overview:_

Get the archive&#95;target&#95;type field of the given VMPP.

_Signature:_

```
vmpp_archive_target_type get_archive_target_type (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmpp_archive_target_type`

value of the field

#### RPC name: get&#95;backup&#95;frequency

**This message is removed.**

_Overview:_

Get the backup&#95;frequency field of the given VMPP.

_Signature:_

```
vmpp_backup_frequency get_backup_frequency (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmpp_backup_frequency`

value of the field

#### RPC name: get&#95;backup&#95;last&#95;run&#95;time

**This message is removed.**

_Overview:_

Get the backup&#95;last&#95;run&#95;time field of the given VMPP.

_Signature:_

```
datetime get_backup_last_run_time (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;backup&#95;retention&#95;value

**This message is removed.**

_Overview:_

Get the backup&#95;retention&#95;value field of the given VMPP.

_Signature:_

```
int get_backup_retention_value (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;backup&#95;schedule

**This message is removed.**

_Overview:_

Get the backup&#95;schedule field of the given VMPP.

_Signature:_

```
(string -> string) map get_backup_schedule (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;backup&#95;type

**This message is removed.**

_Overview:_

Get the backup&#95;type field of the given VMPP.

_Signature:_

```
vmpp_backup_type get_backup_type (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmpp_backup_type`

value of the field

#### RPC name: get&#95;by&#95;name&#95;label

**This message is removed.**

_Overview:_

Get all the VMPP instances with the given label.

_Signature:_

```
VMPP ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VMPP ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

**This message is removed.**

_Overview:_

Get a reference to the VMPP instance with the specified UUID.

_Signature:_

```
VMPP ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VMPP ref`

reference to the object

#### RPC name: get&#95;is&#95;alarm&#95;enabled

**This message is removed.**

_Overview:_

Get the is&#95;alarm&#95;enabled field of the given VMPP.

_Signature:_

```
bool get_is_alarm_enabled (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;archive&#95;running

**This message is removed.**

_Overview:_

Get the is&#95;archive&#95;running field of the given VMPP.

_Signature:_

```
bool get_is_archive_running (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;backup&#95;running

**This message is removed.**

_Overview:_

Get the is&#95;backup&#95;running field of the given VMPP.

_Signature:_

```
bool get_is_backup_running (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;is&#95;policy&#95;enabled

**This message is removed.**

_Overview:_

Get the is&#95;policy&#95;enabled field of the given VMPP.

_Signature:_

```
bool get_is_policy_enabled (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;name&#95;description

**This message is removed.**

_Overview:_

Get the name/description field of the given VMPP.

_Signature:_

```
string get_name_description (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

**This message is removed.**

_Overview:_

Get the name/label field of the given VMPP.

_Signature:_

```
string get_name_label (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;recent&#95;alerts

**This message is removed.**

_Overview:_

Get the recent&#95;alerts field of the given VMPP.

_Signature:_

```
string set get_recent_alerts (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string set`

value of the field

#### RPC name: get&#95;record

**This message is removed.**

_Overview:_

Get a record containing the current state of the given VMPP.

_Signature:_

```
VMPP record get_record (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VMPP record`

all fields from the object

#### RPC name: get&#95;uuid

**This message is removed.**

_Overview:_

Get the uuid field of the given VMPP.

_Signature:_

```
string get_uuid (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VMs

**This message is removed.**

_Overview:_

Get the VMs field of the given VMPP.

_Signature:_

```
VM ref set get_VMs (session ref session_id, VMPP ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: protect&#95;now

**This message is removed.**

_Overview:_

This call executes the protection policy immediately

_Signature:_

```
string protect_now (session ref session_id, VMPP ref vmpp)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|vmpp                          |The protection policy to execute        |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XMLRPC result

#### RPC name: remove&#95;from&#95;alarm&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void remove_from_alarm_config (session ref session_id, VMPP ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;archive&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void remove_from_archive_schedule (session ref session_id, VMPP ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;archive&#95;target&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void remove_from_archive_target_config (session ref session_id, VMPP ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: remove&#95;from&#95;backup&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void remove_from_backup_schedule (session ref session_id, VMPP ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`string                      `|key                           |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;alarm&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void set_alarm_config (session ref session_id, VMPP ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`(string -> string) map      `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;archive&#95;frequency

**This message is removed.**

_Overview:_

Set the value of the archive&#95;frequency field

_Signature:_

```
void set_archive_frequency (session ref session_id, VMPP ref self, vmpp_archive_frequency value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`vmpp_archive_frequency      `|value                         |the archive frequency                   |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;archive&#95;last&#95;run&#95;time

**This message is removed.**

_Overview:_



_Signature:_

```
void set_archive_last_run_time (session ref session_id, VMPP ref self, datetime value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`datetime                    `|value                         |the value to set                        |

_Return Type:_ `void`

#### RPC name: set&#95;archive&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void set_archive_schedule (session ref session_id, VMPP ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`(string -> string) map      `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;archive&#95;target&#95;config

**This message is removed.**

_Overview:_



_Signature:_

```
void set_archive_target_config (session ref session_id, VMPP ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`(string -> string) map      `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;archive&#95;target&#95;type

**This message is removed.**

_Overview:_

Set the value of the archive&#95;target&#95;config&#95;type field

_Signature:_

```
void set_archive_target_type (session ref session_id, VMPP ref self, vmpp_archive_target_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`vmpp_archive_target_type    `|value                         |the archive target config type          |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;backup&#95;frequency

**This message is removed.**

_Overview:_

Set the value of the backup&#95;frequency field

_Signature:_

```
void set_backup_frequency (session ref session_id, VMPP ref self, vmpp_backup_frequency value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`vmpp_backup_frequency       `|value                         |the backup frequency                    |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;backup&#95;last&#95;run&#95;time

**This message is removed.**

_Overview:_



_Signature:_

```
void set_backup_last_run_time (session ref session_id, VMPP ref self, datetime value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`datetime                    `|value                         |the value to set                        |

_Return Type:_ `void`

#### RPC name: set&#95;backup&#95;retention&#95;value

**This message is removed.**

_Overview:_



_Signature:_

```
void set_backup_retention_value (session ref session_id, VMPP ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`int                         `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;backup&#95;schedule

**This message is removed.**

_Overview:_



_Signature:_

```
void set_backup_schedule (session ref session_id, VMPP ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`(string -> string) map      `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;backup&#95;type

**This message is removed.**

_Overview:_

Set the backup&#95;type field of the given VMPP.

_Signature:_

```
void set_backup_type (session ref session_id, VMPP ref self, vmpp_backup_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |
|`vmpp_backup_type            `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;is&#95;alarm&#95;enabled

**This message is removed.**

_Overview:_

Set the value of the is&#95;alarm&#95;enabled field

_Signature:_

```
void set_is_alarm_enabled (session ref session_id, VMPP ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |The protection policy                   |
|`bool                        `|value                         |true if alarm is enabled for this policy|

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;is&#95;policy&#95;enabled

**This message is removed.**

_Overview:_

Set the is&#95;policy&#95;enabled field of the given VMPP.

_Signature:_

```
void set_is_policy_enabled (session ref session_id, VMPP ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

**This message is removed.**

_Overview:_

Set the name/description field of the given VMPP.

_Signature:_

```
void set_name_description (session ref session_id, VMPP ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

**This message is removed.**

_Overview:_

Set the name/label field of the given VMPP.

_Signature:_

```
void set_name_label (session ref session_id, VMPP ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMPP ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

## Class: VMSS

VM Snapshot Schedule

### Fields for class: VMSS

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|enabled             |`bool              `|_RW_           |enable or disable this snapshot schedule|
|frequency           |`vmss_frequency    `|_RO/constructor_|frequency of taking snapshot from snapshot schedule|
|last&#95;run&#95;time|`datetime          `|_RO/runtime_   |time of the last snapshot               |
|name&#95;description|`string            `|_RW_           |a notes field containing human&#45;readable description|
|name&#95;label      |`string            `|_RW_           |a human&#45;readable name               |
|retained&#95;snapshots|`int               `|_RO/constructor_|maximum number of snapshots that should be stored at any time|
|schedule            |`(string -> string) map`|_RO/constructor_|schedule of the snapshot containing 'hour', 'min', 'days'. Date/time&#45;related information is in Local Timezone|
|type                |`vmss_type         `|_RO/constructor_|type of the snapshot schedule           |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VMs                 |`VM ref set        `|_RO/runtime_   |all VMs attached to this snapshot schedule|

### RPCs associated with class: VMSS

#### RPC name: add&#95;to&#95;schedule

_Overview:_



_Signature:_

```
void add_to_schedule (session ref session_id, VMSS ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`string                      `|key                           |the key to add                          |
|`string                      `|value                         |the value to add                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new VMSS instance, and return its handle.

_Signature:_

```
VMSS ref create (session ref session_id, VMSS record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS record                 `|args                          |All constructor arguments               |

_Minimum Role:_ pool-operator

_Return Type:_ `VMSS ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified VMSS instance.

_Signature:_

```
void destroy (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VMSSs known to the system.

_Signature:_

```
VMSS ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VMSS references to VMSS records for all VMSSs known to the system.

_Signature:_

```
(VMSS ref -> VMSS record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VMSS ref -> VMSS record) map`

records of all objects

#### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the VMSS instances with the given label.

_Signature:_

```
VMSS ref set get_by_name_label (session ref session_id, string label)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|label                         |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref set`

references to objects with matching names

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VMSS instance with the specified UUID.

_Signature:_

```
VMSS ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VMSS ref`

reference to the object

#### RPC name: get&#95;enabled

_Overview:_

Get the enabled field of the given VMSS.

_Signature:_

```
bool get_enabled (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;frequency

_Overview:_

Get the frequency field of the given VMSS.

_Signature:_

```
vmss_frequency get_frequency (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmss_frequency`

value of the field

#### RPC name: get&#95;last&#95;run&#95;time

_Overview:_

Get the last&#95;run&#95;time field of the given VMSS.

_Signature:_

```
datetime get_last_run_time (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `datetime`

value of the field

#### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given VMSS.

_Signature:_

```
string get_name_description (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given VMSS.

_Signature:_

```
string get_name_label (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VMSS.

_Signature:_

```
VMSS record get_record (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VMSS record`

all fields from the object

#### RPC name: get&#95;retained&#95;snapshots

_Overview:_

Get the retained&#95;snapshots field of the given VMSS.

_Signature:_

```
int get_retained_snapshots (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `int`

value of the field

#### RPC name: get&#95;schedule

_Overview:_

Get the schedule field of the given VMSS.

_Signature:_

```
(string -> string) map get_schedule (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;type

_Overview:_

Get the type field of the given VMSS.

_Signature:_

```
vmss_type get_type (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vmss_type`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VMSS.

_Signature:_

```
string get_uuid (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VMs

_Overview:_

Get the VMs field of the given VMSS.

_Signature:_

```
VM ref set get_VMs (session ref session_id, VMSS ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref set`

value of the field

#### RPC name: remove&#95;from&#95;schedule

_Overview:_



_Signature:_

```
void remove_from_schedule (session ref session_id, VMSS ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`string                      `|key                           |the key to remove                       |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;enabled

_Overview:_

Set the enabled field of the given VMSS.

_Signature:_

```
void set_enabled (session ref session_id, VMSS ref self, bool value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |
|`bool                        `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;frequency

_Overview:_

Set the value of the frequency field

_Signature:_

```
void set_frequency (session ref session_id, VMSS ref self, vmss_frequency value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`vmss_frequency              `|value                         |the snapshot schedule frequency         |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;last&#95;run&#95;time

_Overview:_



_Signature:_

```
void set_last_run_time (session ref session_id, VMSS ref self, datetime value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`datetime                    `|value                         |the value to set                        |

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given VMSS.

_Signature:_

```
void set_name_description (session ref session_id, VMSS ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given VMSS.

_Signature:_

```
void set_name_label (session ref session_id, VMSS ref self, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |reference to the object                 |
|`string                      `|value                         |New value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;retained&#95;snapshots

_Overview:_



_Signature:_

```
void set_retained_snapshots (session ref session_id, VMSS ref self, int value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The schedule snapshot                   |
|`int                         `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;schedule

_Overview:_



_Signature:_

```
void set_schedule (session ref session_id, VMSS ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`(string -> string) map      `|value                         |the value to set                        |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: set&#95;type

_Overview:_



_Signature:_

```
void set_type (session ref session_id, VMSS ref self, vmss_type value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|self                          |The snapshot schedule                   |
|`vmss_type                   `|value                         |the snapshot schedule type              |

_Minimum Role:_ pool-operator

_Return Type:_ `void`

#### RPC name: snapshot&#95;now

_Overview:_

This call executes the snapshot schedule immediately

_Signature:_

```
string snapshot_now (session ref session_id, VMSS ref vmss)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VMSS ref                    `|vmss                          |Snapshot Schedule to execute            |

_Minimum Role:_ pool-operator

_Return Type:_ `string`

An XMLRPC result

## Class: VTPM

A virtual TPM device

### Fields for class: VTPM

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|backend             |`VM ref            `|_RO/constructor_|the domain where the backend is located |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VM                  |`VM ref            `|_RO/constructor_|the virtual machine                     |

### RPCs associated with class: VTPM

#### RPC name: create

_Overview:_

Create a new VTPM instance, and return its handle.

_Signature:_

```
VTPM ref create (session ref session_id, VTPM record args)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM record                 `|args                          |All constructor arguments               |

_Minimum Role:_ vm-admin

_Return Type:_ `VTPM ref`

reference to the newly created object

#### RPC name: destroy

_Overview:_

Destroy the specified VTPM instance.

_Signature:_

```
void destroy (session ref session_id, VTPM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM ref                    `|self                          |reference to the object                 |

_Minimum Role:_ vm-admin

_Return Type:_ `void`

#### RPC name: get&#95;backend

_Overview:_

Get the backend field of the given VTPM.

_Signature:_

```
VM ref get_backend (session ref session_id, VTPM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VTPM instance with the specified UUID.

_Signature:_

```
VTPM ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VTPM ref`

reference to the object

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VTPM.

_Signature:_

```
VTPM record get_record (session ref session_id, VTPM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VTPM record`

all fields from the object

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VTPM.

_Signature:_

```
string get_uuid (session ref session_id, VTPM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VTPM.

_Signature:_

```
VM ref get_VM (session ref session_id, VTPM ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VTPM ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

## Class: VUSB

Describes the vusb device

### Fields for class: VUSB

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|allowed&#95;operations|`vusb_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|current&#95;operations|`(string -> vusb_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|currently&#95;attached|`bool              `|_RO/runtime_   |is the device currently attached        |
|other&#95;config    |`(string -> string) map`|_RW_           |Additional configuration                |
|USB&#95;group       |`USB_group ref     `|_RO/runtime_   |USB group used by the VUSB              |
|uuid                |`string            `|_RO/runtime_   |Unique identifier/object reference      |
|VM                  |`VM ref            `|_RO/runtime_   |VM that owns the VUSB                   |

### RPCs associated with class: VUSB

#### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VUSB.

_Signature:_

```
void add_to_other_config (session ref session_id, VUSB ref self, string key, string value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to add                              |
|`string                      `|value                         |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: create

_Overview:_

Create a new VUSB record in the database only

_Signature:_

```
VUSB ref create (session ref session_id, VM ref VM, USB_group ref USB_group, (string -> string) map other_config)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VM ref                      `|VM                            |The VM                                  |
|`USB_group ref               `|USB&#95;group                 |                                        |
|`(string -> string) map      `|other&#95;config              |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `VUSB ref`

The ref of the newly created VUSB record.

#### RPC name: destroy

_Overview:_

Removes a VUSB record from the database

_Signature:_

```
void destroy (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |The VUSB to destroy about               |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: get&#95;all

_Overview:_

Return a list of all the VUSBs known to the system.

_Signature:_

```
VUSB ref set get_all (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref set`

references to all objects

#### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VUSB references to VUSB records for all VUSBs known to the system.

_Signature:_

```
(VUSB ref -> VUSB record) map get_all_records (session ref session_id)
```

_Minimum Role:_ read-only

_Return Type:_ `(VUSB ref -> VUSB record) map`

records of all objects

#### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VUSB.

_Signature:_

```
vusb_operations set get_allowed_operations (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vusb_operations set`

value of the field

#### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VUSB instance with the specified UUID.

_Signature:_

```
VUSB ref get_by_uuid (session ref session_id, string uuid)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`string                      `|uuid                          |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref`

reference to the object

#### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VUSB.

_Signature:_

```
(string -> vusb_operations) map get_current_operations (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vusb_operations) map`

value of the field

#### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VUSB.

_Signature:_

```
bool get_currently_attached (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

#### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VUSB.

_Signature:_

```
(string -> string) map get_other_config (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

#### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VUSB.

_Signature:_

```
VUSB record get_record (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VUSB record`

all fields from the object

#### RPC name: get&#95;USB&#95;group

_Overview:_

Get the USB&#95;group field of the given VUSB.

_Signature:_

```
USB_group ref get_USB_group (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

value of the field

#### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VUSB.

_Signature:_

```
string get_uuid (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

#### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VUSB.

_Signature:_

```
VM ref get_VM (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

#### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VUSB.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_id, VUSB ref self, string key)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |
|`string                      `|key                           |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VUSB.

_Signature:_

```
void set_other_config (session ref session_id, VUSB ref self, (string -> string) map value)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |reference to the object                 |
|`(string -> string) map      `|value                         |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

#### RPC name: unplug

_Overview:_

Unplug the vusb device from the vm.

_Signature:_

```
void unplug (session ref session_id, VUSB ref self)
```

_Arguments:_

|type                          |name                          |description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|session ref                   |session_id                    |Reference to a valid session            |
|`VUSB ref                    `|self                          |vusb deivce                             |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

